@@ -71,24 +71,26 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
 #ifndef APPLY_OP_EXPRESSION_H
 #define APPLY_OP_EXPRESSION_H
 
-#include "ProgressIndicator.h"
 #include "ApplyOperatorLocal.h"
-#include "TimeVectorsKrylov.h"
+#include "CorrelationsSkeleton.h"
+#include "Io/IoSelector.h"
+#include "MultiSiteExpressionHelper.h"
+#include "ProgressIndicator.h"
+#include "StageEnum.h"
+#include "TargetParamsBase.h"
 #include "TimeVectorsChebyshev.h"
+#include "TimeVectorsKrylov.h"
 #include "TimeVectorsRungeKutta.h"
 #include "TimeVectorsSuzukiTrotter.h"
-#include "Io/IoSelector.h"
-#include "TargetParamsBase.h"
-#include "StageEnum.h"
-#include "MultiSiteExpressionHelper.h"
-#include "CorrelationsSkeleton.h"
 
-namespace Dmrg {
+namespace Dmrg
+{
 
-template<typename TargetHelperType,
-         typename VectorWithOffsetType,
-         typename LanczosSolverType>
-class ApplyOperatorExpression {
+template <typename TargetHelperType,
+    typename VectorWithOffsetType,
+    typename LanczosSolverType>
+class ApplyOperatorExpression
+{
 
 public:
 
@@ -102,49 +104,45 @@ public:
 	typedef typename BasisWithOperatorsType::SparseMatrixType SparseMatrixType;
 	typedef typename SparseMatrixType::value_type ComplexOrRealType;
 	typedef typename TargetHelperType::WaveFunctionTransfType WaveFunctionTransfType;
-	typedef TimeVectorsBase<TargetParamsType,ModelType,WaveFunctionTransfType,
-	LanczosSolverType,VectorWithOffsetType> TimeVectorsBaseType;
-	typedef TimeVectorsKrylov<TargetParamsType,ModelType,WaveFunctionTransfType,
-	LanczosSolverType,VectorWithOffsetType> TimeVectorsKrylovType;
-	typedef TimeVectorsChebyshev<TargetParamsType,ModelType,WaveFunctionTransfType,
-	LanczosSolverType,VectorWithOffsetType> TimeVectorsChebyshevType;
-	typedef TimeVectorsRungeKutta<TargetParamsType,ModelType,WaveFunctionTransfType,
-	LanczosSolverType,VectorWithOffsetType> TimeVectorsRungeKuttaType;
-	typedef TimeVectorsSuzukiTrotter<TargetParamsType,ModelType,WaveFunctionTransfType,
-	LanczosSolverType,VectorWithOffsetType> TimeVectorsSuzukiTrotterType;
+	typedef TimeVectorsBase<TargetParamsType, ModelType, WaveFunctionTransfType, LanczosSolverType, VectorWithOffsetType> TimeVectorsBaseType;
+	typedef TimeVectorsKrylov<TargetParamsType, ModelType, WaveFunctionTransfType, LanczosSolverType, VectorWithOffsetType> TimeVectorsKrylovType;
+	typedef TimeVectorsChebyshev<TargetParamsType, ModelType, WaveFunctionTransfType, LanczosSolverType, VectorWithOffsetType> TimeVectorsChebyshevType;
+	typedef TimeVectorsRungeKutta<TargetParamsType, ModelType, WaveFunctionTransfType, LanczosSolverType, VectorWithOffsetType> TimeVectorsRungeKuttaType;
+	typedef TimeVectorsSuzukiTrotter<TargetParamsType, ModelType, WaveFunctionTransfType, LanczosSolverType, VectorWithOffsetType> TimeVectorsSuzukiTrotterType;
 	typedef typename ModelType::InputValidatorType InputValidatorType;
 	typedef typename PsimagLite::Vector<VectorWithOffsetType*>::Type VectorVectorWithOffsetType;
 	typedef typename PsimagLite::Vector<SizeType>::Type VectorSizeType;
 	typedef typename PsimagLite::Vector<RealType>::Type VectorRealType;
-	typedef ApplyOperatorLocal<LeftRightSuperType,VectorWithOffsetType> ApplyOperatorType;
+	typedef ApplyOperatorLocal<LeftRightSuperType, VectorWithOffsetType> ApplyOperatorType;
 	typedef typename ApplyOperatorType::BorderEnum BorderEnumType;
 	typedef typename TimeVectorsBaseType::PairType PairType;
 	typedef StageEnum StageEnumType;
 	typedef typename PsimagLite::Vector<StageEnum>::Type VectorStageEnumType;
 	typedef MultiSiteExpressionHelper<LeftRightSuperType, VectorWithOffsetType>
-	MultiSiteExpressionHelperType;
+	    MultiSiteExpressionHelperType;
 	typedef typename MultiSiteExpressionHelperType::DmrgSerializerType DmrgSerializerType;
 	typedef CorrelationsSkeleton<MultiSiteExpressionHelperType, ModelType> CorrelationsSkeletonType;
 	typedef typename TimeVectorsBaseType::WftHelperType WftHelperType;
 	typedef typename VectorWithOffsetType::VectorType VectorType;
-	typedef typename PsimagLite::Vector<typename
-	PsimagLite::Vector<VectorWithOffsetType*>::Type>::Type VectorVectorVectorWithOffsetType;
+	typedef typename PsimagLite::Vector<typename PsimagLite::Vector<VectorWithOffsetType*>::Type>::Type VectorVectorVectorWithOffsetType;
+	typedef typename PsimagLite::Vector<VectorType>::Type VectorVectorType;
+	typedef typename PsimagLite::Vector<VectorVectorType>::Type VectorVectorVectorType;
 
 	ApplyOperatorExpression(const TargetHelperType& targetHelper,
-	                        SizeType indexNoAdvance)
-	    : progress_("ApplyOperatorExpression"),
-	      targetHelper_(targetHelper),
-	      E0_(0.0),
-	      indexNoAdvance_(indexNoAdvance),
-	      applyOpLocal_(targetHelper.lrs(), targetHelper.withLegacyBugs()),
-	      targetVectors_(0),
-	      timeVectorsBase_(new TimeVectorsBaseType(targetHelper_.model(),
-	                                               targetHelper_.lrs(),
-	                                               targetHelper_.wft(),
-	                                               "base")),
-	      wftHelper_(targetHelper.model(), targetHelper.lrs(), targetHelper.wft()),
-	      multiSiteExprHelper_(targetHelper_.model().superGeometry().numberOfSites() - 2),
-	      correlationsSkel_(multiSiteExprHelper_, targetHelper.model(), false)
+	    SizeType indexNoAdvance)
+	    : progress_("ApplyOperatorExpression")
+	    , targetHelper_(targetHelper)
+	    , E0_(0.0)
+	    , indexNoAdvance_(indexNoAdvance)
+	    , applyOpLocal_(targetHelper.lrs(), targetHelper.withLegacyBugs())
+	    , targetVectors_(0)
+	    , timeVectorsBase_(new TimeVectorsBaseType(targetHelper_.model(),
+		  targetHelper_.lrs(),
+		  targetHelper_.wft(),
+		  "base"))
+	    , wftHelper_(targetHelper.model(), targetHelper.lrs(), targetHelper.wft())
+	    , multiSiteExprHelper_(targetHelper_.model().superGeometry().numberOfSites() - 2)
+	    , correlationsSkel_(multiSiteExprHelper_, targetHelper.model(), false)
 	{
 		timesWithoutAdvancement_ = 0;
 		firstSeeLeftCorner_ = false;
@@ -163,7 +161,7 @@ public:
 		}
 	}
 
-	virtual void initPsi(SizeType nsectors, SizeType nexcited)
+	void initPsi(SizeType nsectors, SizeType nexcited)
 	{
 		if (psi_.size() > 0) {
 			bool flag = true;
@@ -176,10 +174,11 @@ public:
 						flag = false;
 			}
 
-			if (flag) return;
+			if (flag)
+				return;
 
-			std::cerr<<"AOE::initPsi(): WARNING sectors/nexcited changed during run\n";
-			std::cout<<"AOE::initPsi(): WARNING sectors/nexcited changed during run\n";
+			std::cerr << "AOE::initPsi(): WARNING sectors/nexcited changed during run\n";
+			std::cout << "AOE::initPsi(): WARNING sectors/nexcited changed during run\n";
 			clearPsi();
 		}
 
@@ -198,11 +197,11 @@ public:
 	}
 
 	SizeType getPhi(VectorWithOffsetType* phiNew,
-	                RealType Eg,
-	                ProgramGlobals::DirectionEnum direction,
-	                SizeType site,
-	                SizeType loopNumber,
-	                const TargetParamsType& tstStruct)
+	    RealType Eg,
+	    ProgramGlobals::DirectionEnum direction,
+	    SizeType site,
+	    SizeType loopNumber,
+	    const TargetParamsType& tstStruct)
 	{
 		SizeType count = 0;
 		const SizeType nsectors = psi_.size();
@@ -222,7 +221,7 @@ public:
 		SizeType max = tstStruct.sites();
 		if (noStageIs(StageEnum::DISABLED)) {
 			max = 1;
-			for (SizeType i=0;i<stage_.size();i++) {
+			for (SizeType i = 0; i < stage_.size(); i++) {
 				if (stage_[i] == StageEnum::OPERATOR)
 					stage_[i] = StageEnum::WFT_NOADVANCE;
 				if (stage_[i] == StageEnum::WFT_ADVANCE)
@@ -236,7 +235,8 @@ public:
 
 			SizeType count2 = evolve(i, Eg, direction, site, loopNumber, max - 1, tstStruct);
 
-			if (count2 == 0) continue;
+			if (count2 == 0)
+				continue;
 
 			// phi = A|psi>
 			if (phiNew)
@@ -244,33 +244,37 @@ public:
 
 			count += count2;
 
-			if (!phiNew) continue;
+			if (!phiNew)
+				continue;
 
 			if (tstStruct.concatenation() == TargetParamsType::ConcatEnum::PRODUCT) {
 				phiOld = *phiNew;
 			} else {
-				if (stage_[i] == StageEnum::OPERATOR) vectorSum += *phiNew;
-				else vectorSum = *phiNew;
+				if (stage_[i] == StageEnum::OPERATOR)
+					vectorSum += *phiNew;
+				else
+					vectorSum = *phiNew;
 			}
 		}
 
 		if (phiNew && tstStruct.concatenation() == TargetParamsType::ConcatEnum::SUM)
 			*phiNew = vectorSum;
 
-		if (allStages(StageEnum::DISABLED)) E0_ = Eg;
+		if (allStages(StageEnum::DISABLED))
+			E0_ = Eg;
 
 		if (noStageIs(StageEnum::DISABLED)) {
 			PsimagLite::OstringStream msgg(std::cout.precision());
 			PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-			msg<<"EnergyForExp was ";
+			msg << "EnergyForExp was ";
 			if (tstStruct.isEnergyForExp()) {
 				E0_ = tstStruct.energyForExp();
-				msg<<"provided explicitly, ";
+				msg << "provided explicitly, ";
 			} else {
-				msg<<"not provided explicitly, ";
+				msg << "not provided explicitly, ";
 			}
 
-			msg<<" value= "<<E0_;
+			msg << " value= " << E0_;
 			progress_.printline(msgg, std::cout);
 		}
 
@@ -279,15 +283,17 @@ public:
 
 	bool allStages(StageEnum x) const
 	{
-		for (SizeType i=0;i<stage_.size();i++)
-			if (stage_[i] != x) return false;
+		for (SizeType i = 0; i < stage_.size(); i++)
+			if (stage_[i] != x)
+				return false;
 		return true;
 	}
 
 	bool noStageIs(StageEnum x) const
 	{
-		for (SizeType i=0;i<stage_.size();i++)
-			if (stage_[i] == x) return false;
+		for (SizeType i = 0; i < stage_.size(); i++)
+			if (stage_[i] == x)
+				return false;
 		return true;
 	}
 
@@ -307,8 +313,8 @@ public:
 
 	void setOnlyOnePsi(const VectorWithOffsetType& v)
 	{
-		std::cerr<<"Setting only one psi\n";
-		std::cout<<"Setting only one psi\n";
+		std::cerr << "Setting only one psi\n";
+		std::cout << "Setting only one psi\n";
 
 		clearPsi();
 
@@ -317,29 +323,40 @@ public:
 		psi_[0][0] = new VectorWithOffsetType(v);
 	}
 
-	template<typename SomeBasisType>
-	void setPsi(SizeType sectorIndex,
-	            SizeType excitedIndex,
-	            VectorType& v,
-	            const SomeBasisType& basis,
-	            const VectorSizeType& sectors)
+	template <typename SomeBasisType>
+	void setPsi(VectorVectorVectorType& inV,
+	    const VectorSizeType& sectors,
+	    const SomeBasisType& someBasis,
+	    SizeType nexcited)
 	{
-		if (psi_.size() == 0) {
-			psi_.resize(sectors.size());
-			const SizeType nexcited = targetHelper_.model().params().numberOfExcited;
-			for (SizeType i = 0; i < psi_.size(); ++i)
-				psi_[i].resize(nexcited);
+		const SizeType nsectors = sectors.size();
+
+		assert(nsectors > 0);
+
+		assert(nexcited > 0);
+
+		if (nsectors != inV.size())
+			err("FATAL: inV.size == " + ttos(inV.size()) + " but params.excited.size= "
+			    + ttos(nsectors) + "\n");
+
+		this->initPsi(nsectors, nexcited);
+
+		for (SizeType sectorIndex = 0; sectorIndex < nsectors; ++sectorIndex) {
+			if (inV[sectorIndex].size() != nexcited)
+				err("Expected inV[" + ttos(sectorIndex) + "].size == " + ttos(nexcited) + " but found " + ttos(inV[sectorIndex].size()) + " instead\n");
+
+			for (SizeType excitedIndex = 0; excitedIndex < nexcited; ++excitedIndex) {
+
+				if (!psi_[sectorIndex][excitedIndex]) {
+					psi_[sectorIndex][excitedIndex] = new VectorWithOffsetType;
+				}
+
+				assert(sectorIndex < sectors.size());
+				psi_[sectorIndex][excitedIndex]->set(inV[sectorIndex][excitedIndex],
+				    sectors[sectorIndex],
+				    someBasis);
+			}
 		}
-
-		assert(sectorIndex < sectors.size());
-		const SizeType sector = sectors[sectorIndex];
-
-		assert(sectorIndex < psi_.size());
-		assert(excitedIndex < psi_[sectorIndex].size());
-
-		if (!psi_[sectorIndex][excitedIndex])
-			psi_[sectorIndex][excitedIndex] = new VectorWithOffsetType;
-		psi_[sectorIndex][excitedIndex]->set(v, sector, basis);
 	}
 
 	void writePsi(PsimagLite::IoSelector::Out& io, PsimagLite::String prefix) const
@@ -431,14 +448,16 @@ public:
 			}
 		}
 
-		if (x == 0) return;
+		if (x == 0)
+			return;
 		targetVectorsResize(n - x);
 	}
 
 	void targetVectorsResize(SizeType x)
 	{
 		const SizeType n = targetVectors_.size();
-		if (n == x) return;
+		if (n == x)
+			return;
 
 		if (n < x) {
 			const SizeType r = x - n;
@@ -460,12 +479,12 @@ public:
 
 		PsimagLite::OstringStream msgg(std::cout.precision());
 		PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-		msg<<"Number of target vectors is now "<<targetVectors_.size();
+		msg << "Number of target vectors is now " << targetVectors_.size();
 		progress_.printline(msgg, std::cout);
 	}
 
 	void initTimeVectors(const TargetParamsType& tstStruct,
-	                     InputValidatorType& ioIn)
+	    InputValidatorType& ioIn)
 	{
 		delete timeVectorsBase_;
 		timeVectorsBase_ = nullptr;
@@ -473,39 +492,39 @@ public:
 		const ModelType& model = targetHelper_.model();
 		const WaveFunctionTransfType& wft = targetHelper_.wft();
 
-		PsimagLite::String s (__FILE__);
+		PsimagLite::String s(__FILE__);
 		s += " Unknown algorithm\n";
 
 		switch (tstStruct.algorithm()) {
 		case TargetParamsType::AlgorithmEnum::KRYLOV:
 			timeVectorsBase_ = new TimeVectorsKrylovType(tstStruct,
-			                                             targetVectors_,
-			                                             model,
-			                                             wft,
-			                                             lrs,
-			                                             ioIn);
+			    targetVectors_,
+			    model,
+			    wft,
+			    lrs,
+			    ioIn);
 			break;
 		case TargetParamsType::AlgorithmEnum::CHEBYSHEV:
 			timeVectorsBase_ = new TimeVectorsChebyshevType(tstStruct,
-			                                                targetVectors_,
-			                                                model,
-			                                                wft,
-			                                                lrs,
-			                                                ioIn);
+			    targetVectors_,
+			    model,
+			    wft,
+			    lrs,
+			    ioIn);
 			break;
 		case TargetParamsType::AlgorithmEnum::RUNGE_KUTTA:
 			timeVectorsBase_ = new TimeVectorsRungeKuttaType(tstStruct,
-			                                                 targetVectors_,
-			                                                 model,
-			                                                 wft,
-			                                                 lrs);
+			    targetVectors_,
+			    model,
+			    wft,
+			    lrs);
 			break;
 		case TargetParamsType::AlgorithmEnum::SUZUKI_TROTTER:
 			timeVectorsBase_ = new TimeVectorsSuzukiTrotterType(tstStruct,
-			                                                    targetVectors_,
-			                                                    model,
-			                                                    wft,
-			                                                    lrs);
+			    targetVectors_,
+			    model,
+			    wft,
+			    lrs);
 			break;
 		default:
 			throw PsimagLite::RuntimeError(s.c_str());
@@ -519,7 +538,7 @@ public:
 	}
 
 	void loadEnergy(PsimagLite::IoSelector::In& io,
-	                PsimagLite::String label)
+	    PsimagLite::String label)
 	{
 		SizeType nsectors = 0;
 		io.read(nsectors, label + "/Size");
@@ -540,58 +559,57 @@ public:
 		io.read(E0_, label + "/0/0");
 	}
 
-	void multiplyTimeVector(SizeType i,RealType factor)
+	void multiplyTimeVector(SizeType i, RealType factor)
 	{
-		*targetVectors_[i] = factor*(*targetVectors_[i]);
+		*targetVectors_[i] = factor * (*targetVectors_[i]);
 	}
 
 	void calcTimeVectors(const PsimagLite::Vector<SizeType>::Type& indices,
-	                     RealType Eg,
-	                     const VectorWithOffsetType& phi,
-	                     ProgramGlobals::DirectionEnum direction,
-	                     bool allOperatorsApplied,
-	                     bool wftAndAdvanceIfNeeded,
-	                     const PsimagLite::Vector<SizeType>::Type& block,
-	                     bool isLastCall)
+	    RealType Eg,
+	    const VectorWithOffsetType& phi,
+	    ProgramGlobals::DirectionEnum direction,
+	    bool allOperatorsApplied,
+	    bool wftAndAdvanceIfNeeded,
+	    const PsimagLite::Vector<SizeType>::Type& block,
+	    bool isLastCall)
 	{
 		typename TimeVectorsBaseType::ExtraData extra(direction,
-		                                              allOperatorsApplied,
-		                                              wftAndAdvanceIfNeeded,
-		                                              block,
-		                                              isLastCall);
+		    allOperatorsApplied,
+		    wftAndAdvanceIfNeeded,
+		    block,
+		    isLastCall);
 		if (timeVectorsBase_->isBase())
 			err("timeVectorsBase_ ptr not setup!?\n");
 
 		timeVectorsBase_->calcTimeVectors(indices,
-		                                  Eg,
-		                                  phi,
-		                                  extra);
+		    Eg,
+		    phi,
+		    extra);
 	}
 
 	void applyOneOperator(SizeType loopNumber,
-	                      SizeType indexOfOperator,
-	                      SizeType site,
-	                      VectorWithOffsetType& phiNew,
-	                      const VectorWithOffsetType& psiSrc,
-	                      const ProgramGlobals::DirectionEnum systemOrEnviron,
-	                      const TargetParamsType& tstStruct)
+	    SizeType indexOfOperator,
+	    SizeType site,
+	    VectorWithOffsetType& phiNew,
+	    const VectorWithOffsetType& psiSrc,
+	    const ProgramGlobals::DirectionEnum systemOrEnviron,
+	    const TargetParamsType& tstStruct)
 	{
-		if (tstStruct.startingLoops().size()>0 &&
-		        tstStruct.startingLoops()[indexOfOperator]>loopNumber)
+		if (tstStruct.startingLoops().size() > 0 && tstStruct.startingLoops()[indexOfOperator] > loopNumber)
 			return;
 
 		const bool hasBeenApplied = (phiNew.size() > 0);
-		if (hasBeenApplied) return;
+		if (hasBeenApplied)
+			return;
 
 		VectorWithOffsetType phiOld = psiSrc;
 		SizeType numberOfSites = targetHelper_.lrs().super().block().size();
 
-		BorderEnumType corner = (site == 0 || site == numberOfSites -1) ?
-		            ApplyOperatorType::BORDER_YES : ApplyOperatorType::BORDER_NO;
+		BorderEnumType corner = (site == 0 || site == numberOfSites - 1) ? ApplyOperatorType::BORDER_YES : ApplyOperatorType::BORDER_NO;
 
 		PsimagLite::OstringStream msgg(std::cout.precision());
 		PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-		msg<<"I'm applying a local operator now";
+		msg << "I'm applying a local operator now";
 		progress_.printline(msgg, std::cout);
 
 		const SizeType splitSize = targetHelper_.model().hilbertSize(site);
@@ -600,18 +618,18 @@ public:
 		targetHelper_.model().findOddElectronsOfOneSite(signs, site);
 		FermionSign fs(targetHelper_.lrs().left(), signs);
 		applyOpLocal_(phiNew,
-		              phiOld,
-		              tstStruct.aOperators()[indexOfOperator],
-		              fs,
-		              splitSize,
-		              systemOrEnviron,
-		              corner);
+		    phiOld,
+		    tstStruct.aOperators()[indexOfOperator],
+		    fs,
+		    splitSize,
+		    systemOrEnviron,
+		    corner);
 
 		RealType norma = norm(phiNew);
-		if (norma<1e-6) {
+		if (norma < 1e-6) {
 			PsimagLite::OstringStream msgg2(std::cout.precision());
 			PsimagLite::OstringStream::OstringStreamType& msg2 = msgg2();
-			msg2<<"Norm of phi is zero\n";
+			msg2 << "Norm of phi is zero\n";
 			progress_.printline(msgg2, std::cout);
 		}
 	}
@@ -628,8 +646,8 @@ public:
 	}
 
 	void wftOneVector(VectorWithOffsetType& phiNew,
-	                  const VectorWithOffsetType& src,
-	                  SizeType site) const
+	    const VectorWithOffsetType& src,
+	    SizeType site) const
 	{
 		wftHelper_.wftOneVector(phiNew, src, site);
 	}
@@ -637,12 +655,10 @@ public:
 	const VectorWithOffsetType& ensureOnlyOnePsi(PsimagLite::String func) const
 	{
 		if (psi_.size() != 1)
-			err("ensureOnlyOnePsi failed (more than one excited); called from" +
-			    func + "\n");
+			err("ensureOnlyOnePsi failed (more than one excited); called from" + func + "\n");
 
 		if (psi_[0].size() != 1)
-			err("ensureOnlyOnePsi failed (more than one sector); called from" +
-			    func + "\n");
+			err("ensureOnlyOnePsi failed (more than one sector); called from" + func + "\n");
 
 		return *(psi_[0][0]);
 	}
@@ -658,7 +674,7 @@ private:
 
 	// legacy reading, use only as fallback
 	void loadEnergyLegacy(PsimagLite::IoSelector::In& io,
-	                      PsimagLite::String label)
+	    PsimagLite::String label)
 	{
 		SizeType total = 0;
 		io.read(total, label + "/Size");
@@ -669,14 +685,15 @@ private:
 
 	void checkOrder(SizeType i, const TargetParamsType& tstStruct) const
 	{
-		if (i==0) return;
-		for (SizeType j=0;j<i;j++) {
+		if (i == 0)
+			return;
+		for (SizeType j = 0; j < i; j++) {
 			if (stage_[j] == StageEnum::DISABLED) {
-				PsimagLite::String s ="TST:: Seeing dynamic site ";
+				PsimagLite::String s = "TST:: Seeing dynamic site ";
 				s += ttos(tstStruct.sites(i));
-				s =s + " before having seen";
-				s = s + " site "+ttos(tstStruct.sites(j));
-				s = s +". Please order your dynamic sites in order of appearance.\n";
+				s = s + " before having seen";
+				s = s + " site " + ttos(tstStruct.sites(j));
+				s = s + ". Please order your dynamic sites in order of appearance.\n";
 				throw PsimagLite::RuntimeError(s);
 			}
 		}
@@ -701,12 +718,12 @@ private:
 	}
 
 	SizeType evolve(SizeType i,
-	                RealType Eg,
-	                ProgramGlobals::DirectionEnum direction,
-	                SizeType site,
-	                SizeType loopNumber,
-	                SizeType lastI,
-	                const TargetParamsType& tstStruct)
+	    RealType Eg,
+	    ProgramGlobals::DirectionEnum direction,
+	    SizeType site,
+	    SizeType loopNumber,
+	    SizeType lastI,
+	    const TargetParamsType& tstStruct)
 	{
 		SizeType advanceEach = tstStruct.advanceEach();
 
@@ -715,13 +732,13 @@ private:
 			return 0;
 		}
 
-		if (tstStruct.startingLoops().size()>0 &&
-		        tstStruct.startingLoops()[i]>loopNumber) return 0;
+		if (tstStruct.startingLoops().size() > 0 && tstStruct.startingLoops()[i] > loopNumber)
+			return 0;
 
 		if (site != tstStruct.sites(i) && stage_[i] == StageEnum::DISABLED)
 			return 0;
 
-		if (site != tstStruct.sites(i) && stage_[i] != StageEnum::DISABLED && i>0)
+		if (site != tstStruct.sites(i) && stage_[i] != StageEnum::DISABLED && i > 0)
 			return 0;
 
 		if (site == tstStruct.sites(i) && stage_[i] == StageEnum::DISABLED) {
@@ -730,13 +747,14 @@ private:
 			stage_[i] = StageEnum::WFT_NOADVANCE;
 		}
 
-		if (stage_[i] == StageEnum::OPERATOR) checkOrder(i, tstStruct);
+		if (stage_[i] == StageEnum::OPERATOR)
+			checkOrder(i, tstStruct);
 
 		const OptionsType& options = targetHelper_.model().params().options;
 		const bool advanceOnlyAtBorder = !options.isSet("advanceUnrestricted");
 
 		SizeType sites = targetHelper_.model().superGeometry().numberOfSites();
-		bool weAreAtBorder = (site < 1 || site >= sites-1);
+		bool weAreAtBorder = (site < 1 || site >= sites - 1);
 		bool dontAdvance = (advanceOnlyAtBorder & !weAreAtBorder);
 
 		if (advanceEach > 0 && timesWithoutAdvancement_ >= advanceEach && !dontAdvance) {
@@ -747,53 +765,47 @@ private:
 				timeVectorsBase_->timeHasAdvanced();
 			}
 		} else {
-			if (i == lastI &&
-			        stage_[i] == StageEnum::WFT_NOADVANCE &&
-			        firstSeeLeftCorner_)
+			if (i == lastI && stage_[i] == StageEnum::WFT_NOADVANCE && firstSeeLeftCorner_)
 				++timesWithoutAdvancement_;
 		}
 
-		if (!firstSeeLeftCorner_ &&
-		        i==lastI &&
-		        stage_[i] == StageEnum::WFT_NOADVANCE &&
-		        site==1)
+		if (!firstSeeLeftCorner_ && i == lastI && stage_[i] == StageEnum::WFT_NOADVANCE && site == 1)
 			firstSeeLeftCorner_ = true;
 
 		const RealType time = timeVectorsBase_->time();
 		PsimagLite::OstringStream msgg2(std::cout.precision());
 		PsimagLite::OstringStream::OstringStreamType& msg2 = msgg2();
-		msg2<<"Steps without advance: "<<timesWithoutAdvancement_;
-		msg2<<" site="<<site<<" currenTime="<<time;
-		if (timesWithoutAdvancement_ > 0) progress_.printline(msgg2, std::cout);
+		msg2 << "Steps without advance: " << timesWithoutAdvancement_;
+		msg2 << " site=" << site << " currenTime=" << time;
+		if (timesWithoutAdvancement_ > 0)
+			progress_.printline(msgg2, std::cout);
 
 		PsimagLite::OstringStream msgg(std::cout.precision());
 		PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-		msg<<"Evolving, stage="<<stageToString(i);
-		msg<<" site="<<site<<" loopNumber="<<loopNumber;
-		msg<<" Eg="<<Eg;
+		msg << "Evolving, stage=" << stageToString(i);
+		msg << " site=" << site << " loopNumber=" << loopNumber;
+		msg << " Eg=" << Eg;
 		progress_.printline(msgg, std::cout);
 
 		return 1;
 	}
 
 	void computePhi(SizeType i,
-	                SizeType site,
-	                VectorWithOffsetType& phiNew,
-	                VectorWithOffsetType& phiOld,
-	                const ProgramGlobals::DirectionEnum systemOrEnviron,
-	                const TargetParamsType& tstStruct) const
+	    SizeType site,
+	    VectorWithOffsetType& phiNew,
+	    VectorWithOffsetType& phiOld,
+	    const ProgramGlobals::DirectionEnum systemOrEnviron,
+	    const TargetParamsType& tstStruct) const
 	{
 		SizeType numberOfSites = targetHelper_.lrs().super().block().size();
 
 		if (stage_[i] == StageEnum::OPERATOR) {
 
-			BorderEnumType corner = (tstStruct.sites(i)==0 ||
-			                         tstStruct.sites(i)==numberOfSites -1) ?
-			            ApplyOperatorType::BORDER_YES : ApplyOperatorType::BORDER_NO;
+			BorderEnumType corner = (tstStruct.sites(i) == 0 || tstStruct.sites(i) == numberOfSites - 1) ? ApplyOperatorType::BORDER_YES : ApplyOperatorType::BORDER_NO;
 
 			PsimagLite::OstringStream msgg(std::cout.precision());
 			PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-			msg<<"I'm applying a local operator now";
+			msg << "I'm applying a local operator now";
 			progress_.printline(msgg, std::cout);
 			typename PsimagLite::Vector<bool>::Type signs;
 			targetHelper_.model().findOddElectronsOfOneSite(signs, site);
@@ -801,27 +813,25 @@ private:
 			const SizeType splitSize = targetHelper_.model().hilbertSize(site);
 			FermionSign fs(targetHelper_.lrs().left(), signs);
 			applyOpLocal_(phiNew,
-			              phiOld,
-			              tstStruct.aOperators()[i],
-			              fs,
-			              splitSize,
-			              systemOrEnviron,corner);
+			    phiOld,
+			    tstStruct.aOperators()[i],
+			    fs,
+			    splitSize,
+			    systemOrEnviron,
+			    corner);
 			RealType norma = norm(phiNew);
 
-			if (norma<1e-6) {
+			if (norma < 1e-6) {
 				PsimagLite::OstringStream msgg2(std::cout.precision());
 				PsimagLite::OstringStream::OstringStreamType& msg2 = msgg2();
-				msg2<<"Norm of phi is zero\n";
+				msg2 << "Norm of phi is zero\n";
 				progress_.printline(msgg2, std::cout);
 			}
-		} else if (stage_[i] == StageEnum::WFT_NOADVANCE ||
-		           stage_[i] == StageEnum::WFT_ADVANCE) {
+		} else if (stage_[i] == StageEnum::WFT_NOADVANCE || stage_[i] == StageEnum::WFT_ADVANCE) {
 			const SizeType advanceEach = tstStruct.advanceEach();
 			SizeType advance = indexNoAdvance_;
 
-			if (advanceEach > 0 &&
-			        stage_[i] == StageEnum::WFT_ADVANCE &&
-			        !timeVectorsBase_->isBase()) {
+			if (advanceEach > 0 && stage_[i] == StageEnum::WFT_ADVANCE && !timeVectorsBase_->isBase()) {
 				SizeType timeSteps = tstStruct.times().size();
 				advance = (timeSteps > 0) ? timeSteps - 1 : 0;
 			}
@@ -842,7 +852,7 @@ private:
 				throw PsimagLite::RuntimeError(s);
 			}
 
-			if  (site == 0 || site == numberOfSites -1) {
+			if (site == 0 || site == numberOfSites - 1) {
 				// don't wft since we did it before
 				assert(advance < targetVectors_.size());
 				if (!timeVectorsBase_->isBase() || advanceEach == 0)
@@ -863,7 +873,7 @@ private:
 			const SizeType nexcited = psi_[i].size();
 			for (SizeType j = 0; j < nexcited; ++j) {
 				delete psi_[i][j];
-				psi_[i][j] = 0;
+				psi_[i][j] = nullptr;
 			}
 		}
 	}
@@ -888,12 +898,11 @@ private:
 	static bool firstSeeLeftCorner_;
 };
 
-template<typename T1, typename T2, typename T3>
-SizeType ApplyOperatorExpression<T1,T2,T3>::timesWithoutAdvancement_ = 0;
+template <typename T1, typename T2, typename T3>
+SizeType ApplyOperatorExpression<T1, T2, T3>::timesWithoutAdvancement_ = 0;
 
-template<typename T1, typename T2, typename T3>
-bool ApplyOperatorExpression<T1,T2,T3>::firstSeeLeftCorner_ = false;
+template <typename T1, typename T2, typename T3>
+bool ApplyOperatorExpression<T1, T2, T3>::firstSeeLeftCorner_ = false;
 } // namespace Dmrg
 
 #endif // APPLY_OP_EXPRESSION_H
-
