@@ -80,32 +80,35 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
 #ifndef CORRECTION_VECTOR_SKEL_H
 #define CORRECTION_VECTOR_SKEL_H
 
-#include "ProgressIndicator.h"
 #include "BLAS.h"
-#include "VectorWithOffsets.h"
-#include "CorrectionVectorFunction.h"
-#include "ParametersForSolver.h"
-#include "ParallelTriDiag.h"
-#include "FreqEnum.h"
-#include "NoPthreadsNg.h"
-#include "TridiagRixsStatic.h"
-#include "KrylovHelper.h"
 #include "CorrectionVectorAction.h"
+#include "CorrectionVectorFunction.h"
+#include "FreqEnum.h"
+#include "KrylovHelper.h"
+#include "NoPthreadsNg.h"
+#include "ParallelTriDiag.h"
+#include "ParametersForSolver.h"
+#include "ProgressIndicator.h"
+#include "TridiagRixsStatic.h"
+#include "VectorWithOffsets.h"
 
-namespace Dmrg {
+namespace Dmrg
+{
 
-template<typename LanczosSolverType_,
-         typename VectorWithOffsetType_,
-         typename TargetingBaseType,
-         typename TargetParamsType>
-class CorrectionVectorSkeleton {
+template <typename LanczosSolverType_,
+    typename VectorWithOffsetType_,
+    typename TargetingBaseType,
+    typename TargetParamsType>
+class CorrectionVectorSkeleton
+{
 
 public:
 
 	typedef CorrectionVectorSkeleton<LanczosSolverType_,
-	VectorWithOffsetType_,
-	TargetingBaseType,
-	TargetParamsType> ThisType;
+	    VectorWithOffsetType_,
+	    TargetingBaseType,
+	    TargetParamsType>
+	    ThisType;
 	typedef LanczosSolverType_ LanczosSolverType;
 	typedef typename TargetingBaseType::MatrixVectorType MatrixVectorType;
 	typedef typename MatrixVectorType::ModelType ModelType;
@@ -132,26 +135,29 @@ public:
 	typedef typename LanczosSolverType::PostProcType PostProcType;
 	typedef typename LanczosSolverType::MatrixType LanczosMatrixType;
 	typedef CorrectionVectorFunction<LanczosMatrixType,
-	TargetParamsType> CorrectionVectorFunctionType;
+	    TargetParamsType>
+	    CorrectionVectorFunctionType;
 	typedef ParallelTriDiag<ModelType, LanczosSolverType, VectorWithOffsetType>
-	ParallelTriDiagType;
+	    ParallelTriDiagType;
 	typedef TridiagRixsStatic<ModelType, LanczosSolverType, VectorWithOffsetType>
-	TridiagRixsStaticType;
+	    TridiagRixsStaticType;
 	typedef typename ParallelTriDiagType::MatrixComplexOrRealType MatrixComplexOrRealType;
 	typedef typename ParallelTriDiagType::VectorMatrixFieldType VectorMatrixFieldType;
 	typedef PsimagLite::Vector<SizeType>::Type VectorSizeType;
 	typedef typename PsimagLite::Vector<VectorRealType>::Type VectorVectorRealType;
 	typedef typename ModelType::InputValidatorType InputValidatorType;
 
-	class CalcR {
+	class CalcR
+	{
 
 	public:
 
 		typedef CorrectionVectorAction<ComplexOrRealType, TargetParamsType> ActionType;
 
 		CalcR(const TargetParamsType& tstStruct, RealType E0, const VectorRealType& eigs)
-		    : action_(tstStruct,E0,eigs)
-		{}
+		    : action_(tstStruct, E0, eigs)
+		{
+		}
 
 		const ActionType& imag() const
 		{
@@ -180,88 +186,89 @@ public:
 	typedef KrylovHelper<typename CalcR::ActionType, TypeWrapper> KrylovHelperType;
 
 	CorrectionVectorSkeleton(InputValidatorType& ioIn,
-	                         const TargetParamsType& tstStruct,
-	                         const ModelType& model,
-	                         const LeftRightSuperType& lrs,
-	                         const RealType& energy)
-	    : ioIn_(ioIn),
-	      tstStruct_(tstStruct),
-	      model_(model),
-	      lrs_(lrs),
-	      energy_(energy),
-	      progress_("CorrectionVectorSkeleton"),
-	      krylovHelper_(model.params(), tstStruct.firstRitz())
-	{}
+	    const TargetParamsType& tstStruct,
+	    const ModelType& model,
+	    const LeftRightSuperType& lrs,
+	    const RealType& energy)
+	    : ioIn_(ioIn)
+	    , tstStruct_(tstStruct)
+	    , model_(model)
+	    , lrs_(lrs)
+	    , energy_(energy)
+	    , progress_("CorrectionVectorSkeleton")
+	    , krylovHelper_(model.params(), tstStruct.firstRitz())
+	{
+	}
 
 	void calcDynVectors(const VectorWithOffsetType& tv0,
-	                    VectorWithOffsetType& tv1,
-	                    VectorWithOffsetType& tv2)
+	    VectorWithOffsetType& tv1,
+	    VectorWithOffsetType& tv2)
 	{
-		const bool needsTv2 = (!CalcR::ActionType::isValueComplex() || tstStruct_.algorithm() !=
-		        TargetParamsType::BaseType::AlgorithmEnum::KRYLOV);
+		const bool needsTv2 = (!CalcR::ActionType::isValueComplex() || tstStruct_.algorithm() != TargetParamsType::BaseType::AlgorithmEnum::KRYLOV);
 
 		const VectorWithOffsetType& phi = tv0;
 		tv1 = phi;
-		if (needsTv2) tv2 = phi;
+		if (needsTv2)
+			tv2 = phi;
 
 		VectorMatrixFieldType V(phi.sectors());
 		VectorMatrixFieldType T(phi.sectors());
 
 		VectorSizeType steps(phi.sectors());
 
-		triDiag(phi,T,V,steps);
+		triDiag(phi, T, V, steps);
 
 		VectorVectorRealType eigs(phi.sectors());
 
-		for (SizeType ii = 0;ii < phi.sectors(); ++ii)
-			PsimagLite::diag(T[ii],eigs[ii],'V');
+		for (SizeType ii = 0; ii < phi.sectors(); ++ii)
+			PsimagLite::diag(T[ii], eigs[ii], 'V');
 
-		for (SizeType i=0;i<phi.sectors();i++) {
+		for (SizeType i = 0; i < phi.sectors(); i++) {
 			VectorType sv;
 			SizeType i0 = phi.sector(i);
-			tv0.extract(sv,i0);
+			tv0.extract(sv, i0);
 			// g.s. is included separately
 			// set Aq
-			//tv0.setDataInSector(sv,i0);
+			// tv0.setDataInSector(sv,i0);
 			// set xi
 			SizeType p = lrs_.super().findPartitionNumber(phi.offset(i0));
-			VectorType xi(sv.size(),0),xr(sv.size(),0);
+			VectorType xi(sv.size(), 0), xr(sv.size(), 0);
 
 			if (tstStruct_.algorithm() == TargetParamsType::BaseType::AlgorithmEnum::KRYLOV) {
-				computeXiAndXrKrylov(xi,xr,phi,i0,V[i],T[i],eigs[i],steps[i]);
+				computeXiAndXrKrylov(xi, xr, phi, i0, V[i], T[i], eigs[i], steps[i]);
 			} else {
-				computeXiAndXrIndirect(xi,xr,sv,p);
+				computeXiAndXrIndirect(xi, xr, sv, p);
 			}
 
-			tv1.setDataInSector(xi,i0);
-			//set xr
+			tv1.setDataInSector(xi, i0);
+			// set xr
 
 			if (needsTv2)
-				tv2.setDataInSector(xr,i0);
+				tv2.setDataInSector(xr, i0);
 		}
 
-		weightForContinuedFraction_ = PsimagLite::real(phi*phi);
+		weightForContinuedFraction_ = PsimagLite::real(phi * phi);
 	}
 
 	void calcDynVectors(const VectorWithOffsetType& tv0,
-	                    const VectorWithOffsetType& tv1,
-	                    VectorWithOffsetType& tv2,
-	                    VectorWithOffsetType& tv3)
+	    const VectorWithOffsetType& tv1,
+	    VectorWithOffsetType& tv2,
+	    VectorWithOffsetType& tv3)
 	{
 		VectorWithOffsetType tv4;
-		calcDynVectors(tv0,tv4,tv2);
+		calcDynVectors(tv0, tv4, tv2);
 		VectorWithOffsetType tv5;
-		calcDynVectors(tv1,tv5,tv3);
+		calcDynVectors(tv1, tv5, tv3);
 		tv2 += tv5;
-		tv3 += (-1.0)*tv4;
+		tv3 += (-1.0) * tv4;
 	}
 
 private:
 
 	void computeXiAndXrIndirect(VectorType& xi,
-	                            VectorType& xr,
-	                            const VectorType& sv,
-	                            SizeType p)
+	    VectorType& xr,
+	    const VectorType& sv,
+	    SizeType p)
 	{
 		if (tstStruct_.omega().first != PsimagLite::FREQ_REAL)
 			throw PsimagLite::RuntimeError("Matsubara only with KRYLOV\n");
@@ -269,38 +276,42 @@ private:
 		const RealType fakeTime = 0;
 		typename ModelHelperType::Aux aux(p, lrs_);
 		typename ModelType::HamiltonianConnectionType hc(lrs_,
-		                                                 ModelType::modelLinks(),
-		                                                 fakeTime,
-		                                                 model_.superOpHelper());
+		    ModelType::modelLinks(),
+		    fakeTime,
+		    model_.superOpHelper());
 		LanczosMatrixType h(model_, hc, aux);
 		RealType E0 = energy_;
-		CorrectionVectorFunctionType cvft(h,tstStruct_,E0);
+		CorrectionVectorFunctionType cvft(h, tstStruct_, E0);
 
-		cvft.getXi(xi,sv);
+		cvft.getXi(xi, sv);
 		// make sure xr is zero
-		for (SizeType i=0;i<xr.size();i++) xr[i] = 0;
-		h.matrixVectorProduct(xr,xi);
-		xr -= (tstStruct_.omega().second+E0)*xi;
+		for (SizeType i = 0; i < xr.size(); i++)
+			xr[i] = 0;
+		h.matrixVectorProduct(xr, xi);
+		xr -= (tstStruct_.omega().second + E0) * xi;
 		xr /= tstStruct_.eta();
 	}
 
 	void computeXiAndXrKrylov(VectorType& xi,
-	                          VectorType& xr,
-	                          const VectorWithOffsetType& phi,
-	                          SizeType i0,
-	                          const MatrixComplexOrRealType& V,
-	                          const MatrixComplexOrRealType& T,
-	                          const VectorRealType& eigs,
-	                          SizeType steps)
+	    VectorType& xr,
+	    const VectorWithOffsetType& phi,
+	    SizeType i0,
+	    const MatrixComplexOrRealType& V,
+	    const MatrixComplexOrRealType& T,
+	    const VectorRealType& eigs,
+	    SizeType steps)
 	{
 		SizeType n2 = steps;
 		SizeType n = V.n_row();
-		if (T.n_col()!=T.n_row()) throw PsimagLite::RuntimeError("T is not square\n");
-		if (V.n_col()!=T.n_col()) throw PsimagLite::RuntimeError("V is not nxn2\n");
+		if (T.n_col() != T.n_row())
+			throw PsimagLite::RuntimeError("T is not square\n");
+		if (V.n_col() != T.n_col())
+			throw PsimagLite::RuntimeError("V is not nxn2\n");
 
 		typename LanczosSolverType::ParametersSolverType params(ioIn_, "Tridiag");
 		bool b1 = (params.options.find("printritz") != PsimagLite::String::npos);
-		if (b1) printRitz(eigs, i0);
+		if (b1)
+			printRitz(eigs, i0);
 
 		ComplexOrRealType zone = 1.0;
 		ComplexOrRealType zzero = 0.0;
@@ -311,59 +322,60 @@ private:
 
 		krylovHelper_.calcR(r, what.imag(), T, V, phi, n2, i0);
 
-		psimag::BLAS::GEMV('N',n2,n2,zone,&(T(0,0)),n2,&(r[0]),1,zzero,&(tmp[0]),1);
+		psimag::BLAS::GEMV('N', n2, n2, zone, &(T(0, 0)), n2, &(r[0]), 1, zzero, &(tmp[0]), 1);
 
 		xi.resize(n);
-		psimag::BLAS::GEMV('N',n,n2,zone,&(V(0,0)),n,&(tmp[0]),1,zzero,&(xi[0]),1);
+		psimag::BLAS::GEMV('N', n, n2, zone, &(V(0, 0)), n, &(tmp[0]), 1, zzero, &(xi[0]), 1);
 
-		if (CalcR::ActionType::isValueComplex()) return;
+		if (CalcR::ActionType::isValueComplex())
+			return;
 
 		krylovHelper_.calcR(r, what.real(), T, V, phi, n2, i0);
 
-		psimag::BLAS::GEMV('N',n2,n2,zone,&(T(0,0)),n2,&(r[0]),1,zzero,&(tmp[0]),1);
+		psimag::BLAS::GEMV('N', n2, n2, zone, &(T(0, 0)), n2, &(r[0]), 1, zzero, &(tmp[0]), 1);
 
 		xr.resize(n);
-		psimag::BLAS::GEMV('N',n,n2,zone,&(V(0,0)),n,&(tmp[0]),1,zzero,&(xr[0]),1);
+		psimag::BLAS::GEMV('N', n, n2, zone, &(V(0, 0)), n, &(tmp[0]), 1, zzero, &(xr[0]), 1);
 	}
 
 	void triDiag(const VectorWithOffsetType& phi,
-	             VectorMatrixFieldType& T,
-	             VectorMatrixFieldType& V,
-	             VectorSizeType& steps)
+	    VectorMatrixFieldType& T,
+	    VectorMatrixFieldType& V,
+	    VectorSizeType& steps)
 	{
 		RealType fakeTime = 0;
 		typedef PsimagLite::NoPthreadsNg<ParallelTriDiagType> ParallelizerType;
 		ParallelizerType threadedTriDiag(PsimagLite::CodeSectionParams(1));
 
 		ParallelTriDiagType helperTriDiag(phi,
-		                                  T,
-		                                  V,
-		                                  steps,
-		                                  lrs_,
-		                                  fakeTime,
-		                                  model_,
-		                                  ioIn_);
+		    T,
+		    V,
+		    steps,
+		    lrs_,
+		    fakeTime,
+		    model_,
+		    ioIn_);
 
 		threadedTriDiag.loopCreate(helperTriDiag);
 	}
 
-	RealType dynWeightOf(VectorType& v,const VectorType& w) const
+	RealType dynWeightOf(VectorType& v, const VectorType& w) const
 	{
 		RealType sum = 0;
-		for (SizeType i=0;i<v.size();i++) {
-			RealType tmp = PsimagLite::real(v[i]*w[i]);
-			sum += tmp*tmp;
+		for (SizeType i = 0; i < v.size(); i++) {
+			RealType tmp = PsimagLite::real(v[i] * w[i]);
+			sum += tmp * tmp;
 		}
 		return sum;
 	}
 
 	static void printRitz(const VectorRealType& eigs, SizeType i0)
 	{
-		std::cout<<"RitzEigenvalues: index="<<i0<<"|";
+		std::cout << "RitzEigenvalues: index=" << i0 << "|";
 		const SizeType n = eigs.size();
 		for (SizeType i = 0; i < n; ++i)
-			std::cout<<eigs[i]<<" ";
-		std::cout<<"\n";
+			std::cout << eigs[i] << " ";
+		std::cout << "\n";
 	}
 
 	InputValidatorType& ioIn_;
@@ -379,4 +391,3 @@ private:
 } // namespace
 /*@}*/
 #endif // CORRECTION_VECTOR_SKEL_H
-
