@@ -79,18 +79,20 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
  */
 #ifndef CORRELATIONS_SK_H
 #define CORRELATIONS_SK_H
-#include "ObserverHelper.h"
-#include "Matrix.h"
-#include "PackIndices.h"
-#include "CrsMatrix.h"
 #include "ApplyOperatorLocal.h"
 #include "Braket.h"
+#include "CrsMatrix.h"
+#include "Matrix.h"
+#include "ObserverHelper.h"
+#include "PackIndices.h"
 #include <numeric>
 
-namespace Dmrg {
+namespace Dmrg
+{
 
-template<typename ObserverHelperType_,typename ModelType>
-class CorrelationsSkeleton {
+template <typename ObserverHelperType_, typename ModelType>
+class CorrelationsSkeleton
+{
 
 public:
 
@@ -98,7 +100,7 @@ public:
 	typedef Braket<ModelType> BraketType;
 	typedef ObserverHelperType_ ObserverHelperType;
 	typedef typename ObserverHelperType::VectorWithOffsetType VectorWithOffsetType;
-	typedef typename VectorWithOffsetType::VectorType VectorType ;
+	typedef typename VectorWithOffsetType::VectorType VectorType;
 	typedef typename ObserverHelperType::BasisWithOperatorsType BasisWithOperatorsType;
 	typedef typename ObserverHelperType::FermionSignType FermionSignType;
 	typedef typename BasisWithOperatorsType::RealType RealType;
@@ -108,13 +110,17 @@ public:
 	typedef typename BasisWithOperatorsType::OperatorType OperatorType;
 	typedef PsimagLite::CrsMatrix<FieldType> SparseMatrixType;
 
-	enum class GrowDirection {RIGHT, LEFT};
+	enum class GrowDirection { RIGHT,
+		LEFT };
 
 	CorrelationsSkeleton(const ObserverHelperType& helper,
-	                     const ModelType& model,
-	                     bool normalizeResult)
-	    : helper_(helper), model_(model), normalizeResult_(normalizeResult)
-	{}
+	    const ModelType& model,
+	    bool normalizeResult)
+	    : helper_(helper)
+	    , model_(model)
+	    , normalizeResult_(normalizeResult)
+	{
+	}
 
 	SizeType numberOfSites() const
 	{
@@ -123,20 +129,21 @@ public:
 
 	//! i can be zero here!!
 	void growDirectly(SparseMatrixType& Odest,
-	                  const SparseMatrixType& Osrc,
-	                  SizeType i,
-	                  ProgramGlobals::FermionOrBosonEnum fermionicSign,
-	                  SizeType ns,
-	                  bool transform) const
+	    const SparseMatrixType& Osrc,
+	    SizeType i,
+	    ProgramGlobals::FermionOrBosonEnum fermionicSign,
+	    SizeType ns,
+	    bool transform) const
 	{
-		Odest =Osrc;
+		Odest = Osrc;
 		// from 0 --> i
-		int nt=i-1;
-		if (nt<0) nt=0;
+		int nt = i - 1;
+		if (nt < 0)
+			nt = 0;
 
 		for (SizeType s = nt; s < ns; ++s) {
 			const GrowDirection growOption = growthDirection(s, nt, i, s);
-			SparseMatrixType Onew(helper_.cols(s),helper_.cols(s));
+			SparseMatrixType Onew(helper_.cols(s), helper_.cols(s));
 
 			fluffUp(Onew, Odest, fermionicSign, growOption, false, s);
 			if (!transform && s == ns - 1) {
@@ -149,22 +156,23 @@ public:
 	}
 
 	GrowDirection growthDirection(SizeType s,
-	                              int nt,
-	                              SizeType i,
-	                              SizeType ptr) const
+	    int nt,
+	    SizeType i,
+	    SizeType ptr) const
 	{
 		const ProgramGlobals::DirectionEnum dir = helper_.direction(ptr);
 		GrowDirection growOption = (dir == ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
-		        ? GrowDirection::RIGHT
-		        : GrowDirection::LEFT;
+		    ? GrowDirection::RIGHT
+		    : GrowDirection::LEFT;
 
-		if (s==SizeType(nt)) {
+		if (s == SizeType(nt)) {
 			growOption = (dir == ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
-			        ? GrowDirection::LEFT
-			        : GrowDirection::RIGHT;
-			if (i==0) growOption = (dir == ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
-			        ? GrowDirection::RIGHT
-			        : GrowDirection::LEFT;
+			    ? GrowDirection::LEFT
+			    : GrowDirection::RIGHT;
+			if (i == 0)
+				growOption = (dir == ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
+				    ? GrowDirection::RIGHT
+				    : GrowDirection::LEFT;
 		}
 
 		return growOption;
@@ -172,42 +180,41 @@ public:
 
 	// Perfomance critical:
 	void fluffUp(SparseMatrixType& ret2,
-	             const SparseMatrixType& O,
-	             ProgramGlobals::FermionOrBosonEnum fOrB,
-	             const GrowDirection growOption,
-	             bool transform,
-	             SizeType ptr) const
+	    const SparseMatrixType& O,
+	    ProgramGlobals::FermionOrBosonEnum fOrB,
+	    const GrowDirection growOption,
+	    bool transform,
+	    SizeType ptr) const
 	{
 		const int fermionicSign = (fOrB == ProgramGlobals::FermionOrBosonEnum::BOSON) ? 1 : -1;
 		const ProgramGlobals::DirectionEnum dir = helper_.direction(ptr);
 
 		const BasisType& basis = (dir == ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
-		        ? helper_.leftRightSuper(ptr).left()
-		        : helper_.leftRightSuper(ptr).right();
+		    ? helper_.leftRightSuper(ptr).left()
+		    : helper_.leftRightSuper(ptr).right();
 
 		SizeType n = basis.size();
 		SizeType orows = O.rows();
-		SizeType ktotal = n/orows;
-		SparseMatrixType ret(n, n, ktotal*O.nonZeros());
+		SizeType ktotal = n / orows;
+		SparseMatrixType ret(n, n, ktotal * O.nonZeros());
 
 		if (growOption == GrowDirection::RIGHT) {
 			RealType sign = (dir == ProgramGlobals::DirectionEnum::EXPAND_ENVIRON)
-			        ? fermionSignBasis(fermionicSign, helper_.leftRightSuper(ptr).left()) :
-			          1;
+			    ? fermionSignBasis(fermionicSign, helper_.leftRightSuper(ptr).left())
+			    : 1;
 
 			SizeType counter = 0;
 			for (SizeType k = 0; k < ktotal; ++k) {
 				for (SizeType i = 0; i < orows; ++i) {
-					ret.setRow(i + k*orows, counter);
+					ret.setRow(i + k * orows, counter);
 					for (int kj = O.getRowPtr(i); kj < O.getRowPtr(i + 1); ++kj) {
 						// Sperm[e0] = i + k*n
 						// Sperm[e1] = j + k*n
 
-						SizeType col = basis.
-						        permutationInverse(O.getCol(kj) + k*orows);
+						SizeType col = basis.permutationInverse(O.getCol(kj) + k * orows);
 
 						ret.setCol(counter, col);
-						ret.setValues(counter++, O.getValue(kj)*sign);
+						ret.setValues(counter++, O.getValue(kj) * sign);
 					}
 				}
 			}
@@ -219,13 +226,14 @@ public:
 			SizeType counter = 0;
 			for (SizeType i = 0; i < orows; ++i) {
 				for (SizeType k = 0; k < ktotal; ++k) {
-					ret.setRow(k + i*ktotal, counter);
+					ret.setRow(k + i * ktotal, counter);
 					RealType sign = 1;
 					if (dir == ProgramGlobals::DirectionEnum::EXPAND_ENVIRON) {
 						sign = (fOrB == ProgramGlobals::FermionOrBosonEnum::BOSON)
-						        ? 1 : fermionSignBasis(fermionicSign,
-						                               helper_.leftRightSuper(ptr).left())*
-						          helper_.signsOneSite(k);
+						    ? 1
+						    : fermionSignBasis(fermionicSign,
+							  helper_.leftRightSuper(ptr).left())
+							* helper_.signsOneSite(k);
 					} else {
 						sign = helper_.fermionicSignLeft(ptr)(k, fermionicSign);
 					}
@@ -234,11 +242,10 @@ public:
 						// Sperm[e0] = k + i*m
 						// Sperm[e1] = k + j*m
 
-						SizeType col = basis.
-						        permutationInverse(k + O.getCol(kj)*ktotal);
+						SizeType col = basis.permutationInverse(k + O.getCol(kj) * ktotal);
 
 						ret.setCol(counter, col);
-						ret.setValues(counter++, O.getValue(kj)*sign);
+						ret.setValues(counter++, O.getValue(kj) * sign);
 					}
 				}
 			}
@@ -257,10 +264,10 @@ public:
 	}
 
 	SizeType dmrgMultiply(SparseMatrixType& result,
-	                      const SparseMatrixType& O1,
-	                      const SparseMatrixType& O2,
-	                      ProgramGlobals::FermionOrBosonEnum fermionicSign,
-	                      SizeType ns) const
+	    const SparseMatrixType& O1,
+	    const SparseMatrixType& O2,
+	    ProgramGlobals::FermionOrBosonEnum fermionicSign,
+	    SizeType ns) const
 	{
 		SizeType ptr = (ns == 0) ? ns : ns - 1;
 		if (helper_.direction(ptr) == ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
@@ -269,30 +276,29 @@ public:
 			dmrgMultiplyEnviron(result, ptr, O1, O2, fermionicSign, ns);
 
 		return ptr;
-
 	}
 
-	static void createWithModification(SparseMatrixType& Om,const SparseMatrixType& O,char mod)
+	static void createWithModification(SparseMatrixType& Om, const SparseMatrixType& O, char mod)
 	{
 		if (mod == 'n' || mod == 'N') {
 			Om = O;
 			return;
 		}
 
-		transposeConjugate(Om,O);
+		transposeConjugate(Om, O);
 	}
 
 	FieldType bracket(const SparseMatrixType& A,
-	                  ProgramGlobals::FermionOrBosonEnum fermionicSign,
-	                  SizeType ptr,
-	                  const PsimagLite::GetBraOrKet& bra,
-	                  const PsimagLite::GetBraOrKet& ket) const
+	    ProgramGlobals::FermionOrBosonEnum fermionicSign,
+	    SizeType ptr,
+	    const PsimagLite::GetBraOrKet& bra,
+	    const PsimagLite::GetBraOrKet& ket) const
 	{
-		//try {
-			const VectorWithOffsetType& src1 = helper_.getVectorFromBracketId(bra, ptr);
-			const VectorWithOffsetType& src2 = helper_.getVectorFromBracketId(ket, ptr);
+		// try {
+		const VectorWithOffsetType& src1 = helper_.getVectorFromBracketId(bra, ptr);
+		const VectorWithOffsetType& src2 = helper_.getVectorFromBracketId(ket, ptr);
 
-			return bracket_(A,src1,src2,fermionicSign,ptr);
+		return bracket_(A, src1, src2, fermionicSign, ptr);
 		/*} catch (std::exception& e) {
 			std::cerr<<"CAUGHT: "<<e.what();
 			std::cerr<<"WARNING: CorrelationsSkeleton::bracket(...):";
@@ -302,40 +308,40 @@ public:
 	}
 
 	FieldType bracketRightCorner(const SparseMatrixType& A,
-	                             const SparseMatrixType& B,
-	                             ProgramGlobals::FermionOrBosonEnum fermionSign,
-	                             SizeType ptr,
-	                             const PsimagLite::GetBraOrKet& bra,
-	                             const PsimagLite::GetBraOrKet& ket) const
+	    const SparseMatrixType& B,
+	    ProgramGlobals::FermionOrBosonEnum fermionSign,
+	    SizeType ptr,
+	    const PsimagLite::GetBraOrKet& bra,
+	    const PsimagLite::GetBraOrKet& ket) const
 	{
 		try {
 			const VectorWithOffsetType& src1 = helper_.getVectorFromBracketId(bra, ptr);
 			const VectorWithOffsetType& src2 = helper_.getVectorFromBracketId(ket, ptr);
-			return bracketRightCorner_(A,B,fermionSign,src1,src2,ptr);
+			return bracketRightCorner_(A, B, fermionSign, src1, src2, ptr);
 		} catch (std::exception& e) {
-			std::cerr<<"CAUGHT: "<<e.what();
-			std::cerr<<"WARNING: CorrelationsSkeleton::bracketRightCorner(...):";
-			std::cerr<<" No data seen yet\n";
+			std::cerr << "CAUGHT: " << e.what();
+			std::cerr << "WARNING: CorrelationsSkeleton::bracketRightCorner(...):";
+			std::cerr << " No data seen yet\n";
 			return 0;
 		}
 	}
 
 	FieldType bracketRightCorner(const SparseMatrixType& A,
-	                             const SparseMatrixType& B,
-	                             const SparseMatrixType& C,
-	                             ProgramGlobals::FermionOrBosonEnum fermionSign,
-	                             SizeType ptr,
-	                             const PsimagLite::GetBraOrKet& bra,
-	                             const PsimagLite::GetBraOrKet& ket) const
+	    const SparseMatrixType& B,
+	    const SparseMatrixType& C,
+	    ProgramGlobals::FermionOrBosonEnum fermionSign,
+	    SizeType ptr,
+	    const PsimagLite::GetBraOrKet& bra,
+	    const PsimagLite::GetBraOrKet& ket) const
 	{
 		try {
 			const VectorWithOffsetType& src1 = helper_.getVectorFromBracketId(bra, ptr);
 			const VectorWithOffsetType& src2 = helper_.getVectorFromBracketId(ket, ptr);
-			return bracketRightCorner_(A,B,C,fermionSign,src1,src2,ptr);
+			return bracketRightCorner_(A, B, C, fermionSign, src1, src2, ptr);
 		} catch (std::exception& e) {
-			std::cerr<<"CAUGHT: "<<e.what();
-			std::cerr<<"WARNING: CorrelationsSkeleton::bracketRightCornerABC(...):";
-			std::cerr<<" No data seen yet\n";
+			std::cerr << "CAUGHT: " << e.what();
+			std::cerr << "WARNING: CorrelationsSkeleton::bracketRightCornerABC(...):";
+			std::cerr << " No data seen yet\n";
 			return 0;
 		}
 	}
@@ -348,7 +354,8 @@ private:
 	{
 		const typename BasisWithOperatorsType::VectorBoolType& v = basis.signs();
 		SizeType n = v.size();
-		if (n == 0) return 1;
+		if (n == 0)
+			return 1;
 		bool nx0 = v[0];
 		for (SizeType i = 1; i < n; ++i)
 			nx0 ^= v[i];
@@ -356,49 +363,49 @@ private:
 	}
 
 	void dmrgMultiplySystem(SparseMatrixType& result,
-	                        SizeType& ptr,
-	                        const SparseMatrixType& O1,
-	                        const SparseMatrixType& O2,
-	                        ProgramGlobals::FermionOrBosonEnum fOrB, // for O2
-	                        SizeType ns) const
+	    SizeType& ptr,
+	    const SparseMatrixType& O1,
+	    const SparseMatrixType& O2,
+	    ProgramGlobals::FermionOrBosonEnum fOrB, // for O2
+	    SizeType ns) const
 	{
 		const int fermionicSign = (fOrB == ProgramGlobals::FermionOrBosonEnum::BOSON) ? 1 : -1;
-		SizeType ni=O1.rows();
+		SizeType ni = O1.rows();
 
 		ptr = ns;
-		SizeType sprime = helper_.leftRightSuper(ptr).left().size(); //ni*nj;
-		result.resize(sprime,sprime);
+		SizeType sprime = helper_.leftRightSuper(ptr).left().size(); // ni*nj;
+		result.resize(sprime, sprime);
 
-		if (helper_.leftRightSuper(ptr).left().size()!=sprime) {
-			std::cerr<<"WARNING: "<<helper_.leftRightSuper(ptr).left().size();
-			std::cerr<<"!="<<sprime<<"\n";
+		if (helper_.leftRightSuper(ptr).left().size() != sprime) {
+			std::cerr << "WARNING: " << helper_.leftRightSuper(ptr).left().size();
+			std::cerr << "!=" << sprime << "\n";
 			err("problem in dmrgMultiply\n");
 		}
 
-		PsimagLite::Vector<SizeType>::Type col(sprime,0);
+		PsimagLite::Vector<SizeType>::Type col(sprime, 0);
 		typename PsimagLite::Vector<FieldType>::Type value(sprime, 0);
 
 		PackIndicesType pack(ni);
 
 		SizeType counter = 0;
-		for (SizeType r=0;r<sprime;r++) {
-			SizeType e,u;
-			pack.unpack(e,u,helper_.leftRightSuper(ptr).left().permutation(r));
-			RealType f = helper_.fermionicSignLeft(ptr)(e,fermionicSign);
-			result.setRow(r,counter);
-			for (int k=O1.getRowPtr(e);k<O1.getRowPtr(e+1);k++) {
+		for (SizeType r = 0; r < sprime; r++) {
+			SizeType e, u;
+			pack.unpack(e, u, helper_.leftRightSuper(ptr).left().permutation(r));
+			RealType f = helper_.fermionicSignLeft(ptr)(e, fermionicSign);
+			result.setRow(r, counter);
+			for (int k = O1.getRowPtr(e); k < O1.getRowPtr(e + 1); k++) {
 				SizeType e2 = O1.getCol(k);
-				for (int k2=O2.getRowPtr(u);k2<O2.getRowPtr(u+1);k2++) {
+				for (int k2 = O2.getRowPtr(u); k2 < O2.getRowPtr(u + 1); k2++) {
 					SizeType u2 = O2.getCol(k2);
-					SizeType r2 = helper_.leftRightSuper(ptr).left().
-					        permutationInverse(e2 + u2*ni);
-					value[r2] += O1.getValue(k)*O2.getValue(k2)*f;
+					SizeType r2 = helper_.leftRightSuper(ptr).left().permutationInverse(e2 + u2 * ni);
+					value[r2] += O1.getValue(k) * O2.getValue(k2) * f;
 					col[r2] = 1;
 				}
 			}
 
-			for (SizeType i=0;i<col.size();i++) {
-				if (col[i]==0) continue;
+			for (SizeType i = 0; i < col.size(); i++) {
+				if (col[i] == 0)
+					continue;
 				result.pushCol(i);
 				result.pushValue(value[i]);
 				counter++;
@@ -407,61 +414,62 @@ private:
 			}
 		}
 
-		result.setRow(result.rows(),counter);
+		result.setRow(result.rows(), counter);
 		result.checkValidity();
 	}
 
 	void dmrgMultiplyEnviron(SparseMatrixType& result,
-	                         SizeType& ptr,
-	                         const SparseMatrixType& O1,
-	                         const SparseMatrixType& O2,
-	                         ProgramGlobals::FermionOrBosonEnum fermionicSign,
-	                         SizeType ns) const
+	    SizeType& ptr,
+	    const SparseMatrixType& O1,
+	    const SparseMatrixType& O2,
+	    ProgramGlobals::FermionOrBosonEnum fermionicSign,
+	    SizeType ns) const
 	{
 		int fs = (fermionicSign == ProgramGlobals::FermionOrBosonEnum::BOSON) ? 1 : -1;
 		RealType f = fermionSignBasis(fs,
-		                              helper_.leftRightSuper(ptr).left());
-		SizeType nj=O2.rows();
+		    helper_.leftRightSuper(ptr).left());
+		SizeType nj = O2.rows();
 
 		ptr = ns;
-		SizeType eprime = helper_.leftRightSuper(ptr).right().size(); //ni*nj;
-		result.resize(eprime,eprime);
+		SizeType eprime = helper_.leftRightSuper(ptr).right().size(); // ni*nj;
+		result.resize(eprime, eprime);
 
-		if (helper_.leftRightSuper(ptr).right().size()!=eprime) {
-			std::cerr<<"WARNING: "<<helper_.leftRightSuper(ptr).right().size();
-			std::cerr<<"!="<<eprime<<"\n";
+		if (helper_.leftRightSuper(ptr).right().size() != eprime) {
+			std::cerr << "WARNING: " << helper_.leftRightSuper(ptr).right().size();
+			std::cerr << "!=" << eprime << "\n";
 			throw PsimagLite::RuntimeError("problem in dmrgMultiply\n");
 		}
 
-		PsimagLite::Vector<SizeType>::Type col(eprime,0);
-		typename PsimagLite::Vector<FieldType>::Type value(eprime,0);
+		PsimagLite::Vector<SizeType>::Type col(eprime, 0);
+		typename PsimagLite::Vector<FieldType>::Type value(eprime, 0);
 
 		PackIndicesType pack(nj);
 
 		SizeType counter = 0;
-		for (SizeType r=0;r<eprime;r++) {
-			result.setRow(r,counter);
+		for (SizeType r = 0; r < eprime; r++) {
+			result.setRow(r, counter);
 			SizeType e = 0;
 			SizeType u = 0;
-			pack.unpack(e,u,helper_.leftRightSuper(ptr).right().permutation(r));
+			pack.unpack(e, u, helper_.leftRightSuper(ptr).right().permutation(r));
 			const RealType sign = (fermionicSign == ProgramGlobals::FermionOrBosonEnum::BOSON)
-			        ? 1 : f*helper_.signsOneSite(e);
+			    ? 1
+			    : f * helper_.signsOneSite(e);
 
-			for (int k=O2.getRowPtr(e);k<O2.getRowPtr(e+1);k++) {
+			for (int k = O2.getRowPtr(e); k < O2.getRowPtr(e + 1); k++) {
 				SizeType e2 = O2.getCol(k);
 
-				for (int k2=O1.getRowPtr(u);k2<O1.getRowPtr(u+1);k2++) {
+				for (int k2 = O1.getRowPtr(u); k2 < O1.getRowPtr(u + 1); k2++) {
 					SizeType u2 = O1.getCol(k2);
-					SizeType r2 = helper_.leftRightSuper(ptr).right().
-					        permutationInverse(e2 + u2*nj);
-					assert(r2<eprime);
+					SizeType r2 = helper_.leftRightSuper(ptr).right().permutationInverse(e2 + u2 * nj);
+					assert(r2 < eprime);
 					col[r2] = 1;
-					value[r2] += O2.getValue(k)*O1.getValue(k2)*sign;
+					value[r2] += O2.getValue(k) * O1.getValue(k2) * sign;
 				}
 			}
 
-			for (SizeType i=0;i<col.size();i++) {
-				if (col[i]==0) continue;
+			for (SizeType i = 0; i < col.size(); i++) {
+				if (col[i] == 0)
+					continue;
 				result.pushCol(i);
 				result.pushValue(value[i]);
 				counter++;
@@ -470,7 +478,7 @@ private:
 			}
 		}
 
-		result.setRow(result.rows(),counter);
+		result.setRow(result.rows(), counter);
 		result.checkValidity();
 	}
 
@@ -498,122 +506,113 @@ private:
 	}
 
 	FieldType bracket_(const SparseMatrixType& A,
-	                   const VectorWithOffsetType& vec1,
-	                   const VectorWithOffsetType& vec2,
-	                   ProgramGlobals::FermionOrBosonEnum fermionicSign,
-	                   SizeType ptr) const
+	    const VectorWithOffsetType& vec1,
+	    const VectorWithOffsetType& vec2,
+	    ProgramGlobals::FermionOrBosonEnum fermionicSign,
+	    SizeType ptr) const
 	{
-		if (vec1.size()!=helper_.leftRightSuper(ptr).super().size() ||
-		        vec1.size()!=vec2.size())
+		if (vec1.size() != helper_.leftRightSuper(ptr).super().size() || vec1.size() != vec2.size())
 			err("CorrelationsSkeleton::bracket_(...): Error\n");
 
 		return (helper_.direction(ptr) == ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
-		        ? bracketSystem_(A,vec1,vec2,ptr)
-		        : bracketEnviron_(A,vec1,vec2,fermionicSign,ptr);
+		    ? bracketSystem_(A, vec1, vec2, ptr)
+		    : bracketEnviron_(A, vec1, vec2, fermionicSign, ptr);
 	}
 
 	FieldType bracketSystem_(const SparseMatrixType& A,
-	                         const VectorWithOffsetType& vec1,
-	                         const VectorWithOffsetType& vec2,
-	                         SizeType ptr) const
+	    const VectorWithOffsetType& vec1,
+	    const VectorWithOffsetType& vec2,
+	    SizeType ptr) const
 	{
-		FieldType sum=0;
+		FieldType sum = 0;
 		PackIndicesType pack(helper_.leftRightSuper(ptr).left().size());
-		for (SizeType x=0;x<vec1.sectors();x++) {
+		for (SizeType x = 0; x < vec1.sectors(); x++) {
 			SizeType sector = vec1.sector(x);
 			SizeType offset = vec1.offset(sector);
 			SizeType total = offset + vec1.effectiveSize(sector);
-			for (SizeType t=offset;t<total;t++) {
-				SizeType eta,r;
+			for (SizeType t = offset; t < total; t++) {
+				SizeType eta, r;
 
-				pack.unpack(r,eta,helper_.leftRightSuper(ptr).super().
-				            permutation(t));
-				for (int k=A.getRowPtr(r);k<A.getRowPtr(r+1);k++) {
+				pack.unpack(r, eta, helper_.leftRightSuper(ptr).super().permutation(t));
+				for (int k = A.getRowPtr(r); k < A.getRowPtr(r + 1); k++) {
 					SizeType r2 = A.getCol(k);
-					SizeType t2 = helper_.leftRightSuper(ptr).super().
-					        permutationInverse(r2+eta*A.cols());
-					sum += A.getValue(k)*PsimagLite::conj(vec1.fastAccess(sector, t - offset))*
-					        vec2.slowAccess(t2);
+					SizeType t2 = helper_.leftRightSuper(ptr).super().permutationInverse(r2 + eta * A.cols());
+					sum += A.getValue(k) * PsimagLite::conj(vec1.fastAccess(sector, t - offset)) * vec2.slowAccess(t2);
 				}
 			}
 		}
 
-		return resultDivided(sum,vec1);
+		return resultDivided(sum, vec1);
 	}
 
 	FieldType bracketEnviron_(const SparseMatrixType& A,
-	                          const VectorWithOffsetType& vec1,
-	                          const VectorWithOffsetType& vec2,
-	                          ProgramGlobals::FermionOrBosonEnum fOrB,
-	                          SizeType ptr) const
+	    const VectorWithOffsetType& vec1,
+	    const VectorWithOffsetType& vec2,
+	    ProgramGlobals::FermionOrBosonEnum fOrB,
+	    SizeType ptr) const
 	{
 		const int fermionicSign = (fOrB == ProgramGlobals::FermionOrBosonEnum::BOSON) ? 1 : -1;
 
 		RealType sign = fermionSignBasis(fermionicSign,
-		                                 helper_.leftRightSuper(ptr).left());
+		    helper_.leftRightSuper(ptr).left());
 
-		FieldType sum=0;
+		FieldType sum = 0;
 		PackIndicesType pack(helper_.leftRightSuper(ptr).left().size());
 		SizeType leftSize = helper_.leftRightSuper(ptr).left().size();
 
-		for (SizeType x=0;x<vec1.sectors();x++) {
+		for (SizeType x = 0; x < vec1.sectors(); x++) {
 			SizeType sector = vec1.sector(x);
 			SizeType offset = vec1.offset(sector);
 			SizeType total = offset + vec1.effectiveSize(sector);
-			for (SizeType t=offset;t<total;t++) {
-				SizeType eta,r;
+			for (SizeType t = offset; t < total; t++) {
+				SizeType eta, r;
 
-				pack.unpack(r,eta,helper_.leftRightSuper(ptr).super().
-				            permutation(t));
+				pack.unpack(r, eta, helper_.leftRightSuper(ptr).super().permutation(t));
 
-				for (int k=A.getRowPtr(eta);k<A.getRowPtr(eta+1);k++) {
+				for (int k = A.getRowPtr(eta); k < A.getRowPtr(eta + 1); k++) {
 					SizeType eta2 = A.getCol(k);
-					SizeType t2 = helper_.leftRightSuper(ptr).super().
-					        permutationInverse(r+eta2*leftSize);
-					sum += A.getValue(k)*PsimagLite::conj(vec1.fastAccess(sector, t - offset))*
-					        vec2.slowAccess(t2)*sign;
+					SizeType t2 = helper_.leftRightSuper(ptr).super().permutationInverse(r + eta2 * leftSize);
+					sum += A.getValue(k) * PsimagLite::conj(vec1.fastAccess(sector, t - offset)) * vec2.slowAccess(t2) * sign;
 				}
 			}
 		}
 
-		return resultDivided(sum,vec1);
+		return resultDivided(sum, vec1);
 	}
 
 	FieldType bracketRightCorner_(const SparseMatrixType& A,
-	                              const SparseMatrixType& B,
-	                              ProgramGlobals::FermionOrBosonEnum fermionSign,
-	                              const VectorWithOffsetType& vec1,
-	                              const VectorWithOffsetType& vec2,
-	                              SizeType ptr) const
+	    const SparseMatrixType& B,
+	    ProgramGlobals::FermionOrBosonEnum fermionSign,
+	    const VectorWithOffsetType& vec1,
+	    const VectorWithOffsetType& vec2,
+	    SizeType ptr) const
 	{
 		return (helper_.direction(ptr) == ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
-		        ? brRghtCrnrSystem_(A,B,fermionSign,vec1,vec2,ptr)
-		        : brLftCrnrEnviron_(A,B,fermionSign,vec1,vec2,ptr);
+		    ? brRghtCrnrSystem_(A, B, fermionSign, vec1, vec2, ptr)
+		    : brLftCrnrEnviron_(A, B, fermionSign, vec1, vec2, ptr);
 	}
 
 	bool superOddElectrons(SizeType t, SizeType ptr) const
 	{
 		// return helper_.leftRightSuper(ptr).super().electrons(t);
 		SizeType tmp = helper_.leftRightSuper(ptr).super().permutation(t);
-		div_t mydiv = PsimagLite::div(tmp,helper_.leftRightSuper(ptr).left().size());
-		return helper_.leftRightSuper(ptr).right().signs()[mydiv.quot] ^
-		        helper_.leftRightSuper(ptr).left().signs()[mydiv.rem];
+		div_t mydiv = PsimagLite::div(tmp, helper_.leftRightSuper(ptr).left().size());
+		return helper_.leftRightSuper(ptr).right().signs()[mydiv.quot] ^ helper_.leftRightSuper(ptr).left().signs()[mydiv.rem];
 	}
 
 	FieldType brRghtCrnrSystem_(const SparseMatrixType& Acrs,
-	                            const SparseMatrixType& Bcrs,
-	                            ProgramGlobals::FermionOrBosonEnum fermionSign,
-	                            const VectorWithOffsetType& vec1,
-	                            const VectorWithOffsetType& vec2,
-	                            SizeType ptr) const
+	    const SparseMatrixType& Bcrs,
+	    ProgramGlobals::FermionOrBosonEnum fermionSign,
+	    const VectorWithOffsetType& vec1,
+	    const VectorWithOffsetType& vec2,
+	    SizeType ptr) const
 	{
 		FieldType sum = 0;
 		SizeType leftSize = helper_.leftRightSuper(ptr).left().size();
 		SizeType ni = helper_.leftRightSuper(ptr).left().size();
 
 		// some sanity checks:
-		if (vec1.size() != vec2.size() ||
-		        vec1.size() != helper_.leftRightSuper(ptr).super().size())
+		if (vec1.size() != vec2.size() || vec1.size() != helper_.leftRightSuper(ptr).super().size())
 			err("Observe::brRghtCrnrSystem_(...)\n");
 
 		if (ni != Acrs.rows())
@@ -621,107 +620,99 @@ private:
 
 		// ok, we're ready for the main course:
 		PackIndicesType pack1(helper_.leftRightSuper(ptr).left().size());
-		for (SizeType x=0;x<vec1.sectors();x++) {
+		for (SizeType x = 0; x < vec1.sectors(); x++) {
 			SizeType sector = vec1.sector(x);
 			SizeType offset = vec1.offset(sector);
 			SizeType total = offset + vec1.effectiveSize(sector);
-			for (SizeType t=offset;t<total;t++) {
-				SizeType eta,r;
+			for (SizeType t = offset; t < total; t++) {
+				SizeType eta, r;
 
-				pack1.unpack(r,eta,helper_.leftRightSuper(ptr).super().
-				             permutation(t));
+				pack1.unpack(r, eta, helper_.leftRightSuper(ptr).super().permutation(t));
 
-				bool odd = superOddElectrons(t,ptr);
+				bool odd = superOddElectrons(t, ptr);
 				odd ^= helper_.leftRightSuper(ptr).right().signs()[eta];
-				const RealType sign = (odd && fermionSign ==
-				                       ProgramGlobals::FermionOrBosonEnum::FERMION) ? -1.0
-				                                                                    : 1.0;
+				const RealType sign = (odd && fermionSign == ProgramGlobals::FermionOrBosonEnum::FERMION) ? -1.0
+															  : 1.0;
 
-				for (int k=Acrs.getRowPtr(r);k<Acrs.getRowPtr(r+1);k++) {
+				for (int k = Acrs.getRowPtr(r); k < Acrs.getRowPtr(r + 1); k++) {
 					SizeType rprime = Acrs.getCol(k);
 					for (int k2 = Bcrs.getRowPtr(eta);
-					     k2<Bcrs.getRowPtr(eta+1);k2++) {
+					     k2 < Bcrs.getRowPtr(eta + 1);
+					     k2++) {
 						SizeType eta2 = Bcrs.getCol(k2);
 
-						SizeType t2 = helper_.leftRightSuper(ptr).super().
-						        permutationInverse(rprime+eta2*leftSize);
-						sum += Acrs.getValue(k)*Bcrs.getValue(k2)*
-						        PsimagLite::conj(vec1.fastAccess(sector, t - offset))*
-						        vec2.slowAccess(t2)*sign;
+						SizeType t2 = helper_.leftRightSuper(ptr).super().permutationInverse(rprime + eta2 * leftSize);
+						sum += Acrs.getValue(k) * Bcrs.getValue(k2) * PsimagLite::conj(vec1.fastAccess(sector, t - offset)) * vec2.slowAccess(t2) * sign;
 					}
 				}
 			}
 		}
 
-		return resultDivided(sum,vec1);
+		return resultDivided(sum, vec1);
 	}
 
 	FieldType brLftCrnrEnviron_(const SparseMatrixType& Acrs,
-	                            const SparseMatrixType& Bcrs,
-	                            ProgramGlobals::FermionOrBosonEnum fOrB,
-	                            const VectorWithOffsetType& vec1,
-	                            const VectorWithOffsetType& vec2,
-	                            SizeType ptr) const
+	    const SparseMatrixType& Bcrs,
+	    ProgramGlobals::FermionOrBosonEnum fOrB,
+	    const VectorWithOffsetType& vec1,
+	    const VectorWithOffsetType& vec2,
+	    SizeType ptr) const
 	{
 		const int fermionSign = (fOrB == ProgramGlobals::FermionOrBosonEnum::BOSON) ? 1 : -1;
 		int signRight = fermionSignBasis(fermionSign,
-		                                 helper_.leftRightSuper(ptr).right());
+		    helper_.leftRightSuper(ptr).right());
 		FieldType sum = 0;
 		SizeType ni = Bcrs.rows();
 		SizeType leftSize = helper_.leftRightSuper(ptr).left().size();
 
 		// some sanity checks:
-		if (vec1.size() != vec2.size() ||
-		        vec1.size()!=helper_.leftRightSuper(ptr).super().size())
+		if (vec1.size() != vec2.size() || vec1.size() != helper_.leftRightSuper(ptr).super().size())
 			err("Observe::brLftCrnrEnviron_(...)\n");
-		if (helper_.leftRightSuper(ptr).right().size()/Bcrs.rows() != Acrs.rows())
+		if (helper_.leftRightSuper(ptr).right().size() / Bcrs.rows() != Acrs.rows())
 			err("Observe::brLftCrnrEnviron_(...)\n");
 
 		// ok, we're ready for the main course:
 		PackIndicesType pack1(helper_.leftRightSuper(ptr).left().size());
 		PackIndicesType pack2(ni);
 
-		for (SizeType x=0;x<vec1.sectors();x++) {
+		for (SizeType x = 0; x < vec1.sectors(); x++) {
 			SizeType sector = vec1.sector(x);
 			SizeType offset = vec1.offset(sector);
 			SizeType total = offset + vec1.effectiveSize(sector);
-			for (SizeType t=offset;t<total;t++) {
-				SizeType eta,r;
+			for (SizeType t = offset; t < total; t++) {
+				SizeType eta, r;
 
-				pack1.unpack(eta,r,helper_.leftRightSuper(ptr).super().
-				             permutation(t));
-				SizeType r0,r1;
-				pack2.unpack(r0,r1,helper_.leftRightSuper(ptr).right().permutation(r));
+				pack1.unpack(eta, r, helper_.leftRightSuper(ptr).super().permutation(t));
+				SizeType r0, r1;
+				pack2.unpack(r0, r1, helper_.leftRightSuper(ptr).right().permutation(r));
 				const RealType sign = (fOrB == ProgramGlobals::FermionOrBosonEnum::BOSON)
-				        ? 1 : helper_.signsOneSite(r0) * signRight;
+				    ? 1
+				    : helper_.signsOneSite(r0) * signRight;
 
-				for (int k=Acrs.getRowPtr(r1);k<Acrs.getRowPtr(r1+1);k++) {
+				for (int k = Acrs.getRowPtr(r1); k < Acrs.getRowPtr(r1 + 1); k++) {
 					SizeType r1prime = Acrs.getCol(k);
 					for (int k2 = Bcrs.getRowPtr(eta);
-					     k2<Bcrs.getRowPtr(eta+1);k2++) {
+					     k2 < Bcrs.getRowPtr(eta + 1);
+					     k2++) {
 						SizeType eta2 = Bcrs.getCol(k2);
-						SizeType rprime = helper_.leftRightSuper(ptr).right().
-						        permutationInverse(r0+r1prime*ni);
-						SizeType t2 = helper_.leftRightSuper(ptr).super().
-						        permutationInverse(eta2+rprime*leftSize);
-						sum += PsimagLite::conj(Acrs.getValue(k))*Bcrs.getValue(k2)*
-						        PsimagLite::conj(vec1.fastAccess(sector, t - offset))*
-						        vec2.slowAccess(t2)*sign;
+						SizeType rprime = helper_.leftRightSuper(ptr).right().permutationInverse(r0 + r1prime * ni);
+						SizeType t2 = helper_.leftRightSuper(ptr).super().permutationInverse(eta2 + rprime * leftSize);
+						sum += PsimagLite::conj(Acrs.getValue(k)) * Bcrs.getValue(k2) * PsimagLite::conj(vec1.fastAccess(sector, t - offset)) * vec2.slowAccess(t2) * sign;
 					}
 				}
 			}
 		}
 
-		return resultDivided(sum,vec1);
+		return resultDivided(sum, vec1);
 	}
 
 	FieldType bracketRightCorner_(const SparseMatrixType& A1,
-	                              const SparseMatrixType& A2,
-	                              const SparseMatrixType& B,
-	                              ProgramGlobals::FermionOrBosonEnum fOrB,
-	                              const VectorWithOffsetType& vec1,
-	                              const VectorWithOffsetType& vec2,
-	                              SizeType ptr) const
+	    const SparseMatrixType& A2,
+	    const SparseMatrixType& B,
+	    ProgramGlobals::FermionOrBosonEnum fOrB,
+	    const VectorWithOffsetType& vec1,
+	    const VectorWithOffsetType& vec2,
+	    SizeType ptr) const
 	{
 		if (helper_.direction(ptr) != ProgramGlobals::DirectionEnum::EXPAND_SYSTEM)
 			return 0;
@@ -737,78 +728,74 @@ private:
 		SparseMatrixType A1crs(A1);
 		SparseMatrixType A2crs(A2);
 		SparseMatrixType Bcrs(B);
-		FieldType sum=0;
-		SizeType ni = helper_.leftRightSuper(ptr).left().size()/A2crs.rows();
+		FieldType sum = 0;
+		SizeType ni = helper_.leftRightSuper(ptr).left().size() / A2crs.rows();
 		SizeType leftSize = helper_.leftRightSuper(ptr).left().size();
 
 		// some sanity checks:
-		assert(vec1.size()==vec2.size());
+		assert(vec1.size() == vec2.size());
 
-		if (vec1.size()==0) return 0;
+		if (vec1.size() == 0)
+			return 0;
 
-		assert(vec1.size()==helper_.leftRightSuper(ptr).super().size());
-		assert(ni==A1crs.rows());
+		assert(vec1.size() == helper_.leftRightSuper(ptr).super().size());
+		assert(ni == A1crs.rows());
 
 		// ok, we're ready for the main course:
 		PackIndicesType pack1(helper_.leftRightSuper(ptr).left().size());
 		PackIndicesType pack2(ni);
 
-		for (SizeType x=0;x<vec1.sectors();x++) {
+		for (SizeType x = 0; x < vec1.sectors(); x++) {
 			SizeType sector = vec1.sector(x);
 			SizeType offset = vec1.offset(sector);
 			SizeType total = offset + vec1.effectiveSize(sector);
-			for (SizeType t=offset;t<total;t++) {
-				SizeType eta,r;
+			for (SizeType t = offset; t < total; t++) {
+				SizeType eta, r;
 
 				pack1.unpack(r,
-				             eta,
-				             helper_.leftRightSuper(ptr).super().permutation(t));
-				SizeType r0,r1;
+				    eta,
+				    helper_.leftRightSuper(ptr).super().permutation(t));
+				SizeType r0, r1;
 				pack2.unpack(r0,
-				             r1,
-				             helper_.leftRightSuper(ptr).left().permutation(r));
+				    r1,
+				    helper_.leftRightSuper(ptr).left().permutation(r));
 				assert(r1 < oddElectrons.size());
 				RealType sign = (oddElectrons[r1]) ? fermionSign : 1;
 
-				for (int k1=A1crs.getRowPtr(r0);k1<A1crs.getRowPtr(r0+1);k1++) {
+				for (int k1 = A1crs.getRowPtr(r0); k1 < A1crs.getRowPtr(r0 + 1); k1++) {
 					SizeType r0prime = A1crs.getCol(k1);
-					for (int k2=A2crs.getRowPtr(r1);k2<A2crs.getRowPtr(r1+1);k2++) {
+					for (int k2 = A2crs.getRowPtr(r1); k2 < A2crs.getRowPtr(r1 + 1); k2++) {
 						SizeType r1prime = A2crs.getCol(k2);
-						for (int k3 = Bcrs.getRowPtr(eta);k3<Bcrs.getRowPtr(eta+1);k3++) {
+						for (int k3 = Bcrs.getRowPtr(eta); k3 < Bcrs.getRowPtr(eta + 1); k3++) {
 							SizeType eta2 = Bcrs.getCol(k3);
-							SizeType rprime = helper_.leftRightSuper(ptr).left().
-							        permutationInverse(r0prime+r1prime*ni);
-							SizeType t2 = helper_.leftRightSuper(ptr).super().
-							        permutationInverse(rprime+eta2*leftSize);
-							sum +=  A1crs.getValue(k1)*A2crs.getValue(k2)*
-							        Bcrs.getValue(k3)*
-							        PsimagLite::conj(vec1.fastAccess(sector, t - offset))*
-							        vec2.slowAccess(t2)*sign;
+							SizeType rprime = helper_.leftRightSuper(ptr).left().permutationInverse(r0prime + r1prime * ni);
+							SizeType t2 = helper_.leftRightSuper(ptr).super().permutationInverse(rprime + eta2 * leftSize);
+							sum += A1crs.getValue(k1) * A2crs.getValue(k2) * Bcrs.getValue(k3) * PsimagLite::conj(vec1.fastAccess(sector, t - offset)) * vec2.slowAccess(t2) * sign;
 						}
 					}
 				}
 			}
 		}
 
-		return resultDivided(sum,vec1);
+		return resultDivided(sum, vec1);
 	}
 
 	FieldType resultDivided(FieldType sum, const VectorWithOffsetType& vec) const
 	{
-		if (!normalizeResult_) return sum;
+		if (!normalizeResult_)
+			return sum;
 
-		FieldType tmp = vec*vec;
+		FieldType tmp = vec * vec;
 		RealType norma2 = PsimagLite::real(tmp);
-		assert(fabs(norma2)>1e-10 && fabs(PsimagLite::imag(tmp))<1e-6);
-		return sum/norma2;
+		assert(fabs(norma2) > 1e-10 && fabs(PsimagLite::imag(tmp)) < 1e-6);
+		return sum / norma2;
 	}
 
 	const ObserverHelperType& helper_;
 	const ModelType& model_;
 	bool normalizeResult_;
-};  //class CorrelationsSkeleton
+}; // class CorrelationsSkeleton
 } // namespace Dmrg
 
 /*@}*/
 #endif
-
