@@ -2,27 +2,27 @@
 #define MANYPOINTACTION_H
 #include "PredicateAwesome.h"
 
-namespace Dmrg {
+namespace Dmrg
+{
 
-
-class ManyPointAction {
+class ManyPointAction
+{
 
 public:
 
 	typedef PsimagLite::PredicateAwesome<> PredicateAwesomeType;
-	typedef PsimagLite::ExpressionCalculator<int> ExpressionCalculatorType;
-	typedef PsimagLite::PrepassData<int> PrepassDataType;
-	typedef PsimagLite::ExpressionPrepass<PrepassDataType> ExpressionPrepassType;
 
 	ManyPointAction(bool hasNonTrivialAction,
-	                PsimagLite::String actionString)
-	    : nonTrivial_(hasNonTrivialAction),
-	      actionString_(actionString)
-	{}
+	    PsimagLite::String actionString)
+	    : nonTrivial_(hasNonTrivialAction)
+	    , actionString_(actionString)
+	{
+	}
 
 	bool operator()(SizeType s0, SizeType s1, SizeType s2, SizeType s3) const
 	{
-		if (!nonTrivial_) return true;
+		if (!nonTrivial_)
+			return true;
 
 		PredicateAwesomeType pred(actionString_, "~");
 		return pred.isTrue("%0", s0, "%1", s1, "%2", s2, "%3", s3);
@@ -30,7 +30,8 @@ public:
 
 	bool operator()(SizeType s0, SizeType s1) const
 	{
-		if (!nonTrivial_) return true;
+		if (!nonTrivial_)
+			return true;
 
 		PredicateAwesomeType pred(actionString_, "~");
 		return pred.isTrue("%0", s0, "%1", s1);
