@@ -1,15 +1,17 @@
 #ifndef OPTIONS_H
 #define OPTIONS_H
-#include "PsimagLite.h"
 #include "ProgramGlobals.h"
-#include <cctype>
+#include "PsimagLite.h"
 #include <algorithm>
+#include <cctype>
 #include <numeric>
 
-namespace Dmrg {
+namespace Dmrg
+{
 
-template<typename InputValidatorType>
-class Options {
+template <typename InputValidatorType>
+class Options
+{
 
 public:
 
@@ -36,8 +38,8 @@ public:
 	void write(PsimagLite::String label, PsimagLite::IoSerializer& ioSerializer) const
 	{
 		const PsimagLite::String tmp = std::accumulate(vdata_.begin(),
-		                                               vdata_.end(),
-		                                               PsimagLite::String(","));
+		    vdata_.end(),
+		    PsimagLite::String(","));
 		ioSerializer.write(label, tmp);
 	}
 
@@ -45,8 +47,8 @@ public:
 	{
 		what = ProgramGlobals::toLower(what);
 		VectorStringType::const_iterator it = std::find(vdata_.begin(),
-		                                                vdata_.end(),
-		                                                what);
+		    vdata_.end(),
+		    what);
 		return (it != vdata_.end());
 	}
 
@@ -55,9 +57,9 @@ private:
 	void lowerAll()
 	{
 		std::transform(vdata_.begin(),
-		               vdata_.end(),
-		               vdata_.begin(),
-		               [](PsimagLite::String s){ return ProgramGlobals::toLower(s); });
+		    vdata_.end(),
+		    vdata_.begin(),
+		    [](PsimagLite::String s) { return ProgramGlobals::toLower(s); });
 	}
 
 	VectorStringType vdata_;
