@@ -1,14 +1,16 @@
 #ifndef PROVENANCE_H
 #define PROVENANCE_H
 #include "../../PsimagLite/src/Version.h"
+#include "../GitRevision.h"
 #include "../Version.h"
 #include "AllocatorCpu.h"
-#include <iostream>
 #include "AnsiColors.h"
+#include "MatrixVectorKron/BatchedGemmInclude.hh"
+#include <iostream>
 #include <sstream>
-#include "../GitRevision.h"
 
-class Provenance {
+class Provenance
+{
 
 public:
 
@@ -26,11 +28,11 @@ public:
 	{
 		PsimagLite::OstringStream msgg(std::cout.precision());
 		PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-		msg<<appName<<"\x1b[38;5;240";
-		msg<<" [master "<<DMRGPP_VERSION<<"] "<<PsimagLite::AnsiColor::reset;
-		PsimagLite::String ctOpts("");
+		msg << appName << "\x1b[38;5;240";
+		msg << " [master " << DMRGPP_VERSION << "] " << PsimagLite::AnsiColor::reset;
+		PsimagLite::String ctOpts(Dmrg::BatchedGemmInclude::info());
 #ifdef USE_SHORT
-		ctOpts += "SHORT ";
+		ctOpts += " SHORT ";
 #endif
 #ifdef USE_FLOAT
 		ctOpts += "FLOAT ";
@@ -44,21 +46,17 @@ public:
 #ifdef USE_BOOST
 		ctOpts += "BOOST ";
 #endif
-#ifdef PLUGIN_SC
-		ctOpts += "PLUGIN_SC ";
-#endif
 #ifndef NDEBUG
 		ctOpts += "DEBUG ";
 #endif
 
 		if (ctOpts != "")
-			msg<<"["<<ctOpts<<"]";
+			msg << "[" << ctOpts << "]";
 
 		return msg.str();
 	}
 }; // Provenance
 
-std::ostream& operator<<(std::ostream& os,const Provenance&);
+std::ostream& operator<<(std::ostream& os, const Provenance&);
 
 #endif // PROVENANCE_H
-
