@@ -81,16 +81,18 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
 #ifndef VECTOR_WITH_OFFSETS_H
 #define VECTOR_WITH_OFFSETS_H
 #include "Complex.h"
+#include "ProgramGlobals.h"
 #include "ProgressIndicator.h"
 #include <cassert>
-#include "ProgramGlobals.h"
 #include <typeinfo>
 
 // FIXME: a more generic solution is needed instead of tying
 // the non-zero structure to basis
-namespace Dmrg {
-template<typename ComplexOrRealType, typename QnType_>
-class VectorWithOffsets {
+namespace Dmrg
+{
+template <typename ComplexOrRealType, typename QnType_>
+class VectorWithOffsets
+{
 
 	typedef VectorWithOffsets<ComplexOrRealType, QnType_> ThisType;
 	typedef typename QnType_::VectorSizeType VectorSizeType;
@@ -108,48 +110,51 @@ public:
 	typedef typename PsimagLite::Vector<VectorType>::Type VectorVectorType;
 
 	VectorWithOffsets()
-	    : progress_("VectorWithOffsets"),size_(0),index2Sector_(0)
-	{ }
-
-	template<typename SomeBasisType>
-	VectorWithOffsets(const typename PsimagLite::Vector<SizeType>::Type& weights,
-	                  const SomeBasisType& someBasis)
-	    : progress_("VectorWithOffsets"),
-	      size_(someBasis.size()),
-	      index2Sector_(size_),
-	      data_(weights.size()),
-	      offsets_(weights.size()+1)
+	    : progress_("VectorWithOffsets")
+	    , size_(0)
+	    , index2Sector_(0)
 	{
-		for (SizeType i=0;i<weights.size();i++) {
+	}
+
+	template <typename SomeBasisType>
+	VectorWithOffsets(const typename PsimagLite::Vector<SizeType>::Type& weights,
+	    const SomeBasisType& someBasis)
+	    : progress_("VectorWithOffsets")
+	    , size_(someBasis.size())
+	    , index2Sector_(size_)
+	    , data_(weights.size())
+	    , offsets_(weights.size() + 1)
+	{
+		for (SizeType i = 0; i < weights.size(); i++) {
 			data_[i].resize(weights[i]);
 			offsets_[i] = someBasis.partition(i);
-			if (weights[i]>0) {
+			if (weights[i] > 0) {
 				QnType qn = someBasis.pseudoQn(i);
-				nzMsAndQns_.push_back(PairQnType(i,qn));
-				//firstSector_ = i;
+				nzMsAndQns_.push_back(PairQnType(i, qn));
+				// firstSector_ = i;
 			}
 		}
 
-		offsets_[weights.size()]=size_;
+		offsets_[weights.size()] = size_;
 		setIndex2Sector();
 	}
 
-	template<typename SomeBasisType>
+	template <typename SomeBasisType>
 	VectorWithOffsets(SizeType, SizeType, const SomeBasisType&)
 	    : progress_("VectorWithOffset")
 	{
 		err("VectorWithOffsets::ctor() FATAL: wrong execution path!\n");
 	}
 
-	template<typename SomeBasisType>
+	template <typename SomeBasisType>
 	VectorWithOffsets(const VectorSizeType& compactedWeights,
-	                  const VectorSizeType& sectors,
-	                  const SomeBasisType& someBasis)
-	    : progress_("VectorWithOffsets"),
-	      size_(someBasis.size()),
-	      index2Sector_(size_),
-	      data_(someBasis.partition() - 1),
-	      offsets_(someBasis.partition())
+	    const VectorSizeType& sectors,
+	    const SomeBasisType& someBasis)
+	    : progress_("VectorWithOffsets")
+	    , size_(someBasis.size())
+	    , index2Sector_(size_)
+	    , data_(someBasis.partition() - 1)
+	    , offsets_(someBasis.partition())
 	{
 		for (SizeType i = 0; i < offsets_.size(); ++i)
 			offsets_[i] = someBasis.partition(i);
@@ -163,7 +168,6 @@ public:
 			data_[sector].resize(compactedWeights[sectorIndex]);
 			QnType qn = someBasis.pseudoQn(sector);
 			nzMsAndQns_.push_back(PairQnType(sector, qn));
-
 		}
 
 		setIndex2Sector();
@@ -178,10 +182,10 @@ public:
 		nzMsAndQns_.clear();
 	}
 
-	template<typename SomeBasisType>
+	template <typename SomeBasisType>
 	void set(VectorType& v,
-	         SizeType sector,
-	         const SomeBasisType& someBasis)
+	    SizeType sector,
+	    const SomeBasisType& someBasis)
 	{
 		size_ = someBasis.size();
 		nzMsAndQns_.clear();
@@ -201,54 +205,54 @@ public:
 		setIndex2Sector();
 	}
 
-	template<typename SomeBasisType>
+	template <typename SomeBasisType>
 	void populateSectors(const SomeBasisType& someBasis)
 	{
-		SizeType np = someBasis.partition()-1;
+		SizeType np = someBasis.partition() - 1;
 		size_ = someBasis.size();
 		nzMsAndQns_.clear();
 		data_.clear();
 		data_.resize(np);
-		offsets_.resize(np+1);
-		for (SizeType i=0;i<np;i++) {
+		offsets_.resize(np + 1);
+		for (SizeType i = 0; i < np; i++) {
 			offsets_[i] = someBasis.partition(i);
-			SizeType total = someBasis.partition(i+1)-offsets_[i];
-			VectorType tmpV(total,0);
+			SizeType total = someBasis.partition(i + 1) - offsets_[i];
+			VectorType tmpV(total, 0);
 			data_[i] = tmpV;
 			const QnType& qn = someBasis.pseudoQn(i);
 			nzMsAndQns_.push_back(PairQnType(i, qn));
 		}
 
-		offsets_[np]=size_;
+		offsets_[np] = size_;
 		setIndex2Sector();
 		PsimagLite::OstringStream msgg(std::cout.precision());
 		PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-		msg<<"Populated "<<np<<" sectors";
+		msg << "Populated " << np << " sectors";
 		progress_.printline(msgg, std::cout);
 	}
 
-	template<typename SomeBasisType>
+	template <typename SomeBasisType>
 	void populateFromQns(const VectorWithOffsets& v,
-	                     const SomeBasisType& someBasis)
+	    const SomeBasisType& someBasis)
 	{
-		SizeType np = someBasis.partition()-1;
+		SizeType np = someBasis.partition() - 1;
 		size_ = someBasis.size();
 		nzMsAndQns_.clear();
 		data_.clear();
 		data_.resize(np);
-		offsets_.resize(np+1);
-		for (SizeType i=0;i<np;i++) {
+		offsets_.resize(np + 1);
+		for (SizeType i = 0; i < np; i++) {
 			offsets_[i] = someBasis.partition(i);
 		}
 
-		offsets_[np]=size_;
+		offsets_[np] = size_;
 
-		for (SizeType i=0;i<v.sectors();i++) {
-			SizeType ip = findPartitionWithThisQn(v.qn(i),someBasis);
+		for (SizeType i = 0; i < v.sectors(); i++) {
+			SizeType ip = findPartitionWithThisQn(v.qn(i), someBasis);
 			if (ip >= np)
 				err("VectorWithOffsets: populateFromQns\n");
-			SizeType total = someBasis.partition(ip+1)-offsets_[ip];
-			VectorType tmpV(total,0);
+			SizeType total = someBasis.partition(ip + 1) - offsets_[ip];
+			VectorType tmpV(total, 0);
 			data_[ip] = tmpV;
 			nzMsAndQns_.push_back(PairQnType(ip, v.qn(i)));
 		}
@@ -256,7 +260,7 @@ public:
 		setIndex2Sector();
 		PsimagLite::OstringStream msgg(std::cout.precision());
 		PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-		msg<<"populateFromQns "<<v.sectors()<<" sectors";
+		msg << "populateFromQns " << v.sectors() << " sectors";
 		progress_.printline(msgg, std::cout);
 	}
 
@@ -282,11 +286,11 @@ public:
 		setIndex2Sector();
 		PsimagLite::OstringStream msgg(std::cout.precision());
 		PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-		msg<<"Collapsed. Non-zero sectors now are "<<nzMsAndQns_.size();
+		msg << "Collapsed. Non-zero sectors now are " << nzMsAndQns_.size();
 		progress_.printline(msgg, std::cout);
 	}
 
-	void setDataInSector(const VectorType& v,SizeType i0)
+	void setDataInSector(const VectorType& v, SizeType i0)
 	{
 		if (i0 >= data_.size())
 			err("VectorWithOffsets: setDataInSector\n");
@@ -308,40 +312,40 @@ public:
 		return nzMsAndQns_[i].second;
 	}
 
-	template<typename SomeBasisType>
-	void fromFull(const VectorType& v,const SomeBasisType& someBasis)
+	template <typename SomeBasisType>
+	void fromFull(const VectorType& v, const SomeBasisType& someBasis)
 	{
 		size_ = someBasis.size();
 
 		offsets_.resize(someBasis.partition());
-		for (SizeType i=0;i<someBasis.partition();i++)
+		for (SizeType i = 0; i < someBasis.partition(); i++)
 			offsets_[i] = someBasis.partition(i);
-		assert(offsets_[offsets_.size()-1]==size_);
+		assert(offsets_[offsets_.size() - 1] == size_);
 
 		data_.clear();
-		data_.resize(someBasis.partition()-1);
+		data_.resize(someBasis.partition() - 1);
 
 		nzMsAndQns_.clear();
-		findPartitions(nzMsAndQns_,v,someBasis);
-		for (SizeType jj=0;jj<nzMsAndQns_.size();jj++) {
+		findPartitions(nzMsAndQns_, v, someBasis);
+		for (SizeType jj = 0; jj < nzMsAndQns_.size(); jj++) {
 			SizeType j = nzMsAndQns_[jj].first;
 			assert(j < data_.size());
 			SizeType offset = offsets_[j];
-			SizeType total = offsets_[j+1]-offset;
+			SizeType total = offsets_[j + 1] - offset;
 			data_[j].resize(total);
-			for (SizeType i=0;i<total;i++)
-				data_[j][i] = v[i+offset];
+			for (SizeType i = 0; i < total; i++)
+				data_[j][i] = v[i + offset];
 		}
 
 		setIndex2Sector();
 	}
 
-	void extract(VectorType& v,SizeType i) const
+	void extract(VectorType& v, SizeType i) const
 	{
 		if (i >= data_.size())
 			err("VectorWithOffsets: extract\n");
 
-		v=data_[i];
+		v = data_[i];
 	}
 
 	SizeType size() const { return size_; }
@@ -361,14 +365,14 @@ public:
 		return offsets_[i];
 	}
 
-	const ComplexOrRealType& fastAccess(SizeType i,SizeType j) const
+	const ComplexOrRealType& fastAccess(SizeType i, SizeType j) const
 	{
 		assert(i < data_.size());
 		assert(j < data_[i].size());
 		return data_[i][j];
 	}
 
-	ComplexOrRealType& fastAccess(SizeType i,SizeType j)
+	ComplexOrRealType& fastAccess(SizeType i, SizeType j)
 	{
 		assert(i < data_.size());
 		assert(j < data_[i].size());
@@ -377,44 +381,46 @@ public:
 
 	const ComplexOrRealType& slowAccess(SizeType i) const
 	{
-		assert(i<index2Sector_.size());
+		assert(i < index2Sector_.size());
 		int j = index2Sector_[i];
-		if (j<0) return zero_;
-		return data_[j][i-offsets_[j]];
+		if (j < 0)
+			return zero_;
+		return data_[j][i - offsets_[j]];
 	}
 
 	ComplexOrRealType& slowAccess(SizeType i)
 	{
 		int j = index2Sector_[i];
-		if (j<0) {
+		if (j < 0) {
 			PsimagLite::String msg("VectorWithOffsets");
-			std::cerr<<msg<<" can't build itself dynamically yet (sorry!)\n";
+			std::cerr << msg << " can't build itself dynamically yet (sorry!)\n";
 			return data_[0][0];
 		}
 
 		assert(static_cast<SizeType>(j) < data_.size());
 		assert(i - offsets_[j] < data_[j].size());
-		return data_[j][i-offsets_[j]];
+		return data_[j][i - offsets_[j]];
 	}
 
-	template<typename SparseVectorType>
+	template <typename SparseVectorType>
 	void toSparse(SparseVectorType& sv) const
 	{
 		sv.resize(size_);
-		for (SizeType jj=0;jj<nzMsAndQns_.size();jj++) {
-			SizeType j =  nzMsAndQns_[jj].first;
+		for (SizeType jj = 0; jj < nzMsAndQns_.size(); jj++) {
+			SizeType j = nzMsAndQns_[jj].first;
 			assert(j < data_.size());
-			for (SizeType i=0;i<data_[j].size();i++)
-				sv[i+offsets_[j]] = data_[j][i];
+			for (SizeType i = 0; i < data_[j].size(); i++)
+				sv[i + offsets_[j]] = data_[j][i];
 		}
 	}
 
-	template<typename SomeInputType>
+	template <typename SomeInputType>
 	void read(SomeInputType& io,
-	          PsimagLite::String label)
+	    PsimagLite::String label)
 	{
 		io.read(size_, label + "/size_");
-		if (size_ == 0) return;
+		if (size_ == 0)
+			return;
 		io.read(index2Sector_, label + "/index2Sector_");
 		SizeType x = 0;
 		io.read(x, label + "/data_/Size");
@@ -424,11 +430,13 @@ public:
 			try {
 				io.read(data_[i], label + "/data_/" + ttos(i));
 				flag = true;
-				std::cerr<<"VectorWithOffsets: non-zero sector index "<<i<<" read \n";
-			} catch (...) {}
+				std::cerr << "VectorWithOffsets: non-zero sector index " << i << " read \n";
+			} catch (...) {
+			}
 		}
 
-		if (!flag) err("VectorWithOffsets: all sectors in data_ are empty (FATAL)\n");
+		if (!flag)
+			err("VectorWithOffsets: all sectors in data_ are empty (FATAL)\n");
 
 		io.read(offsets_, label + "/offsets_");
 		SizeType aSize = 0;
@@ -440,9 +448,9 @@ public:
 		}
 	}
 
-	template<typename SomeIoOutputType>
+	template <typename SomeIoOutputType>
 	void write(SomeIoOutputType& io,
-	           const PsimagLite::String& label) const
+	    const PsimagLite::String& label) const
 	{
 		io.createGroup(label);
 		io.write(size_, label + "/size_");
@@ -455,39 +463,39 @@ public:
 	// We don't have a partitioned basis because we don't
 	// have the superblock basis at this point
 	// Therefore, partitioning is bogus here
-	template<typename IoInputter>
+	template <typename IoInputter>
 	void loadOneSector(IoInputter& io,
-	                   const PsimagLite::String& label,
-	                   SizeType counter=0)
+	    const PsimagLite::String& label,
+	    SizeType counter = 0)
 	{
 		PsimagLite::String msg("VectorWithOffsets:");
-		io.advance(label,counter);
+		io.advance(label, counter);
 		int x = 0;
-		io.readline(x,"size=");
-		if (x<0)
+		io.readline(x, "size=");
+		if (x < 0)
 			err(msg + ":loadOneSector(...): size<0\n");
 		size_ = x;
 
-		io.read(offsets_,"offsets");
+		io.read(offsets_, "offsets");
 
 		data_.clear();
 		data_.resize(offsets_.size());
 
-		io.readline(x,"nonzero=");
+		io.readline(x, "nonzero=");
 		if (x < 0)
 			err(msg + ":loadOneSector(...): nonzerosectors<0\n");
 		nzMsAndQns_.resize(x);
 
-		for (SizeType jj=0;jj<nzMsAndQns_.size();jj++) {
-			io.readline(x,"sector=");
-			if (x<0)
+		for (SizeType jj = 0; jj < nzMsAndQns_.size(); jj++) {
+			io.readline(x, "sector=");
+			if (x < 0)
 				err(msg + ":loadOneSector(...): sector<0\n");
 
 			QnType y;
 			y.read("qn", io);
 			nzMsAndQns_[jj] = PairQnType(x, y);
 
-			if (static_cast<SizeType>(x)>=data_.size())
+			if (static_cast<SizeType>(x) >= data_.size())
 				err(msg + ":loadOneSector(...): sector too big\n");
 
 			PsimagLite::String s = "data" + ttos(jj);
@@ -510,7 +518,7 @@ public:
 
 	VectorWithOffsets operator+=(const VectorWithOffsets& v)
 	{
-		if (nzMsAndQns_.size()==0) {
+		if (nzMsAndQns_.size() == 0) {
 			size_ = v.size_;
 			data_ = v.data_;
 			offsets_ = v.offsets_;
@@ -519,7 +527,7 @@ public:
 			return *this;
 		}
 
-		for (SizeType ii=0;ii<nzMsAndQns_.size();ii++) {
+		for (SizeType ii = 0; ii < nzMsAndQns_.size(); ii++) {
 			SizeType i = nzMsAndQns_[ii].first;
 			assert(i < data_.size());
 			data_[i] += v.data_[i];
@@ -539,12 +547,12 @@ public:
 
 	friend RealType norm(const VectorWithOffsets& v)
 	{
-		RealType sum=0;
-		for (SizeType ii=0;ii<v.nzMsAndQns_.size();ii++) {
+		RealType sum = 0;
+		for (SizeType ii = 0; ii < v.nzMsAndQns_.size(); ii++) {
 			SizeType i = v.nzMsAndQns_[ii].first;
 			assert(i < v.data_.size());
 			RealType tmp = PsimagLite::norm(v.data_[i]);
-			sum += tmp*tmp;
+			sum += tmp * tmp;
 		}
 
 		return sqrt(sum);
@@ -555,26 +563,28 @@ public:
 		RealType norma = norm(v);
 		RealType eps = 1e-5;
 
-		if (fabs(norma-1.0)<eps) return;
+		if (fabs(norma - 1.0) < eps)
+			return;
 
-		assert(fabs(norma)>eps);
+		assert(fabs(norma) > eps);
 
-		for (SizeType i=0;i<v.data_.size();i++)
-			for (SizeType j=0;j<v.data_[i].size();j++)
+		for (SizeType i = 0; i < v.data_.size(); i++)
+			for (SizeType j = 0; j < v.data_[i].size(); j++)
 				v.data_[i][j] /= norma;
 	}
 
 	friend ComplexOrRealType operator*(const VectorWithOffsets& v1,
-	                                   const VectorWithOffsets& v2)
+	    const VectorWithOffsets& v2)
 	{
 		ComplexOrRealType sum = 0;
 		for (SizeType ii = 0; ii < v1.sectors(); ++ii) {
 			SizeType i = v1.sector(ii);
 			for (SizeType jj = 0; jj < v1.sectors(); ++jj) {
 				SizeType j = v2.sector(jj);
-				if (i != j) continue;
+				if (i != j)
+					continue;
 				for (SizeType k = 0; k < v1.effectiveSize(i); ++k)
-					sum+= v1.fastAccess(i,k)*PsimagLite::conj(v2.fastAccess(j,k));
+					sum += v1.fastAccess(i, k) * PsimagLite::conj(v2.fastAccess(j, k));
 			}
 		}
 
@@ -582,7 +592,7 @@ public:
 	}
 
 	friend VectorWithOffsets operator*(const ComplexOrRealType& value,
-	                                   const VectorWithOffsets& v)
+	    const VectorWithOffsets& v)
 	{
 		VectorWithOffsets w = v;
 
@@ -596,17 +606,17 @@ public:
 	}
 
 	friend VectorWithOffsets operator+(const VectorWithOffsets& v1,
-	                                   const VectorWithOffsets& v2)
+	    const VectorWithOffsets& v2)
 	{
 		PsimagLite::String s = "VectorWithOffsets + VectorWithOffsets failed\n";
 		if (v1.nzMsAndQns_ != v2.nzMsAndQns_)
 			err(s.c_str());
 
-		for (SizeType ii=0;ii<v1.nzMsAndQns_.size();ii++) {
+		for (SizeType ii = 0; ii < v1.nzMsAndQns_.size(); ii++) {
 			SizeType i = v1.nzMsAndQns_[ii];
 			if (i >= v1.data_.size() || i >= v2.data_.size())
 				err(s.c_str());
-			if (v1.data_[i].size()!=v2.data_[i].size())
+			if (v1.data_[i].size() != v2.data_[i].size())
 				err(s.c_str());
 		}
 
@@ -619,7 +629,7 @@ private:
 
 	void setIndex2Sector()
 	{
-		if (index2Sector_.size()!=size_)
+		if (index2Sector_.size() != size_)
 			index2Sector_.resize(size_);
 
 		for (SizeType i = 0; i < size_; ++i) {
@@ -627,22 +637,22 @@ private:
 			for (SizeType jj = 0; jj < nzMsAndQns_.size(); ++jj) {
 				SizeType j = nzMsAndQns_[jj].first;
 				assert(j + 1 < offsets_.size());
-				if (i < offsets_[j] || i >= offsets_[j+1])
+				if (i < offsets_[j] || i >= offsets_[j + 1])
 					continue;
 				index2Sector_[i] = j;
 			}
 		}
 	}
 
-	template<typename SomeBasisType>
+	template <typename SomeBasisType>
 	void findPartitions(typename PsimagLite::Vector<PairQnType>::Type& p,
-	                    const VectorType& v,
-	                    const SomeBasisType& someBasis)
+	    const VectorType& v,
+	    const SomeBasisType& someBasis)
 	{
 		bool found = false;
 		p.clear();
-		for (SizeType i=0;i<someBasis.partition()-1;i++) {
-			if (nonZeroPartition(v,someBasis,i)) {
+		for (SizeType i = 0; i < someBasis.partition() - 1; i++) {
+			if (nonZeroPartition(v, someBasis, i)) {
 				found = true;
 				const QnType& qn = someBasis.pseudoQn(i);
 				p.push_back(PairQnType(i, qn));
@@ -652,19 +662,21 @@ private:
 		if (!found) {
 			PsimagLite::OstringStream msgg(std::cout.precision());
 			PsimagLite::OstringStream::OstringStreamType& msg = msgg();
-			msg<<"No partition found";
+			msg << "No partition found";
 			progress_.printline(msgg, std::cout);
 		}
 	}
 
-	template<typename SomeBasisType>
+	template <typename SomeBasisType>
 	bool nonZeroPartition(const VectorType& v,
-	                      const SomeBasisType& someBasis,SizeType i)
+	    const SomeBasisType& someBasis,
+	    SizeType i)
 	{
 		typename VectorType::value_type zero = 0;
-		for (SizeType j = someBasis.partition(i); j < someBasis.partition(i+1); ++j) {
+		for (SizeType j = someBasis.partition(i); j < someBasis.partition(i + 1); ++j) {
 			assert(j < v.size());
-			if (v[j] != zero) return true;
+			if (v[j] != zero)
+				return true;
 		}
 
 		return false;
@@ -674,19 +686,20 @@ private:
 	{
 		RealType eps = 1e-5;
 		for (SizeType i = 0; i < v.size(); ++i)
-			if (fabs(PsimagLite::real(v[i]))>eps || fabs(PsimagLite::imag(v[i]))>eps)
+			if (fabs(PsimagLite::real(v[i])) > eps || fabs(PsimagLite::imag(v[i])) > eps)
 				return false;
 
 		return true;
 	}
 
-	template<typename SomeBasisType>
+	template <typename SomeBasisType>
 	SizeType findPartitionWithThisQn(const QnType& qn,
-	                                 const SomeBasisType& someBasis) const
+	    const SomeBasisType& someBasis) const
 	{
 		SizeType np = someBasis.partition() - 1;
 		for (SizeType i = 0; i < np; ++i)
-			if (someBasis.qnEx(i) == qn) return i;
+			if (someBasis.qnEx(i) == qn)
+				return i;
 
 		throw PsimagLite::RuntimeError("findPartitionWithThisQn\n");
 	}
@@ -699,9 +712,8 @@ private:
 	typename PsimagLite::Vector<PairQnType>::Type nzMsAndQns_;
 }; // class VectorWithOffset
 
-template<typename ComplexOrRealType, typename EffectiveQnType>
+template <typename ComplexOrRealType, typename EffectiveQnType>
 const ComplexOrRealType VectorWithOffsets<ComplexOrRealType, EffectiveQnType>::zero_ = 0;
 }
 /*@}*/
 #endif
-
