@@ -79,18 +79,20 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
  */
 #ifndef DMRGPP_GRAPHENE_H
 #define DMRGPP_GRAPHENE_H
+#include "../FeAsModel/HilbertSpaceFeAs.h"
 #include "ModelBase.h"
 #include "ParametersGraphene.h"
-#include "../FeAsModel/HilbertSpaceFeAs.h"
-//#include "CrsMatrix.h"
-#include "VerySparseMatrix.h"
-#include "ProgramGlobals.h"
-#include <numeric>
+// #include "CrsMatrix.h"
 #include "../../../PsimagLite/src/Vector.h"
+#include "ProgramGlobals.h"
+#include "VerySparseMatrix.h"
+#include <numeric>
 
-namespace Dmrg {
-template<typename ModelBaseType>
-class Graphene : public ModelBaseType {
+namespace Dmrg
+{
+template <typename ModelBaseType>
+class Graphene : public ModelBaseType
+{
 
 public:
 
@@ -109,12 +111,12 @@ public:
 	typedef typename SparseMatrixType::value_type ComplexOrRealType;
 	typedef typename ModelBaseType::HilbertBasisType HilbertBasisType;
 	typedef typename HilbertBasisType::value_type HilbertState;
-	typedef  HilbertSpaceFeAs<HilbertState> HilbertSpaceFeAsType;
+	typedef HilbertSpaceFeAs<HilbertState> HilbertSpaceFeAsType;
 	typedef typename ModelHelperType::BlockType BlockType;
 	typedef typename ModelBaseType::SolverParamsType SolverParamsType;
 	typedef typename ModelBaseType::VectorType VectorType;
-	typedef	 typename ModelBaseType::MyBasis MyBasis;
-	typedef	 typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
+	typedef typename ModelBaseType::MyBasis MyBasis;
+	typedef typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
 	typedef typename ModelBaseType::InputValidatorType InputValidatorType;
 	typedef PsimagLite::Matrix<ComplexOrRealType> MatrixType;
 	typedef ParametersGraphene<ComplexOrRealType, QnType> ParametersGrapheneType;
@@ -123,26 +125,27 @@ public:
 	typedef typename ModelBaseType::ModelTermType ModelTermType;
 
 	static const int FERMION_SIGN = -1;
-	static const int SPIN_UP=HilbertSpaceFeAsType::SPIN_UP;
-	static const int SPIN_DOWN=HilbertSpaceFeAsType::SPIN_DOWN;
+	static const int SPIN_UP = HilbertSpaceFeAsType::SPIN_UP;
+	static const int SPIN_DOWN = HilbertSpaceFeAsType::SPIN_DOWN;
 
 	Graphene(const SolverParamsType& solverParams,
-	         InputValidatorType& io,
-	         const SuperGeometryType& geometry)
-	    : ModelBaseType(solverParams, geometry, io),
-	      modelParameters_(io)
+	    InputValidatorType& io,
+	    const SuperGeometryType& geometry)
+	    : ModelBaseType(solverParams, geometry, io)
+	    , modelParameters_(io)
 	{
-		ProgramGlobals::init(modelParameters_.orbitals*geometry.numberOfSites() + 1);
+		ProgramGlobals::init(modelParameters_.orbitals * geometry.numberOfSites() + 1);
 
 		HilbertSpaceFeAsType::setOrbitals(modelParameters_.orbitals);
-		statesPerSite_ = (1 << (modelParameters_.orbitals*2));
+		statesPerSite_ = (1 << (modelParameters_.orbitals * 2));
 
-		VectorSizeType block(1,0);
-		int sitesTimesDof = 2*modelParameters_.orbitals;
-		HilbertState total = (1<<sitesTimesDof);
+		VectorSizeType block(1, 0);
+		int sitesTimesDof = 2 * modelParameters_.orbitals;
+		HilbertState total = (1 << sitesTimesDof);
 		basis_.resize(total);
-		for (HilbertState a = 0; a < total; ++a) basis_[a] = a;
-		setSymmetryRelatedInternal(qq_,basis_,1);
+		for (HilbertState a = 0; a < total; ++a)
+			basis_[a] = a;
+		setSymmetryRelatedInternal(qq_, basis_, 1);
 		ModelBaseType::notReallySort(basis_, qq_);
 
 		setOperatorMatricesInternal(creationMatrix_, block);
@@ -163,8 +166,8 @@ public:
 	}
 
 	void addDiagonalsInNaturalBasis(SparseMatrixType& hmatrix,
-	                                const BlockType& block,
-	                                RealType time) const
+	    const BlockType& block,
+	    RealType time) const
 	{
 		ModelBaseType::additionalOnSiteHamiltonian(hmatrix, block, time);
 
@@ -179,12 +182,12 @@ public:
 	void fillLabeledOperators(VectorQnType& qns)
 	{
 		qns = qq_;
-		assert(creationMatrix_.size()>0);
+		assert(creationMatrix_.size() > 0);
 		SizeType nrow = creationMatrix_[0].getCRS().rows();
 
 		OpsLabelType& c = this->createOpsLabel("c");
 		OpsLabelType& cc = this->createOpsLabel("C");
-		for (SizeType dof = 0; dof < 2*modelParameters_.orbitals; ++dof) {
+		for (SizeType dof = 0; dof < 2 * modelParameters_.orbitals; ++dof) {
 			VectorOperatorType cm = creationMatrix_;
 			cc.push(creationMatrix_[dof]);
 			cm[dof].dagger();
@@ -196,16 +199,15 @@ public:
 		OpsLabelType& yop = this->createOpsLabel("yop");
 		for (SizeType spin1 = 0; spin1 < 2; ++spin1) {
 			for (SizeType spin2 = 0; spin2 < 2; ++spin2) {
-				MatrixType tmp =
-				        multiplyTc(creationMatrix_[0+spin1*modelParameters_.orbitals].getCRS(),
-				        creationMatrix_[1+spin2*modelParameters_.orbitals].getCRS());
+				MatrixType tmp = multiplyTc(creationMatrix_[0 + spin1 * modelParameters_.orbitals].getCRS(),
+				    creationMatrix_[1 + spin2 * modelParameters_.orbitals].getCRS());
 				SparseMatrixType tmp2(tmp);
 				typename OperatorType::Su2RelatedType su2Related;
 				yop.push(OperatorType(tmp2,
-				                      ProgramGlobals::FermionOrBosonEnum::BOSON,
-				                      typename OperatorType::PairType(0,0),
-				                      1.0,
-				                      su2Related));
+				    ProgramGlobals::FermionOrBosonEnum::BOSON,
+				    typename OperatorType::PairType(0, 0),
+				    1.0,
+				    su2Related));
 			}
 		}
 
@@ -215,86 +217,84 @@ public:
 		OpsLabelType& nn = this->createOpsLabel("nn");
 		OpsLabelType& ntotal = this->createOpsLabel("ntotal");
 		SparseMatrixType ntotalcrs;
-		for (SizeType dof = 0; dof < 2*modelParameters_.orbitals; ++dof) {
-			MatrixType tmp =
-			        multiplyTc(creationMatrix_[dof].getCRS(),creationMatrix_[dof].getCRS());
+		for (SizeType dof = 0; dof < 2 * modelParameters_.orbitals; ++dof) {
+			MatrixType tmp = multiplyTc(creationMatrix_[dof].getCRS(), creationMatrix_[dof].getCRS());
 			SparseMatrixType tmp2(tmp);
 			ntotalcrs += tmp2;
 			typename OperatorType::Su2RelatedType su2Related;
 			nop.push(OperatorType(tmp2,
-			                      ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                      typename OperatorType::PairType(0,0),
-			                      1.0,
-			                      su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 			if (dof == 0 || dof == 2) // naup nadown
 				nn.push(OperatorType(tmp2,
-				                     ProgramGlobals::FermionOrBosonEnum::BOSON,
-				                     typename OperatorType::PairType(0,0),
-				                     1.0,
-				                     su2Related));
+				    ProgramGlobals::FermionOrBosonEnum::BOSON,
+				    typename OperatorType::PairType(0, 0),
+				    1.0,
+				    su2Related));
 		}
 
 		this->makeTrackable("nn");
 
-
 		typename OperatorType::Su2RelatedType su2Related;
 		ntotal.push(OperatorType(ntotalcrs,
-		                         ProgramGlobals::FermionOrBosonEnum::BOSON,
-		                         typename OperatorType::PairType(0,0),
-		                         1.0,
-		                         su2Related));
+		    ProgramGlobals::FermionOrBosonEnum::BOSON,
+		    typename OperatorType::PairType(0, 0),
+		    1.0,
+		    su2Related));
 		this->makeTrackable("ntotal");
 
 		OpsLabelType& splus = this->createOpsLabel("splus");
 		OpsLabelType& sminus = this->createOpsLabel("sminus");
 		OpsLabelType& splus2 = this->createOpsLabel("splus2");
 		for (SizeType dof = 0; dof < modelParameters_.orbitals; ++dof) {
-			MatrixType tmp(nrow,nrow);
+			MatrixType tmp(nrow, nrow);
 			tmp += multiplyTc(creationMatrix_[dof].getCRS(),
-			                  creationMatrix_[dof + modelParameters_.orbitals].getCRS());
+			    creationMatrix_[dof + modelParameters_.orbitals].getCRS());
 			SparseMatrixType tmp2(tmp);
 			typename OperatorType::Su2RelatedType su2Related;
 			splus.push(OperatorType(tmp2,
-			                        ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                        typename OperatorType::PairType(0,0),
-			                        1.0,
-			                        su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 			SparseMatrixType tmp3;
 			transposeConjugate(tmp3, tmp2);
 			sminus.push(OperatorType(tmp3,
-			                         ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                         typename OperatorType::PairType(0,0),
-			                         1.0,
-			                         su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 
 			// s+ a
-			if (dof == 0) splus2.push(OperatorType(tmp2,
-			                                       ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                                       typename OperatorType::PairType(0,0),
-			                                       1.0,
-			                                       su2Related));
+			if (dof == 0)
+				splus2.push(OperatorType(tmp2,
+				    ProgramGlobals::FermionOrBosonEnum::BOSON,
+				    typename OperatorType::PairType(0, 0),
+				    1.0,
+				    su2Related));
 		}
 
 		this->makeTrackable("splus2");
 
-
 		OpsLabelType& sz = this->createOpsLabel("sz");
 		for (SizeType dof = 0; dof < modelParameters_.orbitals; ++dof) {
-			MatrixType tmp(nrow,nrow);
-			MatrixType tmp2(nrow,nrow);
+			MatrixType tmp(nrow, nrow);
+			MatrixType tmp2(nrow, nrow);
 
-			tmp += multiplyTc(creationMatrix_[dof].getCRS(),creationMatrix_[dof].getCRS());
-			tmp2 += multiplyTc(creationMatrix_[dof+modelParameters_.orbitals].getCRS(),
-			        creationMatrix_[dof+modelParameters_.orbitals].getCRS());
+			tmp += multiplyTc(creationMatrix_[dof].getCRS(), creationMatrix_[dof].getCRS());
+			tmp2 += multiplyTc(creationMatrix_[dof + modelParameters_.orbitals].getCRS(),
+			    creationMatrix_[dof + modelParameters_.orbitals].getCRS());
 
-			tmp = 0.5*(tmp-tmp2);
+			tmp = 0.5 * (tmp - tmp2);
 			SparseMatrixType tmp3(tmp);
 			typename OperatorType::Su2RelatedType su2Related;
 			sz.push(OperatorType(tmp3,
-			                     ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                     typename OperatorType::PairType(0,0),
-			                     1.0,
-			                     su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 		}
 	}
 
@@ -307,8 +307,8 @@ public:
 		ModelTermType& hopA = ModelBaseType::createTerm("hoppingA");
 
 		for (SizeType spin = 0; spin < 2; ++spin) {
-			OpForLinkType c1("C", 0 + spin*orbitals);
-			OpForLinkType c2("C", 0 + spin*orbitals);
+			OpForLinkType c1("C", 0 + spin * orbitals);
+			OpForLinkType c2("C", 0 + spin * orbitals);
 			typename ModelTermType::Su2Properties su2properties(1, (spin == 1) ? -1 : 1, spin);
 
 			hopA.push(c1, 'N', c2, 'C', su2properties);
@@ -317,8 +317,8 @@ public:
 		ModelTermType& hopB = ModelBaseType::createTerm("hoppingB");
 
 		for (SizeType spin = 0; spin < 2; ++spin) {
-			OpForLinkType c1("C", 1 + spin*orbitals);
-			OpForLinkType c2("C", 1 + spin*orbitals);
+			OpForLinkType c1("C", 1 + spin * orbitals);
+			OpForLinkType c2("C", 1 + spin * orbitals);
 			typename ModelTermType::Su2Properties su2properties(1, (spin == 1) ? -1 : 1, spin);
 			hopB.push(c1, 'N', c2, 'C', su2properties);
 		}
@@ -340,8 +340,8 @@ public:
 		ModelTermType& yoyo = ModelBaseType::createTerm("yoyo");
 		for (SizeType spin1 = 0; spin1 < 2; ++spin1) {
 			for (SizeType spin2 = 0; spin2 < 2; ++spin2) {
-				OpForLinkType yi("yop", spin1 + spin2*2);
-				OpForLinkType yj("yop", spin2 + spin1*2);
+				OpForLinkType yi("yop", spin1 + spin2 * 2);
+				OpForLinkType yj("yop", spin2 + spin1 * 2);
 				yoyo.push(yi, 'N', yj, 'C');
 			}
 		}
@@ -353,38 +353,38 @@ public:
 	}
 
 	void setOperatorMatricesInternal(VectorOperatorType& creationMatrix,
-	                                 const BlockType& block) const
+	    const BlockType& block) const
 	{
 		const HilbertBasisType& natBasis = basis_;
 		SparseMatrixType tmpMatrix;
 
 		//! Set the operators c^\daggger_{i\gamma\sigma} in the natural basis
 		creationMatrix.clear();
-		SizeType dofs = 2*modelParameters_.orbitals;
-		for (SizeType i=0;i<block.size();i++) {
-			for (SizeType sigma=0;sigma<dofs;sigma++) {
-				findOperatorMatrices(tmpMatrix,i,sigma,natBasis);
+		SizeType dofs = 2 * modelParameters_.orbitals;
+		for (SizeType i = 0; i < block.size(); i++) {
+			for (SizeType sigma = 0; sigma < dofs; sigma++) {
+				findOperatorMatrices(tmpMatrix, i, sigma, natBasis);
 
-				SizeType m=0;
-				int asign=1;
-				if (sigma>modelParameters_.orbitals-1) {
-					m=1;
-					asign= -1;
+				SizeType m = 0;
+				int asign = 1;
+				if (sigma > modelParameters_.orbitals - 1) {
+					m = 1;
+					asign = -1;
 				}
 				typename OperatorType::Su2RelatedType su2related;
-				if (sigma <modelParameters_.orbitals) {
-					su2related.source.push_back(i*dofs+sigma);
-					su2related.source.push_back(i*dofs+sigma + modelParameters_.orbitals);
+				if (sigma < modelParameters_.orbitals) {
+					su2related.source.push_back(i * dofs + sigma);
+					su2related.source.push_back(i * dofs + sigma + modelParameters_.orbitals);
 					su2related.transpose.push_back(-1);
 					su2related.transpose.push_back(-1);
 					su2related.offset = modelParameters_.orbitals;
 				}
 
 				OperatorType myOp(tmpMatrix,
-				                  ProgramGlobals::FermionOrBosonEnum::FERMION,
-				                  typename OperatorType::PairType(1,m),
-				                  asign,
-				                  su2related);
+				    ProgramGlobals::FermionOrBosonEnum::FERMION,
+				    typename OperatorType::PairType(1, m),
+				    asign,
+				    su2related);
 				creationMatrix.push_back(myOp);
 			}
 		}
@@ -395,32 +395,36 @@ private:
 	//! Calculate fermionic sign when applying operator c^\dagger_{i\sigma} to
 	//! basis state ket
 	//! N.B.: HAS BEEN CHANGED TO ACCOMODATE FOR MULTIPLE BANDS
-	RealType sign(HilbertState const &ket, int i,SizeType sigma) const
+	RealType sign(HilbertState const& ket, int i, SizeType sigma) const
 	{
-		int value=0;
-		SizeType dofs=2*modelParameters_.orbitals;
-		for (SizeType alpha=0;alpha<dofs;alpha++)
-			value += HilbertSpaceFeAsType::calcNofElectrons(ket,0,i,alpha);
+		int value = 0;
+		SizeType dofs = 2 * modelParameters_.orbitals;
+		for (SizeType alpha = 0; alpha < dofs; alpha++)
+			value += HilbertSpaceFeAsType::calcNofElectrons(ket, 0, i, alpha);
 		// add electron on site 0 if needed
-		if (i>0) value += HilbertSpaceFeAsType::electrons(ket);
+		if (i > 0)
+			value += HilbertSpaceFeAsType::electrons(ket);
 
-		//order for sign is: a up, b up, a down, b down, etc
-		unsigned int x = HilbertSpaceFeAsType::get(ket,i);
-		int spin = sigma/modelParameters_.orbitals;
+		// order for sign is: a up, b up, a down, b down, etc
+		unsigned int x = HilbertSpaceFeAsType::get(ket, i);
+		int spin = sigma / modelParameters_.orbitals;
 		SizeType orb = sigma % modelParameters_.orbitals;
 
-		for (SizeType j=0;j<orb;j++) {
-			for (SizeType k=0;k<2;k++) {
+		for (SizeType j = 0; j < orb; j++) {
+			for (SizeType k = 0; k < 2; k++) {
 				SizeType ind = j + k * modelParameters_.orbitals;
-				int mask = (1<<ind);
-				if (x & mask) value++;
+				int mask = (1 << ind);
+				if (x & mask)
+					value++;
 			}
 		}
-		if (spin==SPIN_DOWN) {
-			int mask = (1<<orb);
-			if (x & mask) value++;
+		if (spin == SPIN_DOWN) {
+			int mask = (1 << orb);
+			if (x & mask)
+				value++;
 		}
-		if (value==0 || value%2==0) return 1.0;
+		if (value == 0 || value % 2 == 0)
+			return 1.0;
 
 		return FERMION_SIGN;
 	}
@@ -428,65 +432,63 @@ private:
 	//! Find c^\dagger_i\gamma\sigma in the natural basis natBasis
 	//! N.B.: HAS BEEN CHANGED TO ACCOMODATE FOR MULTIPLE BANDS
 	void findOperatorMatrices(SparseMatrixType& creationMatrix,
-	                          int i,
-	                          int sigma,
-	                          const HilbertBasisType& natBasis) const
+	    int i,
+	    int sigma,
+	    const HilbertBasisType& natBasis) const
 	{
-		HilbertState bra,ket;
+		HilbertState bra, ket;
 		int n = natBasis.size();
-		MatrixType cm(n,n);
+		MatrixType cm(n, n);
 
-		for (SizeType ii=0;ii<natBasis.size();ii++) {
-			bra=ket=natBasis[ii];
+		for (SizeType ii = 0; ii < natBasis.size(); ii++) {
+			bra = ket = natBasis[ii];
 
-			if (HilbertSpaceFeAsType::isNonZero(ket,i,sigma)) {
+			if (HilbertSpaceFeAsType::isNonZero(ket, i, sigma)) {
 
 			} else {
-				HilbertSpaceFeAsType::create(bra,i,sigma);
-				int jj = PsimagLite::indexOrMinusOne(natBasis,bra);
-				if (jj<0)
+				HilbertSpaceFeAsType::create(bra, i, sigma);
+				int jj = PsimagLite::indexOrMinusOne(natBasis, bra);
+				if (jj < 0)
 					throw PsimagLite::RuntimeError("findOperatorMatrices: internal error\n");
-				if (ii==SizeType(jj)) {
-					std::cerr<<"ii="<<i<<" ket="<<ket<<" bra="<<bra<<" sigma="<<sigma<<"\n";
+				if (ii == SizeType(jj)) {
+					std::cerr << "ii=" << i << " ket=" << ket << " bra=" << bra << " sigma=" << sigma << "\n";
 					throw PsimagLite::RuntimeError("Creation operator cannot be diagonal\n");
 				}
-				cm(ii,jj) =sign(ket,i,sigma);
+				cm(ii, jj) = sign(ket, i, sigma);
 			}
 		}
 
 		SparseMatrixType temp;
-		fullMatrixToCrsMatrix(temp,cm);
-		transposeConjugate(creationMatrix,temp);
+		fullMatrixToCrsMatrix(temp, cm);
+		transposeConjugate(creationMatrix, temp);
 	}
 
 	void setSymmetryRelatedInternal(VectorQnType& qns,
-	                                const HilbertBasisType& basis,
-	                                int n) const
+	    const HilbertBasisType& basis,
+	    int n) const
 	{
 		// find j,m and flavors (do it by hand since we assume n==1)
 		// note: we use 2j instead of j
 		// note: we use m+j instead of m
 		// This assures us that both j and m are SizeType
-		typedef std::pair<SizeType,SizeType> PairType;
+		typedef std::pair<SizeType, SizeType> PairType;
 
 		qns.resize(basis.size(), QnType::zero());
 		VectorSizeType other(2, 0);
 		for (SizeType i = 0; i < basis.size(); ++i) {
-			PairType jmpair(0,0);
+			PairType jmpair(0, 0);
 
-			SizeType na = HilbertSpaceFeAsType::calcNofElectrons(basis[i],0) +
-			        HilbertSpaceFeAsType::calcNofElectrons(basis[i],0+2);
-			SizeType nb = HilbertSpaceFeAsType::calcNofElectrons(basis[i],1) +
-			        HilbertSpaceFeAsType::calcNofElectrons(basis[i],1+2);
+			SizeType na = HilbertSpaceFeAsType::calcNofElectrons(basis[i], 0) + HilbertSpaceFeAsType::calcNofElectrons(basis[i], 0 + 2);
+			SizeType nb = HilbertSpaceFeAsType::calcNofElectrons(basis[i], 1) + HilbertSpaceFeAsType::calcNofElectrons(basis[i], 1 + 2);
 
-			SizeType flavor = na  + 3*nb;
+			SizeType flavor = na + 3 * nb;
 
 			// nup
 			SizeType electronsUp = HilbertSpaceFeAsType::electronsWithGivenSpin(basis[i],
-			                                                                    SPIN_UP);
+			    SPIN_UP);
 			// ndown
 			SizeType electronsDown = HilbertSpaceFeAsType::electronsWithGivenSpin(basis[i],
-			                                                                      SPIN_DOWN);
+			    SPIN_DOWN);
 			SizeType electrons = electronsDown + electronsUp;
 
 			other[0] = electrons;
@@ -499,14 +501,14 @@ private:
 	//! Term is U*\sum_{\alpha}n_i^2
 	void addNiSquared(SparseMatrixType& hmatrix) const
 	{
-		SizeType dofs = 2*modelParameters_.orbitals;
+		SizeType dofs = 2 * modelParameters_.orbitals;
 		SparseMatrixType nmatrix;
 		const VectorOperatorType& cm = creationMatrix_;
 		for (SizeType alpha = 0; alpha < dofs; ++alpha)
 			nmatrix += n(cm[alpha].getCRS());
 
-		SparseMatrixType nmatrixSquared = nmatrix*nmatrix;
-		hmatrix += modelParameters_.hubbardU*nmatrixSquared;
+		SparseMatrixType nmatrixSquared = nmatrix * nmatrix;
+		hmatrix += modelParameters_.hubbardU * nmatrixSquared;
 	}
 
 	// Term is P*\sum_i(0.25*ni_a ni_b +
@@ -519,31 +521,25 @@ private:
 		SparseMatrixType nmatrixB;
 		const VectorOperatorType& cm = creationMatrix_;
 		for (SizeType spin = 0; spin < 2; ++spin) {
-			nmatrixA += n(cm[0 + spin*orbitals].getCRS()); // orbital a
-			nmatrixB += n(cm[1 + spin*orbitals].getCRS()); // orbital b
+			nmatrixA += n(cm[0 + spin * orbitals].getCRS()); // orbital a
+			nmatrixB += n(cm[1 + spin * orbitals].getCRS()); // orbital b
 		}
 
-		SparseMatrixType nmatrixAB = nmatrixA*nmatrixB;
-		hmatrix += static_cast<ComplexOrRealType>(0.25)*modelParameters_.pairHopping*nmatrixAB;
+		SparseMatrixType nmatrixAB = nmatrixA * nmatrixB;
+		hmatrix += static_cast<ComplexOrRealType>(0.25) * modelParameters_.pairHopping * nmatrixAB;
 
-		const SparseMatrixType splusA =
-		        ModelBaseType::naturalOperator("splus", 0, 0).getCRS(); // splus_a
-		const SparseMatrixType splusB =
-		        ModelBaseType::naturalOperator("splus", 0, 1).getCRS(); // splus_b
-		const SparseMatrixType sminusA =
-		        ModelBaseType::naturalOperator("sminus", 0, 0).getCRS(); // sminus_a
-		const SparseMatrixType sminusB =
-		        ModelBaseType::naturalOperator("sminus", 0, 1).getCRS(); // sminus_b
-		SparseMatrixType tmp = splusA*sminusB;
-		tmp += splusB*sminusA;
-		hmatrix += static_cast<ComplexOrRealType>(0.5)*modelParameters_.pairHopping*tmp;
+		const SparseMatrixType splusA = ModelBaseType::naturalOperator("splus", 0, 0).getCRS(); // splus_a
+		const SparseMatrixType splusB = ModelBaseType::naturalOperator("splus", 0, 1).getCRS(); // splus_b
+		const SparseMatrixType sminusA = ModelBaseType::naturalOperator("sminus", 0, 0).getCRS(); // sminus_a
+		const SparseMatrixType sminusB = ModelBaseType::naturalOperator("sminus", 0, 1).getCRS(); // sminus_b
+		SparseMatrixType tmp = splusA * sminusB;
+		tmp += splusB * sminusA;
+		hmatrix += static_cast<ComplexOrRealType>(0.5) * modelParameters_.pairHopping * tmp;
 
-		const SparseMatrixType szA =
-		        ModelBaseType::naturalOperator("sz", 0, 0).getCRS(); // sz_a
-		const SparseMatrixType szB =
-		        ModelBaseType::naturalOperator("sz", 0, 1).getCRS(); // sz_b
-		tmp = szA*szB;
-		hmatrix += modelParameters_.pairHopping*tmp;
+		const SparseMatrixType szA = ModelBaseType::naturalOperator("sz", 0, 0).getCRS(); // sz_a
+		const SparseMatrixType szB = ModelBaseType::naturalOperator("sz", 0, 1).getCRS(); // sz_b
+		tmp = szA * szB;
+		hmatrix += modelParameters_.pairHopping * tmp;
 	}
 
 	static SparseMatrixType n(const SparseMatrixType& c)
@@ -556,13 +552,12 @@ private:
 		return tmpMatrix;
 	}
 
-	ParametersGrapheneType  modelParameters_;
+	ParametersGrapheneType modelParameters_;
 	SizeType statesPerSite_;
 	HilbertBasisType basis_;
 	VectorQnType qq_;
 	VectorOperatorType creationMatrix_;
-}; //class Graphene
+}; // class Graphene
 } // namespace Dmrg
 /*@}*/
 #endif
-
