@@ -82,25 +82,28 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
 #ifndef DMRG_HEISENBERG_MIX_H
 #define DMRG_HEISENBERG_MIX_H
 
-#include <algorithm>
-#include "ParametersModelHeisenberg.h"
-#include "CrsMatrix.h"
-#include "../../Engine/VerySparseMatrix.h"
 #include "../../Engine/ProgramGlobals.h"
 #include "../../Engine/Utils.h"
+#include "../../Engine/VerySparseMatrix.h"
 #include "Aklt.h"
+#include "CrsMatrix.h"
+#include "ParametersModelHeisenberg.h"
+#include <algorithm>
 
-namespace Dmrg {
+namespace Dmrg
+{
 
-template<typename ModelBaseType>
-class HeisenbergMix : public ModelBaseType {
+template <typename ModelBaseType>
+class HeisenbergMix : public ModelBaseType
+{
 
-	static const int NUMBER_OF_ORBITALS=1;
-	static const int DEGREES_OF_FREEDOM=2; // spin up and down
+	static const int NUMBER_OF_ORBITALS = 1;
+	static const int DEGREES_OF_FREEDOM = 2; // spin up and down
 
 public:
 
-	enum class SiteType {SITE_MIDDLE, SITE_BORDER};
+	enum class SiteType { SITE_MIDDLE,
+		SITE_BORDER };
 
 	typedef typename ModelBaseType::ModelHelperType ModelHelperType;
 	typedef typename ModelHelperType::BasisType BasisType;
@@ -109,7 +112,7 @@ public:
 	typedef typename ModelBaseType::LinkType LinkType;
 	typedef typename ModelHelperType::OperatorsType OperatorsType;
 	typedef typename ModelHelperType::RealType RealType;
-	typedef	typename ModelBaseType::VectorType VectorType;
+	typedef typename ModelBaseType::VectorType VectorType;
 	typedef typename ModelBaseType::QnType QnType;
 	typedef typename ModelBaseType::VectorQnType VectorQnType;
 	typedef typename ModelBaseType::BlockType BlockType;
@@ -126,8 +129,8 @@ public:
 	typedef typename OperatorsType::OperatorType OperatorType;
 	typedef typename OperatorType::PairType PairType;
 	typedef typename PsimagLite::Vector<OperatorType>::Type VectorOperatorType;
-	typedef	typename ModelBaseType::MyBasis MyBasis;
-	typedef	typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
+	typedef typename ModelBaseType::MyBasis MyBasis;
+	typedef typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
 	typedef typename ModelBaseType::OpsLabelType OpsLabelType;
 	typedef typename ModelBaseType::OpForLinkType OpForLinkType;
 	typedef typename ModelBaseType::ModelLinksType ModelLinksType;
@@ -135,11 +138,15 @@ public:
 	typedef typename ModelLinksType::AtomKindBase AtomKindBaseType;
 	using ModelParametersType = ParametersModelHeisenberg<RealType, QnType>;
 
-	class AtomKind : public AtomKindBaseType {
+	class AtomKind : public AtomKindBaseType
+	{
 
 	public:
 
-		AtomKind(SizeType n) : n_(n) {}
+		AtomKind(SizeType n)
+		    : n_(n)
+		{
+		}
 
 		virtual SizeType siteToAtomKind(SizeType site) const
 		{
@@ -154,14 +161,14 @@ public:
 	};
 
 	HeisenbergMix(const SolverParamsType& solverParams,
-	              InputValidatorType& io,
-	              const SuperGeometryType& geometry)
+	    InputValidatorType& io,
+	    const SuperGeometryType& geometry)
 	    : ModelBaseType(solverParams,
-	                    geometry,
-	                    io),
-	      modelParameters_(io),
-	      superGeometry_(geometry),
-	      atomKind_(nullptr)
+		geometry,
+		io)
+	    , modelParameters_(io)
+	    , superGeometry_(geometry)
+	    , atomKind_(nullptr)
 	{
 		SizeType n = superGeometry_.numberOfSites();
 		SizeType md = modelParameters_.anisotropyD.size();
@@ -212,9 +219,9 @@ public:
 	 Please look carefully at the following C++ lines:
 	 PSIDOCCOPY $FirstFunctionBelow::MagneticField
 	 */
-	void addDiagonalsInNaturalBasis(SparseMatrixType &hmatrix,
-	                                const BlockType& block,
-	                                RealType time) const
+	void addDiagonalsInNaturalBasis(SparseMatrixType& hmatrix,
+	    const BlockType& block,
+	    RealType time) const
 	{
 		ModelBaseType::additionalOnSiteHamiltonian(hmatrix, block, time);
 
@@ -239,8 +246,7 @@ public:
 				SparseMatrixType Szsquare;
 				RealType tmp = modelParameters_.anisotropyD[site];
 				multiply(Szsquare, sz.getCRS(), sz.getCRS());
-				hmatrix += tmp*Szsquare;
-
+				hmatrix += tmp * Szsquare;
 			}
 
 			// anisotropyE
@@ -248,13 +254,13 @@ public:
 
 				SparseMatrixType splusSquared;
 
-				RealType tmp = 0.5*modelParameters_.anisotropyE[site];
+				RealType tmp = 0.5 * modelParameters_.anisotropyE[site];
 				multiply(splusSquared, splus.getCRS(), splus.getCRS());
-				hmatrix += tmp*splusSquared;
+				hmatrix += tmp * splusSquared;
 
 				SparseMatrixType sminusSquared;
 				transposeConjugate(sminusSquared, splusSquared);
-				hmatrix += tmp*sminusSquared;
+				hmatrix += tmp * sminusSquared;
 			}
 		}
 	}
@@ -293,10 +299,10 @@ protected:
 		PsimagLite::String border = (typeOfSite == SiteType::SITE_BORDER) ? "B" : "";
 
 		OperatorType myOp(tmpMatrix,
-		                  ProgramGlobals::FermionOrBosonEnum::BOSON,
-		                  PairType(2, 2),
-		                  -1,
-		                  su2related);
+		    ProgramGlobals::FermionOrBosonEnum::BOSON,
+		    PairType(2, 2),
+		    -1,
+		    su2related);
 		this->createOpsLabel("splus" + border, indOfKindOfSite).push(myOp);
 		this->makeTrackable("splus" + border);
 
@@ -307,10 +313,10 @@ protected:
 		tmpMatrix = findSzMatrices(site, natBasis);
 		typename OperatorType::Su2RelatedType su2related2;
 		OperatorType myOp2(tmpMatrix,
-		                   ProgramGlobals::FermionOrBosonEnum::BOSON,
-		                   PairType(2, 1),
-		                   1.0/sqrt(2.0),
-		                   su2related2);
+		    ProgramGlobals::FermionOrBosonEnum::BOSON,
+		    PairType(2, 1),
+		    1.0 / sqrt(2.0),
+		    su2related2);
 		this->createOpsLabel("sz" + border, indOfKindOfSite).push(myOp2);
 		this->makeTrackable("sz" + border);
 
@@ -318,18 +324,18 @@ protected:
 		tmpMatrix = findSxMatrices(site, natBasis);
 		typename OperatorType::Su2RelatedType su2related3;
 		OperatorType myOp3(tmpMatrix,
-		                   ProgramGlobals::FermionOrBosonEnum::BOSON,
-		                   PairType(2, 1),
-		                   1.0/sqrt(2.0),
-		                   su2related3);
+		    ProgramGlobals::FermionOrBosonEnum::BOSON,
+		    PairType(2, 1),
+		    1.0 / sqrt(2.0),
+		    su2related3);
 		this->createOpsLabel("sx" + border, indOfKindOfSite).push(myOp3);
 
 		tmpMatrix = findMaximal(site, natBasis);
 		OperatorType myOp4(tmpMatrix,
-		                   ProgramGlobals::FermionOrBosonEnum::BOSON,
-		                   PairType(2, 1),
-		                   1.0/sqrt(2.0),
-		                   su2related3);
+		    ProgramGlobals::FermionOrBosonEnum::BOSON,
+		    PairType(2, 1),
+		    1.0 / sqrt(2.0),
+		    su2related3);
 		this->createOpsLabel("maximal" + border, indOfKindOfSite).push(myOp4);
 
 		return natBasis.size();
@@ -344,55 +350,55 @@ protected:
 
 		OpForLinkType splus("splus");
 
-		auto valueModiferTerm0 = [](ComplexOrRealType& value) { value *=  0.5;};
+		auto valueModiferTerm0 = [](ComplexOrRealType& value) { value *= 0.5; };
 
-		typename ModelTermType::Su2Properties su2properties(2, -1, 2);
-		spsm.push(splus, 'N', splus, 'C', valueModiferTerm0, su2properties);
+		spsm.push(splus, 'N', splus, 'C', valueModiferTerm0);
 
 		ModelTermType& szsz = ModelBaseType::createTerm("szsz");
 
 		OpForLinkType sz("sz");
-		szsz.push(sz, 'N', sz, 'N', typename ModelTermType::Su2Properties(2, 0.5));
+		szsz.push(sz, 'N', sz, 'N');
 
 		OpForLinkType splusB("splusB");
 
 		const bool wantsHermit = true;
 		ModelTermType& spsmB1 = ModelBaseType::createTerm("SplusSminusB1",
-		                                                  wantsHermit,
-		                                                  "SplusSminus");
-		spsmB1.push(splusB, 'N', splus, 'C', valueModiferTerm0, su2properties);
+		    wantsHermit,
+		    "SplusSminus");
+		spsmB1.push(splusB, 'N', splus, 'C', valueModiferTerm0);
 
 		ModelTermType& spsmB2 = ModelBaseType::createTerm("SplusSminusB2",
-		                                                  wantsHermit,
-		                                                  "SplusSminus");
-		spsmB2.push(splus, 'N', splusB, 'C', valueModiferTerm0, su2properties);
+		    wantsHermit,
+		    "SplusSminus");
+		spsmB2.push(splus, 'N', splusB, 'C', valueModiferTerm0);
 
 		OpForLinkType szB("szB");
 
 		ModelTermType& szszB1 = ModelBaseType::createTerm("szszB1",
-		                                                  wantsHermit,
-		                                                  "szsz");
-		szszB1.push(szB, 'N', sz, 'N', typename ModelTermType::Su2Properties(2, 0.5));
+		    wantsHermit,
+		    "szsz");
+		szszB1.push(szB, 'N', sz, 'N');
 
 		ModelTermType& szszB2 = ModelBaseType::createTerm("szszB2",
-		                                                  wantsHermit,
-		                                                  "szsz");
-		szszB2.push(sz, 'N', szB, 'N', typename ModelTermType::Su2Properties(2, 0.5));
+		    wantsHermit,
+		    "szsz");
+		szszB2.push(sz, 'N', szB, 'N');
 	}
 
 private:
 
 	void addMagneticField(SparseMatrixType& hmatrix,
-	                      char c,
-	                      SizeType site) const
+	    char c,
+	    SizeType site) const
 	{
 		assert(c == 'X' || c == 'Z');
 
 		const SizeType linSize = superGeometry_.numberOfSites();
 		const VectorRealType& v = (c == 'X') ? modelParameters_.magneticFieldX
-		                                     : modelParameters_.magneticFieldZ;
+						     : modelParameters_.magneticFieldZ;
 
-		if (v.size() != linSize) return;
+		if (v.size() != linSize)
+			return;
 
 		assert(site < v.size());
 		RealType tmp = v[site];
@@ -401,15 +407,15 @@ private:
 		const OperatorType& sz = ModelBaseType::naturalOperator("sz", site, 0);
 
 		if (c == 'Z') {
-			hmatrix += tmp*sz.getCRS();
+			hmatrix += tmp * sz.getCRS();
 			return;
 		}
 
 		assert(c == 'X');
 		const OperatorType& splus = ModelBaseType::naturalOperator("splus", site, 0);
 		constexpr RealType zeroPointFive = 0.5;
-		hmatrix += zeroPointFive*tmp*splus.getCRS();
-		hmatrix += zeroPointFive*tmp*sminus.getCRS();
+		hmatrix += zeroPointFive * tmp * splus.getCRS();
+		hmatrix += zeroPointFive * tmp * sminus.getCRS();
 	}
 
 	// atomKind_ is not setup here yet, so do not call it
@@ -417,7 +423,7 @@ private:
 	{
 		const SizeType n = superGeometry_.numberOfSites();
 		return (site == 0 || site == n - 1) ? modelParameters_.twiceTheSpinBorder
-		                                    : modelParameters_.twiceTheSpin;
+						    : modelParameters_.twiceTheSpin;
 	}
 
 	void setBasis(HilbertBasisType& natBasis, SizeType site) const
@@ -425,31 +431,33 @@ private:
 		const SizeType twiceTheSpin = getSpin(site);
 		const SizeType total = twiceTheSpin + 1;
 		natBasis.resize(total);
-		for (SizeType i = 0; i < total; ++i) natBasis[i] = i;
+		for (SizeType i = 0; i < total; ++i)
+			natBasis[i] = i;
 	}
 
 	//! Find S^+_site in the natural basis natBasis
 	SparseMatrixType findSplusMatrices(SizeType site,
-	                                   const HilbertBasisType& natBasis) const
+	    const HilbertBasisType& natBasis) const
 	{
 		SizeType total = natBasis.size();
-		MatrixType cm(total,total);
+		MatrixType cm(total, total);
 		const SizeType twiceTheSpin = getSpin(site);
-		RealType j = 0.5*twiceTheSpin;
+		RealType j = 0.5 * twiceTheSpin;
 		SizeType bits = 1 + ProgramGlobals::logBase2(twiceTheSpin);
 		SizeType mask = 1;
 		mask <<= bits; // mask = 2^bits
 		assert(mask > 0);
 		mask--;
 
-		for (SizeType ii=0;ii<total;ii++) {
+		for (SizeType ii = 0; ii < total; ii++) {
 			SizeType ket = natBasis[ii];
 
 			SizeType ketsite = ket & mask;
 
 			assert(ketsite == ket);
 			SizeType brasite = ketsite + 1;
-			if (brasite >= twiceTheSpin + 1) continue;
+			if (brasite >= twiceTheSpin + 1)
+				continue;
 
 			SizeType bra = ket & (~mask);
 			assert(bra == 0);
@@ -457,10 +465,10 @@ private:
 			assert(bra == brasite);
 
 			RealType m = ketsite - j;
-			RealType x = j*(j+1)-m*(m+1);
-			assert(x>=0);
+			RealType x = j * (j + 1) - m * (m + 1);
+			assert(x >= 0);
 
-			cm(ket,bra) = sqrt(x);
+			cm(ket, bra) = sqrt(x);
 		}
 
 		SparseMatrixType operatorMatrix(cm);
@@ -469,25 +477,25 @@ private:
 
 	//! Find S^z_i in the natural basis natBasis
 	SparseMatrixType findSzMatrices(SizeType site,
-	                                const HilbertBasisType& natBasis) const
+	    const HilbertBasisType& natBasis) const
 	{
 		SizeType total = natBasis.size();
-		MatrixType cm(total,total);
+		MatrixType cm(total, total);
 		const SizeType twiceTheSpin = getSpin(site);
-		RealType j = 0.5*twiceTheSpin;
+		RealType j = 0.5 * twiceTheSpin;
 		SizeType bits = ProgramGlobals::logBase2(twiceTheSpin) + 1;
 		SizeType mask = 1;
 		mask <<= bits; // mask = 2^bits
 		assert(mask > 0);
 		mask--;
 
-		for (SizeType ii=0;ii<total;ii++) {
+		for (SizeType ii = 0; ii < total; ii++) {
 			SizeType ket = natBasis[ii];
 
 			SizeType ketsite = ket & mask;
 			assert(ketsite == ket);
 			RealType m = ketsite - j;
-			cm(ket,ket) = m;
+			cm(ket, ket) = m;
 		}
 
 		SparseMatrixType operatorMatrix(cm);
@@ -496,10 +504,10 @@ private:
 
 	//! Find Maximal_i in the natural basis natBasis
 	SparseMatrixType findMaximal(SizeType site,
-	                             const HilbertBasisType& natBasis) const
+	    const HilbertBasisType& natBasis) const
 	{
 		SizeType total = natBasis.size();
-		MatrixType cm(total,total);
+		MatrixType cm(total, total);
 		const SizeType twiceTheSpin = getSpin(site);
 		SizeType bits = ProgramGlobals::logBase2(twiceTheSpin) + 1;
 		SizeType mask = 1;
@@ -507,7 +515,7 @@ private:
 		assert(mask > 0);
 		mask--;
 
-		for (SizeType ii=0;ii<total;ii++) {
+		for (SizeType ii = 0; ii < total; ii++) {
 			SizeType ket = natBasis[ii];
 
 			SizeType ketsite = ket & mask;
@@ -521,41 +529,39 @@ private:
 		return operatorMatrix;
 	}
 
-
 	SparseMatrixType findSxMatrices(SizeType site,
-	                                const HilbertBasisType& natBasis) const
+	    const HilbertBasisType& natBasis) const
 	{
 		SparseMatrixType Splus_temp = findSplusMatrices(site, natBasis);
-		SparseMatrixType Sminus_temp,Sx;
-		transposeConjugate(Sminus_temp,Splus_temp);
-		RealType tmp=0.5;
+		SparseMatrixType Sminus_temp, Sx;
+		transposeConjugate(Sminus_temp, Splus_temp);
+		RealType tmp = 0.5;
 
-		Sx = tmp*Splus_temp;
-		Sx += tmp*Sminus_temp;
+		Sx = tmp * Splus_temp;
+		Sx += tmp * Sminus_temp;
 
 		return Sx;
 	}
 
 	void setSymmetryRelated(VectorQnType& qns,
-	                        const HilbertBasisType& basis,
-	                        SizeType offset,
-	                        SiteType) const
+	    const HilbertBasisType& basis,
+	    SizeType offset,
+	    SiteType) const
 	{
 		// find j,m and flavors (do it by hand since we assume n==1)
 		// note: we use 2j instead of j
 		// note: we use m+j instead of m
 		// This assures us that both j and m are SizeType
-		typedef std::pair<SizeType,SizeType> PairType;
+		typedef std::pair<SizeType, SizeType> PairType;
 
 		bool isCanonical = (ModelBaseType::targetQuantum().sizeOfOther() == 1);
 
 		if (isCanonical && !modelParameters_.magneticFieldX.empty())
-			err(PsimagLite::String(__FILE__) +
-			    ": MagneticFieldX CANNOT be canonical. Please " +
-			    "delete the TargetSzPlusConst= from the input file\n");
+			err(PsimagLite::String(__FILE__) + ": MagneticFieldX CANNOT be canonical. Please " + "delete the TargetSzPlusConst= from the input file\n");
 
 		VectorSizeType other;
-		if (isCanonical) other.resize(1, 0);
+		if (isCanonical)
+			other.resize(1, 0);
 		QnType::ifPresentOther0IsElectrons = false;
 		qns.resize(basis.size() + offset, QnType::zero());
 		for (SizeType i = 0; i < basis.size(); ++i) {
@@ -574,5 +580,4 @@ private:
 
 } // namespace Dmrg
 /*@}*/
-#endif //DMRG_HEISENBERG_MIX_H
-
+#endif // DMRG_HEISENBERG_MIX_H
