@@ -80,23 +80,25 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
 #ifndef DMRG_MODEL_HEISENBERG_HEADER_H
 #define DMRG_MODEL_HEISENBERG_HEADER_H
 
-#include "Aklt.h"
-#include <algorithm>
-#include "ParametersModelHeisenberg.h"
-#include "CrsMatrix.h"
-#include "../../Engine/VerySparseMatrix.h"
-#include "../../Engine/SpinSquaredHelper.h"
-#include "../../Engine/SpinSquared.h"
 #include "../../Engine/ProgramGlobals.h"
+#include "../../Engine/SpinSquared.h"
+#include "../../Engine/SpinSquaredHelper.h"
 #include "../../Engine/Utils.h"
+#include "../../Engine/VerySparseMatrix.h"
+#include "Aklt.h"
+#include "CrsMatrix.h"
+#include "ParametersModelHeisenberg.h"
+#include <algorithm>
 
-namespace Dmrg {
+namespace Dmrg
+{
 
-template<typename ModelBaseType>
-class ModelHeisenberg : public ModelBaseType {
+template <typename ModelBaseType>
+class ModelHeisenberg : public ModelBaseType
+{
 
-	static const int NUMBER_OF_ORBITALS=1;
-	static const int DEGREES_OF_FREEDOM=2; // spin up and down
+	static const int NUMBER_OF_ORBITALS = 1;
+	static const int DEGREES_OF_FREEDOM = 2; // spin up and down
 
 public:
 
@@ -107,7 +109,7 @@ public:
 	typedef typename ModelBaseType::LinkType LinkType;
 	typedef typename ModelHelperType::OperatorsType OperatorsType;
 	typedef typename ModelHelperType::RealType RealType;
-	typedef	typename ModelBaseType::VectorType VectorType;
+	typedef typename ModelBaseType::VectorType VectorType;
 	typedef typename ModelBaseType::QnType QnType;
 	typedef typename ModelBaseType::VectorQnType VectorQnType;
 	typedef typename ModelBaseType::BlockType BlockType;
@@ -124,25 +126,25 @@ public:
 	typedef typename OperatorsType::OperatorType OperatorType;
 	typedef typename OperatorType::PairType PairType;
 	typedef typename PsimagLite::Vector<OperatorType>::Type VectorOperatorType;
-	typedef	typename ModelBaseType::MyBasis MyBasis;
-	typedef	typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
+	typedef typename ModelBaseType::MyBasis MyBasis;
+	typedef typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
 	typedef typename ModelBaseType::OpsLabelType OpsLabelType;
 	typedef typename ModelBaseType::OpForLinkType OpForLinkType;
 	typedef Aklt<ModelBaseType> AkltType;
 	using ModelParametersType = ParametersModelHeisenberg<RealType, QnType>;
 
 	ModelHeisenberg(const SolverParamsType& solverParams,
-	                InputValidatorType& io,
-	                const SuperGeometryType& geometry,
-	                PsimagLite::String additional)
+	    InputValidatorType& io,
+	    const SuperGeometryType& geometry,
+	    PsimagLite::String additional)
 	    : ModelBaseType(solverParams,
-	                    geometry,
-	                    io),
-	      modelParameters_(io),
-	      superGeometry_(geometry),
-	      additional_(additional),
-	      spinSquared_(spinSquaredHelper_,NUMBER_OF_ORBITALS,DEGREES_OF_FREEDOM),
-	      aklt_(*this, additional)
+		geometry,
+		io)
+	    , modelParameters_(io)
+	    , superGeometry_(geometry)
+	    , additional_(additional)
+	    , spinSquared_(spinSquaredHelper_, NUMBER_OF_ORBITALS, DEGREES_OF_FREEDOM)
+	    , aklt_(*this, additional)
 	{
 		SizeType n = superGeometry_.numberOfSites();
 		SizeType md = modelParameters_.anisotropyD.size();
@@ -183,9 +185,9 @@ public:
 	 Please look carefully at the following C++ lines:
 	 PSIDOCCOPY $FirstFunctionBelow::MagneticField
 	 */
-	void addDiagonalsInNaturalBasis(SparseMatrixType &hmatrix,
-	                                const BlockType& block,
-	                                RealType time) const
+	void addDiagonalsInNaturalBasis(SparseMatrixType& hmatrix,
+	    const BlockType& block,
+	    RealType time) const
 	{
 		ModelBaseType::additionalOnSiteHamiltonian(hmatrix, block, time);
 
@@ -210,8 +212,7 @@ public:
 				SparseMatrixType Szsquare;
 				RealType tmp = modelParameters_.anisotropyD[site];
 				multiply(Szsquare, sz.getCRS(), sz.getCRS());
-				hmatrix += tmp*Szsquare;
-
+				hmatrix += tmp * Szsquare;
 			}
 
 			// anisotropyE
@@ -219,13 +220,13 @@ public:
 
 				SparseMatrixType splusSquared;
 
-				RealType tmp = 0.5*modelParameters_.anisotropyE[site];
+				RealType tmp = 0.5 * modelParameters_.anisotropyE[site];
 				multiply(splusSquared, splus.getCRS(), splus.getCRS());
-				hmatrix += tmp*splusSquared;
+				hmatrix += tmp * splusSquared;
 
 				SparseMatrixType sminusSquared;
 				transposeConjugate(sminusSquared, splusSquared);
-				hmatrix += tmp*sminusSquared;
+				hmatrix += tmp * sminusSquared;
 			}
 		}
 	}
@@ -238,28 +239,29 @@ protected:
 		BlockType block(1, site);
 		SizeType total = utils::powUint(modelParameters_.twiceTheSpin + 1, block.size());
 		HilbertBasisType natBasis(total);
-		for (SizeType i = 0; i < total; ++i) natBasis[i] = i;
+		for (SizeType i = 0; i < total; ++i)
+			natBasis[i] = i;
 
 		setSymmetryRelated(qns, natBasis, block.size());
 
-		for (SizeType i=0;i<block.size();i++) {
+		for (SizeType i = 0; i < block.size(); i++) {
 			// Set the operators S^+_i in the natural basis
-			SparseMatrixType tmpMatrix = findSplusMatrices(i,natBasis);
+			SparseMatrixType tmpMatrix = findSplusMatrices(i, natBasis);
 
 			typename OperatorType::Su2RelatedType su2related;
-			su2related.source.push_back(i*DEGREES_OF_FREEDOM);
-			su2related.source.push_back(i*DEGREES_OF_FREEDOM+NUMBER_OF_ORBITALS);
-			su2related.source.push_back(i*DEGREES_OF_FREEDOM);
+			su2related.source.push_back(i * DEGREES_OF_FREEDOM);
+			su2related.source.push_back(i * DEGREES_OF_FREEDOM + NUMBER_OF_ORBITALS);
+			su2related.source.push_back(i * DEGREES_OF_FREEDOM);
 			su2related.transpose.push_back(-1);
 			su2related.transpose.push_back(-1);
 			su2related.transpose.push_back(1);
 			su2related.offset = NUMBER_OF_ORBITALS;
 
 			OperatorType myOp(tmpMatrix,
-			                  ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                  PairType(2, 2),
-			                  -1,
-			                  su2related);
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    PairType(2, 2),
+			    -1,
+			    su2related);
 			this->createOpsLabel("splus").push(myOp);
 			if (additional_ != "2")
 				this->makeTrackable("splus");
@@ -268,24 +270,24 @@ protected:
 			this->createOpsLabel("sminus").push(myOp);
 
 			// Set the operators S^z_i in the natural basis
-			tmpMatrix = findSzMatrices(i,natBasis);
+			tmpMatrix = findSzMatrices(i, natBasis);
 			typename OperatorType::Su2RelatedType su2related2;
 			OperatorType myOp2(tmpMatrix,
-			                   ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                   PairType(2, 1),
-			                   1.0/sqrt(2.0),
-			                   su2related2);
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    PairType(2, 1),
+			    1.0 / sqrt(2.0),
+			    su2related2);
 			this->createOpsLabel("sz").push(myOp2);
 			this->makeTrackable("sz");
 
 			// Set the operators S^x_i in the natural basis
-			tmpMatrix = findSxOrSyBarMatrices(i,natBasis, "sx");
+			tmpMatrix = findSxOrSyBarMatrices(i, natBasis, "sx");
 			typename OperatorType::Su2RelatedType su2related3;
 			OperatorType myOp3(tmpMatrix,
-			                   ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                   PairType(2, 1),
-			                   1.0/sqrt(2.0),
-			                   su2related3);
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    PairType(2, 1),
+			    1.0 / sqrt(2.0),
+			    su2related3);
 			this->createOpsLabel("sx").push(myOp3);
 
 			if (additional_ == "Anisotropic" || additional_ == "2")
@@ -294,10 +296,10 @@ protected:
 			// Set the operators S^ybar_i in the natural basis
 			tmpMatrix = findSxOrSyBarMatrices(i, natBasis, "sybar");
 			OperatorType syBarOp(tmpMatrix,
-			                     ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                     PairType(0, 0),
-			                     1,
-			                     su2related3);
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    PairType(0, 0),
+			    1,
+			    su2related3);
 			this->createOpsLabel("sybar").push(syBarOp);
 
 			if (additional_ == "2")
@@ -307,10 +309,10 @@ protected:
 
 			tmpMatrix = findMaximal(i, natBasis);
 			OperatorType myOp4(tmpMatrix,
-			                   ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                   PairType(2, 1),
-			                   1.0/sqrt(2.0),
-			                   su2related3);
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    PairType(2, 1),
+			    1.0 / sqrt(2.0),
+			    su2related3);
 			this->createOpsLabel("maximal").push(myOp4);
 		}
 	}
@@ -329,10 +331,9 @@ protected:
 
 		OpForLinkType splus("splus");
 
-		auto valueModiferTerm0 = [](ComplexOrRealType& value) { value *= 0.5;};
+		auto valueModiferTerm0 = [](ComplexOrRealType& value) { value *= 0.5; };
 
-		typename ModelTermType::Su2Properties su2properties(2, -1, 2);
-		spsm.push(splus, 'N', splus, 'C', valueModiferTerm0, su2properties);
+		spsm.push(splus, 'N', splus, 'C', valueModiferTerm0);
 
 		connectionSzSz();
 
@@ -351,16 +352,17 @@ protected:
 private:
 
 	void addMagneticField(SparseMatrixType& hmatrix,
-	                      char c,
-	                      SizeType site) const
+	    char c,
+	    SizeType site) const
 	{
 		assert(c == 'X' || c == 'Z');
 
 		const SizeType linSize = superGeometry_.numberOfSites();
 		const VectorRealType& v = (c == 'X') ? modelParameters_.magneticFieldX
-		                                     : modelParameters_.magneticFieldZ;
+						     : modelParameters_.magneticFieldZ;
 
-		if (v.size() != linSize) return;
+		if (v.size() != linSize)
+			return;
 
 		assert(site < v.size());
 		RealType tmp = v[site];
@@ -369,15 +371,15 @@ private:
 		const OperatorType& sz = ModelBaseType::naturalOperator("sz", site, 0);
 
 		if (c == 'Z') {
-			hmatrix += tmp*sz.getCRS();
+			hmatrix += tmp * sz.getCRS();
 			return;
 		}
 
 		assert(c == 'X');
 		const OperatorType& splus = ModelBaseType::naturalOperator("splus", site, 0);
 		constexpr RealType zeroPointFive = 0.5;
-		hmatrix += zeroPointFive*tmp*splus.getCRS();
-		hmatrix += zeroPointFive*tmp*sminus.getCRS();
+		hmatrix += zeroPointFive * tmp * splus.getCRS();
+		hmatrix += zeroPointFive * tmp * sminus.getCRS();
 	}
 
 	void fillModelLinks2()
@@ -386,7 +388,7 @@ private:
 		OpForLinkType sx("sx");
 		sxsx.push(sx, 'N', sx, 'N');
 
-		auto sybarsybarModifier = [](ComplexOrRealType& value) { value *= -1.0;};
+		auto sybarsybarModifier = [](ComplexOrRealType& value) { value *= -1.0; };
 		ModelTermType& sybarsybar = ModelBaseType::createTerm("sybarsybar");
 		OpForLinkType sybar("sybar");
 		sybarsybar.push(sybar, 'N', sybar, 'N', sybarsybarModifier);
@@ -404,40 +406,41 @@ private:
 
 	//! Find S^+_site in the natural basis natBasis
 	SparseMatrixType findSplusMatrices(SizeType site,
-	                                   const HilbertBasisType& natBasis) const
+	    const HilbertBasisType& natBasis) const
 	{
 		SizeType total = natBasis.size();
-		MatrixType cm(total,total);
-		RealType j = 0.5*modelParameters_.twiceTheSpin;
+		MatrixType cm(total, total);
+		RealType j = 0.5 * modelParameters_.twiceTheSpin;
 		SizeType bitsForOneSite = utils::bitSizeOfInteger(modelParameters_.twiceTheSpin);
 		SizeType bits = 1 + ProgramGlobals::logBase2(modelParameters_.twiceTheSpin);
 		SizeType mask = 1;
 		mask <<= bits; // mask = 2^bits
 		assert(mask > 0);
 		mask--;
-		mask <<= (site*bitsForOneSite);
+		mask <<= (site * bitsForOneSite);
 
-		for (SizeType ii=0;ii<total;ii++) {
+		for (SizeType ii = 0; ii < total; ii++) {
 			SizeType ket = natBasis[ii];
 
 			SizeType ketsite = ket & mask;
-			ketsite >>= (site*bitsForOneSite);
+			ketsite >>= (site * bitsForOneSite);
 
 			assert(ketsite == ket);
 			SizeType brasite = ketsite + 1;
-			if (brasite >= modelParameters_.twiceTheSpin+1) continue;
+			if (brasite >= modelParameters_.twiceTheSpin + 1)
+				continue;
 
 			SizeType bra = ket & (~mask);
 			assert(bra == 0);
-			brasite <<= (site*bitsForOneSite);
+			brasite <<= (site * bitsForOneSite);
 			bra |= brasite;
 			assert(bra == brasite);
 
 			RealType m = ketsite - j;
-			RealType x = j*(j+1)-m*(m+1);
-			assert(x>=0);
+			RealType x = j * (j + 1) - m * (m + 1);
+			assert(x >= 0);
 
-			cm(ket,bra) = sqrt(x);
+			cm(ket, bra) = sqrt(x);
 		}
 
 		SparseMatrixType operatorMatrix(cm);
@@ -446,27 +449,27 @@ private:
 
 	//! Find S^z_i in the natural basis natBasis
 	SparseMatrixType findSzMatrices(SizeType site,
-	                                const HilbertBasisType& natBasis) const
+	    const HilbertBasisType& natBasis) const
 	{
 		SizeType total = natBasis.size();
-		MatrixType cm(total,total);
-		RealType j = 0.5*modelParameters_.twiceTheSpin;
+		MatrixType cm(total, total);
+		RealType j = 0.5 * modelParameters_.twiceTheSpin;
 		SizeType bitsForOneSite = utils::bitSizeOfInteger(modelParameters_.twiceTheSpin);
 		SizeType bits = ProgramGlobals::logBase2(modelParameters_.twiceTheSpin) + 1;
 		SizeType mask = 1;
 		mask <<= bits; // mask = 2^bits
 		assert(mask > 0);
 		mask--;
-		mask <<= (site*bitsForOneSite);
+		mask <<= (site * bitsForOneSite);
 
-		for (SizeType ii=0;ii<total;ii++) {
+		for (SizeType ii = 0; ii < total; ii++) {
 			SizeType ket = natBasis[ii];
 
 			SizeType ketsite = ket & mask;
-			ketsite >>= (site*bitsForOneSite);
+			ketsite >>= (site * bitsForOneSite);
 			assert(ketsite == ket);
 			RealType m = ketsite - j;
-			cm(ket,ket) = m;
+			cm(ket, ket) = m;
 		}
 
 		SparseMatrixType operatorMatrix(cm);
@@ -475,23 +478,23 @@ private:
 
 	//! Find Maximal_i in the natural basis natBasis
 	SparseMatrixType findMaximal(SizeType site,
-	                             const HilbertBasisType& natBasis) const
+	    const HilbertBasisType& natBasis) const
 	{
 		SizeType total = natBasis.size();
-		MatrixType cm(total,total);
+		MatrixType cm(total, total);
 		SizeType bitsForOneSite = utils::bitSizeOfInteger(modelParameters_.twiceTheSpin);
 		SizeType bits = ProgramGlobals::logBase2(modelParameters_.twiceTheSpin) + 1;
 		SizeType mask = 1;
 		mask <<= bits; // mask = 2^bits
 		assert(mask > 0);
 		mask--;
-		mask <<= (site*bitsForOneSite);
+		mask <<= (site * bitsForOneSite);
 
-		for (SizeType ii=0;ii<total;ii++) {
+		for (SizeType ii = 0; ii < total; ii++) {
 			SizeType ket = natBasis[ii];
 
 			SizeType ketsite = ket & mask;
-			ketsite >>= (site*bitsForOneSite);
+			ketsite >>= (site * bitsForOneSite);
 			assert(ketsite == ket);
 			if (ketsite != modelParameters_.twiceTheSpin)
 				continue;
@@ -502,49 +505,45 @@ private:
 		return operatorMatrix;
 	}
 
-
 	SparseMatrixType findSxOrSyBarMatrices(SizeType site,
-	                                       const HilbertBasisType& natBasis,
-	                                       PsimagLite::String what) const
+	    const HilbertBasisType& natBasis,
+	    PsimagLite::String what) const
 	{
 		if (what != "sx" && what != "sybar")
 			err("findSxOrSyBarMatrices: don't know how to calculate " + what + "\n");
 
 		const RealType sign = (what == "sx") ? 1.0 : -1.0;
-		SparseMatrixType Splus_temp=findSplusMatrices(site,natBasis);
-		SparseMatrixType Sminus_temp,Sx;
-		transposeConjugate(Sminus_temp,Splus_temp);
+		SparseMatrixType Splus_temp = findSplusMatrices(site, natBasis);
+		SparseMatrixType Sminus_temp, Sx;
+		transposeConjugate(Sminus_temp, Splus_temp);
 		const RealType tmp = 0.5;
 
-		Sx = tmp*Splus_temp;
-		Sx += sign*tmp*Sminus_temp;
+		Sx = tmp * Splus_temp;
+		Sx += sign * tmp * Sminus_temp;
 
 		return Sx;
 	}
 
 	void setSymmetryRelated(VectorQnType& qns,
-	                        const HilbertBasisType& basis,
-	                        int n) const
+	    const HilbertBasisType& basis,
+	    int n) const
 	{
 		// find j,m and flavors (do it by hand since we assume n==1)
 		// note: we use 2j instead of j
 		// note: we use m+j instead of m
 		// This assures us that both j and m are SizeType
-		typedef std::pair<SizeType,SizeType> PairType;
+		typedef std::pair<SizeType, SizeType> PairType;
 
 		bool isCanonical = (ModelBaseType::targetQuantum().sizeOfOther() == 1);
 		if (isCanonical && additional_ == "Anisotropic")
-			err(PsimagLite::String(__FILE__) +
-			    ": Anisotropic sub-model CANNOT be canonical. Please " +
-			    "delete the TargetSzPlusConst= from the input file\n");
+			err(PsimagLite::String(__FILE__) + ": Anisotropic sub-model CANNOT be canonical. Please " + "delete the TargetSzPlusConst= from the input file\n");
 
 		if (isCanonical && !modelParameters_.magneticFieldX.empty())
-			err(PsimagLite::String(__FILE__) +
-			    ": MagneticFieldX CANNOT be canonical. Please " +
-			    "delete the TargetSzPlusConst= from the input file\n");
+			err(PsimagLite::String(__FILE__) + ": MagneticFieldX CANNOT be canonical. Please " + "delete the TargetSzPlusConst= from the input file\n");
 
 		VectorSizeType other;
-		if (isCanonical) other.resize(1, 0);
+		if (isCanonical)
+			other.resize(1, 0);
 		QnType::ifPresentOther0IsElectrons = false;
 		qns.resize(basis.size(), QnType::zero());
 		for (SizeType i = 0; i < basis.size(); ++i) {
@@ -558,31 +557,31 @@ private:
 
 	SizeType getSzPlusConst(SizeType ket, SizeType n) const
 	{
-		if (n == 1) return ket;
+		if (n == 1)
+			return ket;
 
 		SizeType bitsForOneSite = utils::bitSizeOfInteger(modelParameters_.twiceTheSpin);
 
 		SizeType sum = 0;
 		for (SizeType site = 0; site < n; ++site) {
 			SizeType mask = modelParameters_.twiceTheSpin;
-			mask <<= (site*bitsForOneSite);
+			mask <<= (site * bitsForOneSite);
 			SizeType ketsite = ket & mask;
-			ketsite >>= (site*bitsForOneSite);
+			ketsite >>= (site * bitsForOneSite);
 			sum += ketsite;
 		}
 
 		return sum;
 	}
 
-	ModelParametersType  modelParameters_;
+	ModelParametersType modelParameters_;
 	const SuperGeometryType& superGeometry_;
-	SpinSquaredHelper<RealType,WordType> spinSquaredHelper_;
+	SpinSquaredHelper<RealType, WordType> spinSquaredHelper_;
 	PsimagLite::String additional_;
-	SpinSquared<SpinSquaredHelper<RealType,WordType> > spinSquared_;
+	SpinSquared<SpinSquaredHelper<RealType, WordType>> spinSquared_;
 	AkltType aklt_;
 }; // class ModelHeisenberg
 
 } // namespace Dmrg
 /*@}*/
-#endif //DMRG_MODEL_HEISENBERG_HEADER_H
-
+#endif // DMRG_MODEL_HEISENBERG_HEADER_H
