@@ -81,20 +81,22 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
  */
 #ifndef PARAMETERSMODELHEISENBERG_H
 #define PARAMETERSMODELHEISENBERG_H
-#include "Vector.h"
 #include "../../Engine/ParametersModelBase.h"
+#include "Vector.h"
 
-namespace Dmrg {
+namespace Dmrg
+{
 //! Heisenberg Model Parameters
-template<typename RealType, typename QnType>
+template <typename RealType, typename QnType>
 struct ParametersModelHeisenberg : public ParametersModelBase<RealType, QnType> {
 
 	typedef ParametersModelBase<RealType, QnType> BaseType;
 	typedef typename PsimagLite::Vector<RealType>::Type VectorRealType;
 	// no connectors here, connectors are handled by the geometry
-	template<typename IoInputType>
+	template <typename IoInputType>
 	ParametersModelHeisenberg(IoInputType& io)
-	    : BaseType(io, false), twiceTheSpinBorder(0)
+	    : BaseType(io, false)
+	    , twiceTheSpinBorder(0)
 	{
 		PsimagLite::String model;
 		io.readline(model, "Model=");
@@ -121,17 +123,44 @@ struct ParametersModelHeisenberg : public ParametersModelBase<RealType, QnType>
 			magneticFieldZ.clear();
 		}
 
+		// throw if supplying MagneticField label
+		bool invalidLabel = false;
 		try {
-			io.read(anisotropyD,"AnisotropyD");
-		} catch (std::exception&) {}
+			VectorRealType tmpVector;
+			io.read(tmpVector, "MagneticField=");
+			invalidLabel = true;
+		} catch (std::exception&) {
+		}
+
+		if (invalidLabel) {
+			throw PsimagLite::RuntimeError("MagneticField label is no longer supported.\n" + PsimagLite::String("Please use MagneticField[XZ] instead\n"));
+		}
+
+		// throw if supplying MagneticFieldDirection label
+		try {
+			PsimagLite::String tmpStr;
+			io.readline(tmpStr, "MagneticFieldDirection=");
+			invalidLabel = true;
+		} catch (std::exception&) {
+		}
+
+		if (invalidLabel) {
+			throw PsimagLite::RuntimeError("MagneticFieldDirection label is no longer supported.\n" + PsimagLite::String("Please use MagneticField[XZ] instead\n"));
+		}
 
 		try {
-			io.read(anisotropyE,"AnisotropyE");
-		} catch (std::exception&) {}
+			io.read(anisotropyD, "AnisotropyD");
+		} catch (std::exception&) {
+		}
+
+		try {
+			io.read(anisotropyE, "AnisotropyE");
+		} catch (std::exception&) {
+		}
 	}
 
 	void write(PsimagLite::String label1,
-	           PsimagLite::IoNg::Out::Serializer& io) const
+	    PsimagLite::IoNg::Out::Serializer& io) const
 	{
 		PsimagLite::String label = label1 + "/ParametersModelHeisenberg";
 		io.createGroup(label);
@@ -145,26 +174,26 @@ struct ParametersModelHeisenberg : public ParametersModelBase<RealType, QnType>
 
 	static void checkMagneticField(SizeType s, unsigned char c, SizeType n)
 	{
-		if (s == 0 || s == n) return;
+		if (s == 0 || s == n)
+			return;
 
 		PsimagLite::String msg("ModelHeisenberg: If provided, ");
-		msg += " MagneticField" + ttos(c) + " must be a vector of " +
-		        ttos(n) + " entries.\n";
+		msg += " MagneticField" + ttos(c) + " must be a vector of " + ttos(n) + " entries.\n";
 		err(msg);
 	}
 
 	//! Function that prints model parameters to stream os
-	friend std::ostream& operator<<(std::ostream &os,
-	                                const ParametersModelHeisenberg& parameters)
+	friend std::ostream& operator<<(std::ostream& os,
+	    const ParametersModelHeisenberg& parameters)
 	{
 		if (!parameters.magneticFieldX.empty())
-			os<<"MagneticFieldX="<<parameters.magneticFieldX<<"\n";
+			os << "MagneticFieldX=" << parameters.magneticFieldX << "\n";
 		if (!parameters.magneticFieldZ.empty())
-			os<<"MagneticFieldZ="<<parameters.magneticFieldZ<<"\n";
+			os << "MagneticFieldZ=" << parameters.magneticFieldZ << "\n";
 
-		os<<"AnisotropyD="<<parameters.anisotropy<<"\n";
-		os<<"HeisenbergTwiceS="<<parameters.twiceTheSpin<<"\n";
-		os<<parameters.targetQuantum;
+		os << "AnisotropyD=" << parameters.anisotropy << "\n";
+		os << "HeisenbergTwiceS=" << parameters.twiceTheSpin << "\n";
+		os << parameters.targetQuantum;
 		return os;
 	}
 
@@ -179,4 +208,3 @@ struct ParametersModelHeisenberg : public ParametersModelBase<RealType, QnType>
 
 /*@}*/
 #endif
-
