@@ -78,22 +78,24 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
  */
 #ifndef DMRG_HUBBARD_HOLSTEIN_H
 #define DMRG_HUBBARD_HOLSTEIN_H
+#include "CrsMatrix.h"
+#include "Geometry/GeometryDca.h"
+#include "HilbertSpaceHubbardHolstein.h"
 #include "ModelBase.h"
 #include "ParametersHubbardHolstein.h"
-#include "HilbertSpaceHubbardHolstein.h"
-#include "CrsMatrix.h"
-#include "SpinSquaredHelper.h"
-#include "SpinSquared.h"
-#include "VerySparseMatrix.h"
 #include "ProgramGlobals.h"
-#include "Geometry/GeometryDca.h"
+#include "PsimagLite.h"
+#include "SpinSquared.h"
+#include "SpinSquaredHelper.h"
+#include "VerySparseMatrix.h"
 #include <cstdlib>
 #include <numeric>
-#include "PsimagLite.h"
 
-namespace Dmrg {
-template<typename ModelBaseType>
-class HubbardHolstein : public ModelBaseType {
+namespace Dmrg
+{
+template <typename ModelBaseType>
+class HubbardHolstein : public ModelBaseType
+{
 
 public:
 
@@ -119,12 +121,12 @@ public:
 	typedef typename ModelHelperType::BlockType BlockType;
 	typedef typename ModelBaseType::SolverParamsType SolverParamsType;
 	typedef typename ModelBaseType::VectorType VectorType;
-	typedef	typename ModelBaseType::MyBasis BasisType;
-	typedef	typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
+	typedef typename ModelBaseType::MyBasis BasisType;
+	typedef typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
 	typedef typename ModelBaseType::InputValidatorType InputValidatorType;
 	typedef PsimagLite::Matrix<ComplexOrRealType> MatrixType;
 	typedef ParametersHubbardHolstein<RealType, QnType> ParametersHubbardHolsteinType;
-	typedef std::pair<SizeType,SizeType> PairType;
+	typedef std::pair<SizeType, SizeType> PairType;
 	typedef typename PsimagLite::Vector<PairType>::Type VectorPairType;
 	typedef typename PsimagLite::Vector<SparseMatrixType>::Type VectorSparseMatrixType;
 	typedef typename ModelBaseType::OpsLabelType OpsLabelType;
@@ -135,50 +137,49 @@ public:
 	static SizeType const ORBITALS = 2;
 
 	HubbardHolstein(const SolverParamsType& solverParams,
-	                InputValidatorType& io,
-	                const SuperGeometryType& geometry,
-	                PsimagLite::String additional,
-	                PsimagLite::String hdf5fileIfAny)
+	    InputValidatorType& io,
+	    const SuperGeometryType& geometry,
+	    PsimagLite::String additional,
+	    PsimagLite::String hdf5fileIfAny)
 	    : ModelBaseType(solverParams,
-	                    geometry,
-	                    io),
-	      modelParameters_(io),
-	      isSsh_(additional == "SSH"),
-	      isLrh_(additional == "LRH"),
-	      oStruncActive_(false),
-	      wantsOneSiteTruncation_(0)
+		geometry,
+		io)
+	    , modelParameters_(io)
+	    , isSsh_(additional == "SSH")
+	    , isLrh_(additional == "LRH")
+	    , oStruncActive_(false)
+	    , wantsOneSiteTruncation_(0)
 	{
 		if (isSsh_) {
 			PsimagLite::String warning("HubbardHolstein: ");
 			warning += "SSH term in use.\n";
-			std::cout<<warning;
-			std::cerr<<warning;
+			std::cout << warning;
+			std::cerr << warning;
 		}
 		if (isLrh_) {
 			PsimagLite::String warning("HubbardHolstein: ");
 			warning += "Long Range Holstein term in use.\n";
-			std::cout<<warning;
-			std::cerr<<warning;
+			std::cout << warning;
+			std::cerr << warning;
 		}
 
-
 		restartHook(hdf5fileIfAny);
 	}
 
-	void print(std::ostream& os) const { operator<<(os,modelParameters_); }
+	void print(std::ostream& os) const { operator<<(os, modelParameters_); }
 
-	void addDiagonalsInNaturalBasis(SparseMatrixType &hmatrix,
-	                                const BlockType& block,
-	                                RealType time) const
+	void addDiagonalsInNaturalBasis(SparseMatrixType& hmatrix,
+	    const BlockType& block,
+	    RealType time) const
 	{
 		ModelBaseType::additionalOnSiteHamiltonian(hmatrix, block, time);
 
 		SizeType phonons = (oStruncActive_ || U_.rows() > 0) ? modelParameters_.oStruncPhonons
-		                                                     : modelParameters_.numberphonons;
+								     : modelParameters_.numberphonons;
 		if (phonons == 0)
 			err("addDiagonalsInNaturalBasis fatal error when OSTRUNC active\n");
 
-		SizeType n=block.size();
+		SizeType n = block.size();
 		HilbertBasisType natBasis;
 		setBasis(natBasis, block, phonons);
 
@@ -224,7 +225,7 @@ protected:
 		OpsLabelType& cx = this->createOpsLabel("cx");
 		this->makeTrackable("c");
 		const SizeType phonons = (U_.rows() > 0) ? modelParameters_.oStruncPhonons
-		                                         : modelParameters_.numberphonons;
+							 : modelParameters_.numberphonons;
 		if (phonons > 0) {
 			this->makeTrackable("a");
 			if (isSsh_)
@@ -247,7 +248,8 @@ protected:
 				nmatrix += n(tmpMatrix);
 
 			int asign = 1;
-			if (sigma > 0) asign = 1;
+			if (sigma > 0)
+				asign = 1;
 			typename OperatorType::Su2RelatedType su2related;
 			if (sigma == 0) {
 				su2related.source.push_back(site);
@@ -263,12 +265,12 @@ protected:
 			transposeConjugate(tmpMatrix2, tmpMatrix);
 
 			OperatorType myOp(tmpMatrix2,
-			                  ProgramGlobals::FermionOrBosonEnum::FERMION,
-			                  typename OperatorType::PairType(1,1-sigma),
-			                  asign,
-			                  su2related);
+			    ProgramGlobals::FermionOrBosonEnum::FERMION,
+			    typename OperatorType::PairType(1, 1 - sigma),
+			    asign,
+			    su2related);
 
-			c.push(myOp,(sigma == 0) ? "up" : "down");
+			c.push(myOp, (sigma == 0) ? "up" : "down");
 		}
 
 		OpsLabelType& n = this->createOpsLabel("n");
@@ -277,10 +279,10 @@ protected:
 		transformByU(nmatrix);
 
 		OperatorType myOp(nmatrix,
-		                  ProgramGlobals::FermionOrBosonEnum::BOSON,
-		                  typename OperatorType::PairType(0,0),
-		                  1,
-		                  su2relatedA);
+		    ProgramGlobals::FermionOrBosonEnum::BOSON,
+		    typename OperatorType::PairType(0, 0),
+		    1,
+		    su2relatedA);
 
 		n.push(myOp);
 
@@ -291,38 +293,36 @@ protected:
 			OpsLabelType& sminus = this->createOpsLabel("sminus");
 			SparseMatrixType t1MatrixUp = findOperatorMatrices(iup, natBasis);
 			SparseMatrixType t1MatrixDown = findOperatorMatrices(idown, natBasis);
-			SparseMatrixType tmp1;
-			multiply(tmp1, t1MatrixUp, t1MatrixDown);
+			PsimagLite::Matrix<typename SparseMatrixType::value_type> t1 = multiplyTc(t1MatrixUp, t1MatrixDown);
 			typename OperatorType::Su2RelatedType su2Related;
-			splus.push(OperatorType(tmp1,
-			                        ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                        typename OperatorType::PairType(0,0),
-			                        1.0,
-			                        su2Related));
-			SparseMatrixType tmp2;
-			transposeConjugate(tmp2, tmp1);
-			sminus.push(OperatorType(tmp2,
-			                         ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                         typename OperatorType::PairType(0,0),
-			                         1.0,
-			                         su2Related));
+			SparseMatrixType spmatrix(t1);
+			splus.push(OperatorType(spmatrix,
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
+			SparseMatrixType smmatrix;
+			transposeConjugate(smmatrix, spmatrix);
+			sminus.push(OperatorType(smmatrix,
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 		}
 		{
 			OpsLabelType& sz = this->createOpsLabel("sz");
 			SparseMatrixType t1MatrixUp = findOperatorMatrices(iup, natBasis);
 			SparseMatrixType t1MatrixDown = findOperatorMatrices(idown, natBasis);
-			PsimagLite::Matrix<SparseElementType> t1 =
-			        multiplyTc(t1MatrixUp,t1MatrixUp);
-			PsimagLite::Matrix<SparseElementType> t2 =
-			        multiplyTc(t1MatrixDown,t1MatrixDown);
-			t1 = 0.5*(t1 - t2);
+			PsimagLite::Matrix<SparseElementType> t1 = multiplyTc(t1MatrixUp, t1MatrixUp);
+			PsimagLite::Matrix<SparseElementType> t2 = multiplyTc(t1MatrixDown, t1MatrixDown);
+			t1 = 0.5 * (t1 - t2);
 			SparseMatrixType szmatrix(t1);
 			typename OperatorType::Su2RelatedType su2Related;
 			sz.push(OperatorType(szmatrix,
-			                     ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                     typename OperatorType::PairType(0,0),
-			                     1.0,
-			                     su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 		}
 
 		{
@@ -330,42 +330,40 @@ protected:
 			OpsLabelType& doubleOccM = this->createOpsLabel("doubleM");
 			SparseMatrixType t1MatrixUp = findOperatorMatrices(iup, natBasis);
 			SparseMatrixType t1MatrixDown = findOperatorMatrices(idown, natBasis);
-			PsimagLite::Matrix<SparseElementType> t1 =
-			        multiplyTc(t1MatrixUp,t1MatrixUp);
-			PsimagLite::Matrix<SparseElementType> t2 =
-			        multiplyTc(t1MatrixDown,t1MatrixDown);
+			PsimagLite::Matrix<SparseElementType> t1 = multiplyTc(t1MatrixUp, t1MatrixUp);
+			PsimagLite::Matrix<SparseElementType> t2 = multiplyTc(t1MatrixDown, t1MatrixDown);
 			SparseMatrixType nMatrixUp(t1);
-			t1 = t1+t2;
+			t1 = t1 + t2;
 			SparseMatrixType nMatrixDown(t2);
-			PsimagLite::Matrix<SparseElementType> t3 =
-			        multiplyTc(nMatrixDown,nMatrixUp);
+			PsimagLite::Matrix<SparseElementType> t3 = multiplyTc(nMatrixDown, nMatrixUp);
 
-			t1 = t1+(-2.0)*t3;
+			t1 = t1 + (-2.0) * t3;
 
 			SparseMatrixType tmp4(t1);
 			typename OperatorType::Su2RelatedType su2Related;
 			doubleOccM.push(OperatorType(tmp4,
-			                            ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                            typename OperatorType::PairType(0,0),
-			                            1.0,
-			                            su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 
 			SparseMatrixType tmp5(t3);
 			doubleOcc.push(OperatorType(tmp5,
-			                            ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                            typename OperatorType::PairType(0,0),
-			                            1.0,
-			                            su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 		}
 
-		if (phonons == 0) return; //<<--- EARLY EXIT
+		if (phonons == 0)
+			return; //<<--- EARLY EXIT
 
 		tmpMatrix = findPhononadaggerMatrix(natBasis, phonons);
 
 		typename OperatorType::Su2RelatedType su2related2;
-		su2related2.source.push_back(site*2);
-		su2related2.source.push_back(site*2+1);
-		su2related2.source.push_back(site*2);
+		su2related2.source.push_back(site * 2);
+		su2related2.source.push_back(site * 2 + 1);
+		su2related2.source.push_back(site * 2);
 		su2related2.transpose.push_back(-1);
 		su2related2.transpose.push_back(-1);
 		su2related2.transpose.push_back(1);
@@ -377,10 +375,10 @@ protected:
 		transposeConjugate(tmpMatrix2, tmpMatrix);
 
 		OperatorType myOp2(tmpMatrix2,
-		                   ProgramGlobals::FermionOrBosonEnum::BOSON,
-		                   PairType(2, 2),
-		                   -1,
-		                   su2related2);
+		    ProgramGlobals::FermionOrBosonEnum::BOSON,
+		    PairType(2, 2),
+		    -1,
+		    su2related2);
 		a.push(myOp2);
 
 		{
@@ -391,13 +389,14 @@ protected:
 			tmp2 += tmp1;
 			typename OperatorType::Su2RelatedType su2Related2;
 			disp.push(OperatorType(tmp2,
-			                       ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                       typename OperatorType::PairType(0,0),
-			                       1.0,
-			                       su2Related2));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related2));
 		}
 
-		if (!isSsh_ && !isLrh_) return; //<<--- EARLY EXIT
+		if (!isSsh_ && !isLrh_)
+			return; //<<--- EARLY EXIT
 
 		if (isSsh_) {
 
@@ -406,7 +405,8 @@ protected:
 			for (SizeType sigma = 0; sigma < 2; ++sigma) {
 				tmpMatrix = findSSHMatrices(sigma, natBasis, phonons);
 				int asign = 1;
-				if (sigma > 0) asign = 1;
+				if (sigma > 0)
+					asign = 1;
 				typename OperatorType::Su2RelatedType su2related3;
 				if (sigma == 0) {
 					su2related3.source.push_back(site);
@@ -422,15 +422,15 @@ protected:
 				transposeConjugate(tmpMatrix2, tmpMatrix);
 
 				OperatorType myOp3(tmpMatrix2,
-				                   ProgramGlobals::FermionOrBosonEnum::FERMION,
-				                   typename OperatorType::PairType(1,1-sigma),
-				                   asign,
-				                   su2related3);
+				    ProgramGlobals::FermionOrBosonEnum::FERMION,
+				    typename OperatorType::PairType(1, 1 - sigma),
+				    asign,
+				    su2related3);
 
-				cx.push(myOp3,(sigma == 0) ? "up" : "down");
+				cx.push(myOp3, (sigma == 0) ? "up" : "down");
 			}
 		} else if (isLrh_) {
-				this->makeTrackable("disp");
+			this->makeTrackable("disp");
 		}
 	}
 
@@ -458,7 +458,7 @@ protected:
 			OpForLinkType cx0("cx", 0);
 			OpForLinkType cx1("cx", 1);
 
-			auto modifier = [](ComplexOrRealType& value) { value *= (-1.0);};
+			auto modifier = [](ComplexOrRealType& value) { value *= (-1.0); };
 
 			hopSsh.push(cup, 'C', cx0, 'N');
 
@@ -480,8 +480,6 @@ protected:
 		} else {
 			return;
 		}
-
-
 	}
 
 	void announce(PsimagLite::String str) const
@@ -489,7 +487,8 @@ protected:
 		const PsimagLite::String msg("finite loop");
 		const SizeType l = msg.length();
 
-		if (str.substr(0, l) != msg) return;
+		if (str.substr(0, l) != msg)
+			return;
 
 		PsimagLite::Vector<PsimagLite::String>::Type tokens;
 		PsimagLite::split(tokens, str, ";");
@@ -508,9 +507,9 @@ protected:
 
 		static const bool verbose = true;
 		if (verbose) {
-			std::cout<<"U UPDATED\n";
-			std::cout<<U_;
-			std::cout<<"--------\n";
+			std::cout << "U UPDATED\n";
+			std::cout << U_;
+			std::cout << "--------\n";
 		}
 
 		if (firstCall) {
@@ -519,15 +518,15 @@ protected:
 		} else {
 			ioOut.overwrite(U_, "OneSiteTruncationU");
 			ioOut.write(modelParameters_.oStruncPhonons,
-			            "OsTruncPhonons",
-			            PsimagLite::IoNgSerializer::ALLOW_OVERWRITE);
+			    "OsTruncPhonons",
+			    PsimagLite::IoNgSerializer::ALLOW_OVERWRITE);
 		}
 	}
 
 	// virtual override
 	SizeType setOperatorMatrices(VectorOperatorType& ops,
-	                             VectorQnType& qm,
-	                             const BlockType& block) const
+	    VectorQnType& qm,
+	    const BlockType& block) const
 	{
 		oStruncActive_ = false;
 
@@ -553,9 +552,10 @@ protected:
 		for (SizeType sigma = 0; sigma < 2; ++sigma) {
 			SparseMatrixType tmpMatrix = findOperatorMatrices(sigma, natBasis);
 			int asign = 1;
-			if (sigma > 0) asign = 1;
+			if (sigma > 0)
+				asign = 1;
 			typename OperatorType::Su2RelatedType su2related;
-			if (sigma==0) {
+			if (sigma == 0) {
 				su2related.source.push_back(ind);
 				su2related.source.push_back(ind + 1);
 				su2related.transpose.push_back(-1);
@@ -564,44 +564,47 @@ protected:
 			}
 
 			OperatorType myOp(tmpMatrix,
-			                  ProgramGlobals::FermionOrBosonEnum::FERMION,
-			                  typename OperatorType::PairType(1,1-sigma),
-			                  asign,
-			                  su2related);
+			    ProgramGlobals::FermionOrBosonEnum::FERMION,
+			    typename OperatorType::PairType(1, 1 - sigma),
+			    asign,
+			    su2related);
 
 			ops.push_back(myOp);
 		}
 
 		// operator n should NOT be pushed because it isn't tracked
 
-		if (modelParameters_.oStruncPhonons == 0) return oneSiteTruncSize;
+		if (modelParameters_.oStruncPhonons == 0)
+			return oneSiteTruncSize;
 
 		SparseMatrixType tmpMatrix = findPhononadaggerMatrix(natBasis,
-		                                                     modelParameters_.oStruncPhonons);
+		    modelParameters_.oStruncPhonons);
 
 		typename OperatorType::Su2RelatedType su2related2;
-		su2related2.source.push_back(ind*2);
-		su2related2.source.push_back(ind*2 + 1);
-		su2related2.source.push_back(ind*2);
+		su2related2.source.push_back(ind * 2);
+		su2related2.source.push_back(ind * 2 + 1);
+		su2related2.source.push_back(ind * 2);
 		su2related2.transpose.push_back(-1);
 		su2related2.transpose.push_back(-1);
 		su2related2.transpose.push_back(1);
 		su2related2.offset = 1;
 		OperatorType myOp2(tmpMatrix,
-		                   ProgramGlobals::FermionOrBosonEnum::BOSON,
-		                   PairType(2, 2),
-		                   -1,
-		                   su2related2);
+		    ProgramGlobals::FermionOrBosonEnum::BOSON,
+		    PairType(2, 2),
+		    -1,
+		    su2related2);
 		ops.push_back(myOp2);
 
-		if (!isSsh_ && !isLrh_) return oneSiteTruncSize; //<<--- EARLY EXIT
+		if (!isSsh_ && !isLrh_)
+			return oneSiteTruncSize; //<<--- EARLY EXIT
 
 		// Set the operators c_(i,sigma} * x_i in the natural basis
 
 		for (SizeType sigma = 0; sigma < 2; ++sigma) {
 			tmpMatrix = findSSHMatrices(sigma, natBasis, modelParameters_.oStruncPhonons);
 			int asign = 1;
-			if (sigma > 0) asign = 1;
+			if (sigma > 0)
+				asign = 1;
 			typename OperatorType::Su2RelatedType su2related3;
 			if (sigma == 0) {
 				su2related3.source.push_back(ind);
@@ -614,10 +617,10 @@ protected:
 			transformByU(tmpMatrix);
 
 			OperatorType myOp3(tmpMatrix,
-			                   ProgramGlobals::FermionOrBosonEnum::FERMION,
-			                   typename OperatorType::PairType(1,1-sigma),
-			                   asign,
-			                   su2related3);
+			    ProgramGlobals::FermionOrBosonEnum::FERMION,
+			    typename OperatorType::PairType(1, 1 - sigma),
+			    asign,
+			    su2related3);
 
 			ops.push_back(myOp3);
 		}
@@ -630,12 +633,12 @@ private:
 	//! find all states in the natural basis for a block of n sites
 	//! N.B.: HAS BEEN CHANGED TO ACCOMODATE FOR MULTIPLE BANDS
 	static void setBasis(HilbertBasisType& basis,
-	                     const VectorSizeType& block,
-	                     SizeType phonons)
+	    const VectorSizeType& block,
+	    SizeType phonons)
 	{
 		SizeType n = block.size();
-		HilbertState total = 4*(phonons + 1);
-		total = pow(total,n);
+		HilbertState total = 4 * (phonons + 1);
+		total = pow(total, n);
 
 		basis.resize(total);
 
@@ -643,28 +646,28 @@ private:
 		SizeType npPlusOne = phonons + 1;
 		for (SizeType i = 0; i < 4; ++i) {
 			for (SizeType b = 0; b < npPlusOne; ++b) {
-				basis[counter++] = b*4 + i;
+				basis[counter++] = b * 4 + i;
 			}
 		}
 
 		assert(counter == total);
 
 		SizeType sum = std::accumulate(basis.begin(),
-		                               basis.end(),
-		                               static_cast<SizeType>(0));
-		if (sum != total*(total-1)/2)
+		    basis.end(),
+		    static_cast<SizeType>(0));
+		if (sum != total * (total - 1) / 2)
 			err("Could not set up basis\n");
 	}
 
 	//! Find a^+ in the natural basis natBasis
 	SparseMatrixType findPhononadaggerMatrix(const HilbertBasisType& natBasis,
-	                                         SizeType phonons) const
+	    SizeType phonons) const
 	{
 		const SizeType total = natBasis.size();
 
 		MatrixType cm(total, total);
 
-		for (SizeType ii = 0;ii < total; ++ii) {
+		for (SizeType ii = 0; ii < total; ++ii) {
 
 			typename HilbertSpaceHubbardHolsteinType::HilbertState ket = natBasis[ii];
 
@@ -689,23 +692,22 @@ private:
 
 		SparseMatrixType operatorMatrix(cm);
 		SparseMatrixType temp;
-		fullMatrixToCrsMatrix(temp,cm);
-		transposeConjugate(operatorMatrix,temp);
+		fullMatrixToCrsMatrix(temp, cm);
+		transposeConjugate(operatorMatrix, temp);
 		return operatorMatrix;
 	}
 
 	//! Calculate fermionic sign when applying operator c^\dagger_{i\sigma} to basis state ket
 	RealType sign(typename HilbertSpaceHubbardHolsteinType::HilbertState ket) const
 	{
-		const SizeType ndown = HilbertSpaceHubbardHolsteinType::electronsWithGivenSpin
-		        (ket, HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_DOWN);
+		const SizeType ndown = HilbertSpaceHubbardHolsteinType::electronsWithGivenSpin(ket, HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_DOWN);
 
-		return (ndown%2 == 0) ? 1 : FERMION_SIGN;
+		return (ndown % 2 == 0) ? 1 : FERMION_SIGN;
 	}
 
 	//! Find c^\dagger_isigma in the natural basis natBasis
 	SparseMatrixType findOperatorMatrices(SizeType sigma,
-	                                      const HilbertBasisType& natBasis) const
+	    const HilbertBasisType& natBasis) const
 	{
 		const SizeType n = natBasis.size();
 		PsimagLite::Matrix<typename SparseMatrixType::value_type> cm(n, n);
@@ -715,14 +717,14 @@ private:
 			typename HilbertSpaceHubbardHolsteinType::HilbertState ket = natBasis[ii];
 
 			const typename HilbertSpaceHubbardHolsteinType::SpinEnum spin = (sigma == 0)
-			        ? HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_UP
-			        : HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_DOWN;
+			    ? HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_UP
+			    : HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_DOWN;
 
 			SizeType neSpin = HilbertSpaceHubbardHolsteinType::electronsWithGivenSpin(ket, spin);
 			if (neSpin == 0) {
 				typename HilbertSpaceHubbardHolsteinType::HilbertState bra = ket;
 				HilbertSpaceHubbardHolsteinType::createF(bra, sigma);
-				const int jj = PsimagLite::indexOrMinusOne(natBasis,bra);
+				const int jj = PsimagLite::indexOrMinusOne(natBasis, bra);
 				if (jj < 0)
 					err("findOperatorMatrices\n");
 				cm(ii, jj) = sign(ket);
@@ -731,28 +733,27 @@ private:
 
 		SparseMatrixType creationMatrix(cm);
 		SparseMatrixType temp;
-		fullMatrixToCrsMatrix(temp,cm);
-		transposeConjugate(creationMatrix,temp);
+		fullMatrixToCrsMatrix(temp, cm);
+		transposeConjugate(creationMatrix, temp);
 
 		return creationMatrix;
 	}
 
-
 	SparseMatrixType findSSHMatrices(SizeType sigma,
-	                                 const HilbertBasisType& natBasis,
-	                                 SizeType phonons) const
+	    const HilbertBasisType& natBasis,
+	    SizeType phonons) const
 	{
 		SparseMatrixType csigma_temp = findOperatorMatrices(sigma, natBasis);
 		SparseMatrixType a_temp = findPhononadaggerMatrix(natBasis, phonons);
 		SparseMatrixType x_temp = displacementOp(a_temp);
 		SparseMatrixType csigma_a;
-		multiply(csigma_a,csigma_temp,x_temp);
+		multiply(csigma_a, csigma_temp, x_temp);
 		return csigma_a;
 	}
 
 	void findAllMatrices(VectorSparseMatrixType& vm,
-	                     const HilbertBasisType& natBasis,
-	                     SizeType phonons) const
+	    const HilbertBasisType& natBasis,
+	    SizeType phonons) const
 	{
 		for (SizeType sigma = 0; sigma < 2; ++sigma) {
 			SparseMatrixType m = findOperatorMatrices(sigma, natBasis);
@@ -760,31 +761,30 @@ private:
 			vm.push_back(m);
 		}
 
-		if (phonons == 0) return;
+		if (phonons == 0)
+			return;
 		SparseMatrixType m = findPhononadaggerMatrix(natBasis, phonons);
 		transformByU(m);
 		vm.push_back(m);
 	}
 
 	void setSymmetryRelated(VectorQnType& qns,
-	                        const HilbertBasisType& basis) const
+	    const HilbertBasisType& basis) const
 	{
 		// find j,m and flavors (do it by hand since we assume n==1)
 		// note: we use 2j instead of j
 		// note: we use m+j instead of m
 		// This assures us that both j and m are SizeType
-		typedef std::pair<SizeType,SizeType> PairType;
+		typedef std::pair<SizeType, SizeType> PairType;
 		VectorSizeType other(2, 0);
 		qns.resize(basis.size(), QnType::zero());
 		for (SizeType i = 0; i < basis.size(); ++i) {
-			PairType jmpair = PairType(0,0);
+			PairType jmpair = PairType(0, 0);
 
 			// nup
-			SizeType electronsUp = HilbertSpaceHubbardHolsteinType::electronsWithGivenSpin
-			        (basis[i], HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_UP);
+			SizeType electronsUp = HilbertSpaceHubbardHolsteinType::electronsWithGivenSpin(basis[i], HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_UP);
 			// ndown
-			SizeType electronsDown = HilbertSpaceHubbardHolsteinType::electronsWithGivenSpin
-			        (basis[i], HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_DOWN);
+			SizeType electronsDown = HilbertSpaceHubbardHolsteinType::electronsWithGivenSpin(basis[i], HilbertSpaceHubbardHolsteinType::SpinEnum::SPIN_DOWN);
 
 			SizeType electrons = electronsUp + electronsDown;
 			other[0] = electrons;
@@ -794,9 +794,9 @@ private:
 		}
 	}
 
-	void addPotentialFV(SparseMatrixType &hmatrix,
-	                    const VectorSparseMatrixType& cm,
-	                    SizeType actualIndexOfSite) const
+	void addPotentialFV(SparseMatrixType& hmatrix,
+	    const VectorSparseMatrixType& cm,
+	    SizeType actualIndexOfSite) const
 	{
 		SparseMatrixType nup = n(cm[0]); // spin up
 		SparseMatrixType ndown = n(cm[1]); // spin down
@@ -810,12 +810,13 @@ private:
 		hmatrix += modelParameters_.potentialFV[iDown] * ndown;
 	}
 
-	void addPotentialPhononV(SparseMatrixType &hmatrix,
-	                         const VectorSparseMatrixType& cm,
-	                         SizeType actualIndexOfSite,
-	                         SizeType phonons) const
+	void addPotentialPhononV(SparseMatrixType& hmatrix,
+	    const VectorSparseMatrixType& cm,
+	    SizeType actualIndexOfSite,
+	    SizeType phonons) const
 	{
-		if (phonons == 0) return;
+		if (phonons == 0)
+			return;
 		assert(2 < cm.size());
 		SparseMatrixType nphon = n(cm[2]);
 		SizeType iUp = actualIndexOfSite;
@@ -827,7 +828,7 @@ private:
 	{
 		SparseMatrixType tmpMatrix;
 		SparseMatrixType cdagger;
-		transposeConjugate(cdagger,c);
+		transposeConjugate(cdagger, c);
 		multiply(tmpMatrix, c, cdagger);
 
 		return tmpMatrix;
@@ -837,32 +838,33 @@ private:
 	{
 		SparseMatrixType tmpMatrix = c;
 		SparseMatrixType cdagger;
-		transposeConjugate(cdagger,c);
-		tmpMatrix+=cdagger;
+		transposeConjugate(cdagger, c);
+		tmpMatrix += cdagger;
 		return tmpMatrix;
 	}
 
 	//! Term is U \sum_{\alpha}n_{i\alpha UP} n_{i\alpha DOWN}
-	void addInteractionFU(SparseMatrixType &hmatrix,
-	                      const VectorSparseMatrixType& cm,
-	                      SizeType actualSite) const
+	void addInteractionFU(SparseMatrixType& hmatrix,
+	    const VectorSparseMatrixType& cm,
+	    SizeType actualSite) const
 	{
 		SparseMatrixType tmpMatrix;
-		SparseMatrixType m1=cm[0]; // spin up
-		SparseMatrixType m2=cm[1]; // spin down
+		SparseMatrixType m1 = cm[0]; // spin up
+		SparseMatrixType m2 = cm[1]; // spin down
 
-		multiply(tmpMatrix,n(m1),n(m2));
+		multiply(tmpMatrix, n(m1), n(m2));
 		assert(actualSite < modelParameters_.hubbardFU.size());
-		hmatrix += modelParameters_.hubbardFU[actualSite]*tmpMatrix;
+		hmatrix += modelParameters_.hubbardFU[actualSite] * tmpMatrix;
 	}
 
 	//! Term is lambda\sum_{\alpha} (n_{i\alpha} -1) x_{i}
-	void addInteractionFPhonon(SparseMatrixType &hmatrix,
-	                           const VectorSparseMatrixType& cm,
-	                           SizeType actualSite,
-	                           SizeType phonons) const
+	void addInteractionFPhonon(SparseMatrixType& hmatrix,
+	    const VectorSparseMatrixType& cm,
+	    SizeType actualSite,
+	    SizeType phonons) const
 	{
-		if (phonons == 0) return;
+		if (phonons == 0)
+			return;
 		SparseMatrixType tmpMatrix;
 		SparseMatrixType m = n(cm[0]); // spin up
 		SparseMatrixType m2 = n(cm[1]); // spin down
@@ -870,15 +872,16 @@ private:
 		assert(2 < cm.size());
 		SparseMatrixType x = displacementOp(cm[2]);
 
-		multiply(tmpMatrix,m,x);
+		multiply(tmpMatrix, m, x);
 		tmpMatrix.checkValidity();
 		assert(actualSite < modelParameters_.lambdaFP.size());
-		hmatrix += modelParameters_.lambdaFP[actualSite]*tmpMatrix;
+		hmatrix += modelParameters_.lambdaFP[actualSite] * tmpMatrix;
 	}
 
 	void transformByU(SparseMatrixType& m) const
 	{
-		if (U_.rows() == 0) return;
+		if (U_.rows() == 0)
+			return;
 
 		if (U_.rows() != m.rows())
 			err("HubbardHolstein::transformByU(): wrong sizes\n");
@@ -903,18 +906,20 @@ private:
 
 	void restartHook(PsimagLite::String restartFilename)
 	{
-		if (restartFilename == "") return;
+		if (restartFilename == "")
+			return;
 
 		PsimagLite::IoSelector::In io(restartFilename);
 		try {
 			io.read(U_, "OneSiteTruncationU");
-			std::cout<<"OneSiteTruncationU = "<<U_.rows()<<" x "<<U_.cols();
-			std::cout<<" read from "<<restartFilename<<"\n";
-		} catch (...) {}
+			std::cout << "OneSiteTruncationU = " << U_.rows() << " x " << U_.cols();
+			std::cout << " read from " << restartFilename << "\n";
+		} catch (...) {
+		}
 
 		if (U_.rows() > 0) {
 			io.read(modelParameters_.oStruncPhonons, "OsTruncPhonons");
-			std::cout<<"OsTruncPhonons set to "<<modelParameters_.oStruncPhonons<<"\n";
+			std::cout << "OsTruncPhonons set to " << modelParameters_.oStruncPhonons << "\n";
 		}
 	}
 
@@ -924,7 +929,7 @@ private:
 	mutable bool oStruncActive_;
 	mutable SizeType wantsOneSiteTruncation_;
 	mutable MatrixType U_;
-}; //class HubbardHolstein
+}; // class HubbardHolstein
 } // namespace Dmrg
 /*@}*/
 #endif
