@@ -78,18 +78,20 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
  */
 #ifndef MODEL_HUBBARD_MULTI_BAND_H
 #define MODEL_HUBBARD_MULTI_BAND_H
-#include "ModelBase.h"
-#include "ParametersHubbardMultiBand.h"
 #include "../Models/FeAsModel/HilbertSpaceFeAs.h"
 #include "CrsMatrix.h"
-#include "SpinSquaredHelper.h"
-#include "SpinSquared.h"
-#include "VerySparseMatrix.h"
+#include "ModelBase.h"
+#include "ParametersHubbardMultiBand.h"
 #include "ProgramGlobals.h"
+#include "SpinSquared.h"
+#include "SpinSquaredHelper.h"
+#include "VerySparseMatrix.h"
 
-namespace Dmrg {
-template<typename ModelBaseType>
-class ModelHubbardMultiBand : public ModelBaseType {
+namespace Dmrg
+{
+template <typename ModelBaseType>
+class ModelHubbardMultiBand : public ModelBaseType
+{
 
 public:
 
@@ -112,8 +114,8 @@ public:
 	typedef typename ModelHelperType::BlockType BlockType;
 	typedef typename ModelBaseType::SolverParamsType SolverParamsType;
 	typedef typename ModelBaseType::VectorType VectorType;
-	typedef	typename ModelBaseType::MyBasis BasisType;
-	typedef	typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
+	typedef typename ModelBaseType::MyBasis BasisType;
+	typedef typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
 	typedef typename ModelBaseType::InputValidatorType InputValidatorType;
 	typedef PsimagLite::Matrix<ComplexOrRealType> MatrixType;
 	typedef ParametersHubbardMultiBand<ComplexOrRealType, QnType> ParamsModelType;
@@ -122,24 +124,23 @@ public:
 	typedef typename ModelBaseType::ModelTermType ModelTermType;
 
 	static const int FERMION_SIGN = -1;
-	static const int SPIN_UP=HilbertSpaceFeAsType::SPIN_UP;
-	static const int SPIN_DOWN=HilbertSpaceFeAsType::SPIN_DOWN;
+	static const int SPIN_UP = HilbertSpaceFeAsType::SPIN_UP;
+	static const int SPIN_DOWN = HilbertSpaceFeAsType::SPIN_DOWN;
 
 	ModelHubbardMultiBand(const SolverParamsType& solverParams,
-	                      InputValidatorType& io,
-	                      const SuperGeometryType& geometry)
-	    : ModelBaseType(solverParams, geometry, io),
-	      modelParameters_(io),
-	      superGeometry_(geometry),
-	      spinSquared_(spinSquaredHelper_,
-	                   modelParameters_.orbitals,
-	                   2*modelParameters_.orbitals)
+	    InputValidatorType& io,
+	    const SuperGeometryType& geometry)
+	    : ModelBaseType(solverParams, geometry, io)
+	    , modelParameters_(io)
+	    , superGeometry_(geometry)
+	    , spinSquared_(spinSquaredHelper_,
+		  modelParameters_.orbitals,
+		  2 * modelParameters_.orbitals)
 	{
-		ProgramGlobals::init(modelParameters_.orbitals*superGeometry_.numberOfSites() + 1);
-		SizeType v1 = 2*modelParameters_.orbitals*geometry.numberOfSites();
-		SizeType v2 = v1*modelParameters_.orbitals;
-		if (modelParameters_.potentialV.size() != v1 &&
-		        modelParameters_.potentialV.size() != v2) {
+		ProgramGlobals::init(modelParameters_.orbitals * superGeometry_.numberOfSites() + 1);
+		SizeType v1 = 2 * modelParameters_.orbitals * geometry.numberOfSites();
+		SizeType v2 = v1 * modelParameters_.orbitals;
+		if (modelParameters_.potentialV.size() != v1 && modelParameters_.potentialV.size() != v2) {
 			PsimagLite::String str(__FILE__);
 			str += " " + ttos(__LINE__) + "\n";
 			str += "potentialV length must be 2*orbitals times the number of sites or";
@@ -149,9 +150,9 @@ public:
 
 		HilbertSpaceFeAsType::setOrbitals(modelParameters_.orbitals);
 
-		VectorSizeType block(1,0);
-		int sitesTimesDof=2*modelParameters_.orbitals;
-		HilbertState total = (1<<sitesTimesDof);
+		VectorSizeType block(1, 0);
+		int sitesTimesDof = 2 * modelParameters_.orbitals;
+		HilbertState total = (1 << sitesTimesDof);
 		basis_.resize(total);
 		for (HilbertState a = 0; a < total; ++a)
 			basis_[a] = a;
@@ -181,9 +182,9 @@ public:
 		qx_.write(label + "/qx_", io);
 	}
 
-	void addDiagonalsInNaturalBasis(SparseMatrixType &hmatrix,
-	                                const BlockType& block,
-	                                RealType time) const
+	void addDiagonalsInNaturalBasis(SparseMatrixType& hmatrix,
+	    const BlockType& block,
+	    RealType time) const
 	{
 		ModelBaseType::additionalOnSiteHamiltonian(hmatrix, block, time);
 
@@ -196,12 +197,12 @@ public:
 			addHoppingOnSite(hmatrix, i, block[i]);
 
 			assert(site < modelParameters_.hubbardU.size());
-			hmatrix += modelParameters_.hubbardU[site]*qx_;
+			hmatrix += modelParameters_.hubbardU[site] * qx_;
 
 			addPotentialV(hmatrix,
-			              i,
-			              block[i],
-			              modelParameters_.potentialV);
+			    i,
+			    block[i],
+			    modelParameters_.potentialV);
 		}
 	}
 
@@ -210,7 +211,7 @@ protected:
 	void fillLabeledOperators(VectorQnType& qns)
 	{
 		qns = qq_;
-		assert(creationMatrix_.size()>0);
+		assert(creationMatrix_.size() > 0);
 		SizeType nrow = creationMatrix_[0].getCRS().rows();
 
 		OpsLabelType& splus = this->createOpsLabel("splus");
@@ -220,73 +221,72 @@ protected:
 
 		for (SizeType orbital = 0; orbital < modelParameters_.orbitals; ++orbital) {
 			{
-				MatrixType tmp(nrow,nrow);
+				MatrixType tmp(nrow, nrow);
 				tmp += multiplyTc(creationMatrix_[orbital].getCRS(),
-				                  creationMatrix_[orbital + modelParameters_.orbitals].getCRS());
+				    creationMatrix_[orbital + modelParameters_.orbitals].getCRS());
 				SparseMatrixType tmp2(tmp);
 				typename OperatorType::Su2RelatedType su2Related;
 				splus.push(OperatorType(tmp2,
-				                        ProgramGlobals::FermionOrBosonEnum::BOSON,
-				                        typename OperatorType::PairType(0,0),
-				                        1.0,
-				                        su2Related));
+				    ProgramGlobals::FermionOrBosonEnum::BOSON,
+				    typename OperatorType::PairType(0, 0),
+				    1.0,
+				    su2Related));
 				SparseMatrixType tmp3;
 				transposeConjugate(tmp3, tmp2);
 				sminus.push(OperatorType(tmp3,
-				                         ProgramGlobals::FermionOrBosonEnum::BOSON,
-				                         typename OperatorType::PairType(0,0),
-				                         1.0,
-				                         su2Related));
+				    ProgramGlobals::FermionOrBosonEnum::BOSON,
+				    typename OperatorType::PairType(0, 0),
+				    1.0,
+				    su2Related));
 			}
 
 			{ // S^z
-				MatrixType tmp(nrow,nrow);
-				MatrixType tmp2(nrow,nrow);
+				MatrixType tmp(nrow, nrow);
+				MatrixType tmp2(nrow, nrow);
 
 				tmp += multiplyTc(creationMatrix_[orbital].getCRS(),
-				                  creationMatrix_[orbital].getCRS());
+				    creationMatrix_[orbital].getCRS());
 				tmp2 += multiplyTc(creationMatrix_[orbital + modelParameters_.orbitals].getCRS(),
-				        creationMatrix_[orbital + modelParameters_.orbitals].getCRS());
+				    creationMatrix_[orbital + modelParameters_.orbitals].getCRS());
 
-				tmp = 0.5*(tmp-tmp2);
+				tmp = 0.5 * (tmp - tmp2);
 				SparseMatrixType tmp3(tmp);
 				typename OperatorType::Su2RelatedType su2Related;
 				sz.push(OperatorType(tmp3,
-				                     ProgramGlobals::FermionOrBosonEnum::BOSON,
-				                     typename OperatorType::PairType(0,0),
-				                     1.0,
-				                     su2Related));
+				    ProgramGlobals::FermionOrBosonEnum::BOSON,
+				    typename OperatorType::PairType(0, 0),
+				    1.0,
+				    su2Related));
 			}
 
 			{ // delta = c^\dagger * c^dagger
 				SparseMatrixType atmp;
 				multiply(atmp,
-				         creationMatrix_[orbital + modelParameters_.orbitals].getCRS(),
-				        creationMatrix_[orbital].getCRS());
+				    creationMatrix_[orbital + modelParameters_.orbitals].getCRS(),
+				    creationMatrix_[orbital].getCRS());
 				typename OperatorType::Su2RelatedType su2Related;
 				d.push(OperatorType(atmp,
-				                    ProgramGlobals::FermionOrBosonEnum::BOSON,
-				                    typename OperatorType::PairType(0,0),
-				                    1.0,
-				                    su2Related));
+				    ProgramGlobals::FermionOrBosonEnum::BOSON,
+				    typename OperatorType::PairType(0, 0),
+				    1.0,
+				    su2Related));
 			}
 		}
 
 		OpsLabelType& nop = this->createOpsLabel("n");
 		OpsLabelType& c = this->createOpsLabel("c");
 		this->makeTrackable("c");
-		SizeType dofs = 2*modelParameters_.orbitals;
+		SizeType dofs = 2 * modelParameters_.orbitals;
 		for (SizeType dof = 0; dof < dofs; ++dof) {
 			{
-				MatrixType tmp =
-				        multiplyTc(creationMatrix_[dof].getCRS(),creationMatrix_[dof].getCRS());
+				MatrixType tmp = multiplyTc(creationMatrix_[dof].getCRS(), creationMatrix_[dof].getCRS());
 				SparseMatrixType tmp2(tmp);
 				typename OperatorType::Su2RelatedType su2Related;
 				nop.push(OperatorType(tmp2,
-				                      ProgramGlobals::FermionOrBosonEnum::BOSON,
-				                      typename OperatorType::PairType(0,0),
-				                      1.0,
-				                      su2Related));
+				    ProgramGlobals::FermionOrBosonEnum::BOSON,
+				    typename OperatorType::PairType(0, 0),
+				    1.0,
+				    su2Related));
 			}
 
 			{
@@ -308,9 +308,9 @@ protected:
 		for (SizeType spin = 0; spin < 2; ++spin) {
 			typename ModelTermType::Su2Properties su2properties(1, (spin == 1) ? -1 : 1, spin);
 			for (SizeType orb1 = 0; orb1 < orbitals; ++orb1) {
-				OpForLinkType c1("c", orb1 + spin*orbitals, orb1);
+				OpForLinkType c1("c", orb1 + spin * orbitals, orb1);
 				for (SizeType orb2 = 0; orb2 < orbitals; ++orb2) {
-					OpForLinkType c2("c", orb2 + spin*orbitals, orb2);
+					OpForLinkType c2("c", orb2 + spin * orbitals, orb2);
 
 					hop.push(c1, 'N', c2, 'C', su2properties);
 				}
@@ -321,38 +321,38 @@ protected:
 private:
 
 	void setOperatorMatricesInternal(VectorOperatorType& creationMatrix,
-	                                 const BlockType& block) const
+	    const BlockType& block) const
 	{
 		HilbertBasisType natBasis = basis_;
 		SparseMatrixType tmpMatrix;
 
 		//! Set the operators c^\daggger_{i\gamma\sigma} in the natural basis
 		creationMatrix.clear();
-		SizeType dofs = 2*modelParameters_.orbitals;
-		for (SizeType i=0;i<block.size();i++) {
-			for (SizeType sigma=0;sigma<dofs;sigma++) {
-				findOperatorMatrices(tmpMatrix,i,sigma,natBasis);
+		SizeType dofs = 2 * modelParameters_.orbitals;
+		for (SizeType i = 0; i < block.size(); i++) {
+			for (SizeType sigma = 0; sigma < dofs; sigma++) {
+				findOperatorMatrices(tmpMatrix, i, sigma, natBasis);
 
-				SizeType m=0;
-				int asign=1;
-				if (sigma>modelParameters_.orbitals-1) {
-					m=1;
-					asign= -1;
+				SizeType m = 0;
+				int asign = 1;
+				if (sigma > modelParameters_.orbitals - 1) {
+					m = 1;
+					asign = -1;
 				}
 				typename OperatorType::Su2RelatedType su2related;
-				if (sigma <modelParameters_.orbitals) {
-					su2related.source.push_back(i*dofs+sigma);
-					su2related.source.push_back(i*dofs+sigma + modelParameters_.orbitals);
+				if (sigma < modelParameters_.orbitals) {
+					su2related.source.push_back(i * dofs + sigma);
+					su2related.source.push_back(i * dofs + sigma + modelParameters_.orbitals);
 					su2related.transpose.push_back(-1);
 					su2related.transpose.push_back(-1);
 					su2related.offset = modelParameters_.orbitals;
 				}
 
 				OperatorType myOp(tmpMatrix,
-				                  ProgramGlobals::FermionOrBosonEnum::FERMION,
-				                  typename OperatorType::PairType(1,m),
-				                  asign,
-				                  su2related);
+				    ProgramGlobals::FermionOrBosonEnum::FERMION,
+				    typename OperatorType::PairType(1, m),
+				    asign,
+				    su2related);
 				creationMatrix.push_back(myOp);
 			}
 		}
@@ -361,32 +361,36 @@ private:
 	//! Calculate fermionic sign when applying operator c^\dagger_{i\sigma} to
 	//! basis state ket
 	//! N.B.: HAS BEEN CHANGED TO ACCOMODATE FOR MULTIPLE BANDS
-	RealType sign(HilbertState const &ket, int i,SizeType sigma) const
+	RealType sign(HilbertState const& ket, int i, SizeType sigma) const
 	{
-		int value=0;
-		SizeType dofs=2*modelParameters_.orbitals;
-		for (SizeType alpha=0;alpha<dofs;alpha++)
-			value += HilbertSpaceFeAsType::calcNofElectrons(ket,0,i,alpha);
+		int value = 0;
+		SizeType dofs = 2 * modelParameters_.orbitals;
+		for (SizeType alpha = 0; alpha < dofs; alpha++)
+			value += HilbertSpaceFeAsType::calcNofElectrons(ket, 0, i, alpha);
 		// add electron on site 0 if needed
-		if (i>0) value += HilbertSpaceFeAsType::electrons(ket);
+		if (i > 0)
+			value += HilbertSpaceFeAsType::electrons(ket);
 
-		//order for sign is: a up, b up, a down, b down, etc
-		unsigned int x = HilbertSpaceFeAsType::get(ket,i);
-		int spin = sigma/modelParameters_.orbitals;
+		// order for sign is: a up, b up, a down, b down, etc
+		unsigned int x = HilbertSpaceFeAsType::get(ket, i);
+		int spin = sigma / modelParameters_.orbitals;
 		SizeType orb = sigma % modelParameters_.orbitals;
 
-		for (SizeType j=0;j<orb;j++) {
-			for (SizeType k=0;k<2;k++) {
+		for (SizeType j = 0; j < orb; j++) {
+			for (SizeType k = 0; k < 2; k++) {
 				SizeType ind = j + k * modelParameters_.orbitals;
-				int mask = (1<<ind);
-				if (x & mask) value++;
+				int mask = (1 << ind);
+				if (x & mask)
+					value++;
 			}
 		}
-		if (spin==SPIN_DOWN) {
-			int mask = (1<<orb);
-			if (x & mask) value++;
+		if (spin == SPIN_DOWN) {
+			int mask = (1 << orb);
+			if (x & mask)
+				value++;
 		}
-		if (value==0 || value%2==0) return 1.0;
+		if (value == 0 || value % 2 == 0)
+			return 1.0;
 
 		return FERMION_SIGN;
 	}
@@ -394,47 +398,47 @@ private:
 	//! Find c^\dagger_i\gamma\sigma in the natural basis natBasis
 	//! N.B.: HAS BEEN CHANGED TO ACCOMODATE FOR MULTIPLE BANDS
 	void findOperatorMatrices(SparseMatrixType& creationMatrix,
-	                          int i,
-	                          int sigma,
-	                          const HilbertBasisType& natBasis) const
+	    int i,
+	    int sigma,
+	    const HilbertBasisType& natBasis) const
 	{
 		int n = natBasis.size();
-		MatrixType cm(n,n);
+		MatrixType cm(n, n);
 
-		for (SizeType ii=0;ii<natBasis.size();ii++) {
+		for (SizeType ii = 0; ii < natBasis.size(); ii++) {
 			HilbertState ket = natBasis[ii];
 			HilbertState bra = ket;
 
-			if (HilbertSpaceFeAsType::isNonZero(ket,i,sigma)) {
+			if (HilbertSpaceFeAsType::isNonZero(ket, i, sigma)) {
 
 			} else {
-				HilbertSpaceFeAsType::create(bra,i,sigma);
-				int jj = PsimagLite::indexOrMinusOne(natBasis,bra);
-				if (jj<0)
+				HilbertSpaceFeAsType::create(bra, i, sigma);
+				int jj = PsimagLite::indexOrMinusOne(natBasis, bra);
+				if (jj < 0)
 					throw PsimagLite::RuntimeError("findOperatorMatrices: internal error\n");
-				if (ii==SizeType(jj)) {
-					std::cerr<<"ii="<<i<<" ket="<<ket<<" bra="<<bra<<" sigma="<<sigma<<"\n";
+				if (ii == SizeType(jj)) {
+					std::cerr << "ii=" << i << " ket=" << ket << " bra=" << bra << " sigma=" << sigma << "\n";
 					throw PsimagLite::RuntimeError("Creation operator cannot be diagonal\n");
 				}
 
-				cm(ii,jj) =sign(ket,i,sigma);
+				cm(ii, jj) = sign(ket, i, sigma);
 			}
 		}
 
 		SparseMatrixType temp;
-		fullMatrixToCrsMatrix(temp,cm);
-		transposeConjugate(creationMatrix,temp);
+		fullMatrixToCrsMatrix(temp, cm);
+		transposeConjugate(creationMatrix, temp);
 	}
 
 	void setSymmetryRelatedInternal(VectorQnType& qns,
-	                                const HilbertBasisType& basis,
-	                                int n) const
+	    const HilbertBasisType& basis,
+	    int n) const
 	{
 		// find j,m and flavors (do it by hand since we assume n==1)
 		// note: we use 2j instead of j
 		// note: we use m+j instead of m
 		// This assures us that both j and m are SizeType
-		typedef std::pair<SizeType,SizeType> PairType;
+		typedef std::pair<SizeType, SizeType> PairType;
 
 		qns.resize(basis.size(), QnType::zero());
 		SizeType mode = ModelBaseType::targetQuantum().sizeOfOther();
@@ -447,19 +451,20 @@ private:
 		}
 
 		for (SizeType i = 0; i < basis.size(); ++i) {
-			PairType jmpair(0,0);
+			PairType jmpair(0, 0);
 
 			// nup
 			SizeType electronsUp = HilbertSpaceFeAsType::electronsWithGivenSpin(basis[i],
-			                                                                    SPIN_UP);
+			    SPIN_UP);
 			// ndown
 			SizeType electronsDown = HilbertSpaceFeAsType::electronsWithGivenSpin(basis[i],
-			                                                                      SPIN_DOWN);
+			    SPIN_DOWN);
 			SizeType electrons = electronsDown + electronsUp;
 
 			other[0] = electrons;
 			other[1] = electronsUp;
-			if (mode == 2) other[2] = findMvalue(basis[i]);
+			if (mode == 2)
+				other[2] = findMvalue(basis[i]);
 			bool sign = electrons & 1;
 			qns[i] = QnType(sign, other, jmpair, 0);
 		}
@@ -467,10 +472,11 @@ private:
 
 	SizeType findMvalue(SizeType ket) const
 	{
-		SizeType dofs = 2*modelParameters_.orbitals;
+		SizeType dofs = 2 * modelParameters_.orbitals;
 		SizeType sum = 0;
 		for (SizeType sigma = 0; sigma < dofs; ++sigma) {
-			if (!HilbertSpaceFeAsType::isNonZero(ket, 0, sigma)) continue;
+			if (!HilbertSpaceFeAsType::isNonZero(ket, 0, sigma))
+				continue;
 			SizeType orbital = sigma % modelParameters_.orbitals;
 			sum += orbital;
 		}
@@ -482,50 +488,51 @@ private:
 	// note: we use m+j instead of m
 	// This assures us that both j and m are SizeType
 	// does not work for 6 or 9
-	template<typename PairType>
+	template <typename PairType>
 	PairType calcJmvalue(const HilbertState& ket) const
 	{
-		SizeType site0=0;
-		SizeType site1=0;
+		SizeType site0 = 0;
+		SizeType site1 = 0;
 
-		spinSquared_.doOnePairOfSitesA(ket,site0,site1);
-		spinSquared_.doOnePairOfSitesB(ket,site0,site1);
-		spinSquared_.doDiagonal(ket,site0,site1);
+		spinSquared_.doOnePairOfSitesA(ket, site0, site1);
+		spinSquared_.doOnePairOfSitesB(ket, site0, site1);
+		spinSquared_.doDiagonal(ket, site0, site1);
 
-		RealType sz = spinSquared_.spinZ(ket,site0);
-		PairType jm= spinSquaredHelper_.getJmPair(sz);
+		RealType sz = spinSquared_.spinZ(ket, site0);
+		PairType jm = spinSquaredHelper_.getJmPair(sz);
 		return jm;
 	}
 
 	void addHoppingOnSite(SparseMatrixType& hmatrix,
-	                      SizeType i,
-	                      SizeType actualSite) const
+	    SizeType i,
+	    SizeType actualSite) const
 	{
 		const RealType zero = 0.0;
 		SizeType orbitals = modelParameters_.orbitals;
-		SizeType dof = 2*orbitals;
+		SizeType dof = 2 * orbitals;
 		SparseMatrixType tmpMatrix;
 		SparseMatrixType tmp;
 		const VectorOperatorType& cm = creationMatrix_;
 		for (SizeType orb1 = 0; orb1 < orbitals; ++orb1) {
-			const SparseMatrixType& m1up = cm[orb1 + SPIN_UP*orbitals + i*dof].getCRS();
-			const SparseMatrixType& m1down = cm[orb1 + SPIN_DOWN*orbitals + i*dof].getCRS();
+			const SparseMatrixType& m1up = cm[orb1 + SPIN_UP * orbitals + i * dof].getCRS();
+			const SparseMatrixType& m1down = cm[orb1 + SPIN_DOWN * orbitals + i * dof].getCRS();
 
 			for (SizeType orb2 = 0; orb2 < orbitals; ++orb2) {
 				ComplexOrRealType val = getOnSiteHopping(actualSite, orb1, orb2);
-				if (val == zero) continue;
+				if (val == zero)
+					continue;
 
-				const SparseMatrixType& m2up = cm[orb2 + SPIN_UP*orbitals + i*dof].getCRS();
+				const SparseMatrixType& m2up = cm[orb2 + SPIN_UP * orbitals + i * dof].getCRS();
 				SparseMatrixType m2t;
 				transposeConjugate(m2t, m2up);
 				multiply(tmpMatrix, m1up, m2t);
-				tmp += val*tmpMatrix;
+				tmp += val * tmpMatrix;
 
-				const SparseMatrixType& m2down = cm[orb2 + SPIN_DOWN*orbitals + i*dof].getCRS();
+				const SparseMatrixType& m2down = cm[orb2 + SPIN_DOWN * orbitals + i * dof].getCRS();
 				transposeConjugate(m2t, m2down);
 				multiply(tmpMatrix, m1down, m2t);
 
-				tmp += val*tmpMatrix;
+				tmp += val * tmpMatrix;
 			}
 		}
 
@@ -534,8 +541,7 @@ private:
 
 	ComplexOrRealType getOnSiteHopping(SizeType actualSite, SizeType orb1, SizeType orb2) const
 	{
-		const typename PsimagLite::Vector<PsimagLite::Matrix<ComplexOrRealType> >::Type& v =
-		        modelParameters_.hopOnSite;
+		const typename PsimagLite::Vector<PsimagLite::Matrix<ComplexOrRealType>>::Type& v = modelParameters_.hopOnSite;
 		if (v.size() == 0)
 			err("getOnSiteHopping");
 		if (v.size() > 1 && actualSite >= v.size())
@@ -545,12 +551,12 @@ private:
 	}
 
 	void addPotentialV(SparseMatrixType& hmatrix,
-	                   SizeType i,
-	                   SizeType actualIndexOfSite,
-	                   const typename PsimagLite::Vector<RealType>::Type& V) const
+	    SizeType i,
+	    SizeType actualIndexOfSite,
+	    const typename PsimagLite::Vector<RealType>::Type& V) const
 	{
-		SizeType v1 = 2*modelParameters_.orbitals*superGeometry_.numberOfSites();
-		SizeType v2 = v1*modelParameters_.orbitals;
+		SizeType v1 = 2 * modelParameters_.orbitals * superGeometry_.numberOfSites();
+		SizeType v2 = v1 * modelParameters_.orbitals;
 
 		if (V.size() != v1 && V.size() != v2) {
 			PsimagLite::String str(__FILE__);
@@ -561,13 +567,13 @@ private:
 		}
 
 		if (V.size() == v1) {
-			for (SizeType orb=0;orb<modelParameters_.orbitals;orb++)
+			for (SizeType orb = 0; orb < modelParameters_.orbitals; orb++)
 				addPotentialV(hmatrix, i, actualIndexOfSite, orb, V);
 		}
 
 		if (V.size() == v2) {
-			for (SizeType orb=0;orb<modelParameters_.orbitals;orb++) {
-				for (SizeType orb2=0;orb2<modelParameters_.orbitals;orb2++) {
+			for (SizeType orb = 0; orb < modelParameters_.orbitals; orb++) {
+				for (SizeType orb2 = 0; orb2 < modelParameters_.orbitals; orb2++) {
 					addPotentialV(hmatrix, i, actualIndexOfSite, orb, orb2, V);
 				}
 			}
@@ -577,47 +583,45 @@ private:
 	}
 
 	void addPotentialV(SparseMatrixType& hmatrix,
-	                   SizeType i,
-	                   SizeType actualIndexOfSite,
-	                   SizeType orbital,
-	                   const typename PsimagLite::Vector<RealType>::Type& V) const
+	    SizeType i,
+	    SizeType actualIndexOfSite,
+	    SizeType orbital,
+	    const typename PsimagLite::Vector<RealType>::Type& V) const
 	{
-		int dof = 2*modelParameters_.orbitals;
+		int dof = 2 * modelParameters_.orbitals;
 		const VectorOperatorType& cm = creationMatrix_;
-		SparseMatrixType nup = n(cm[orbital+SPIN_UP*modelParameters_.orbitals+i*dof].getCRS());
-		SparseMatrixType ndown = n(cm[orbital+SPIN_DOWN*modelParameters_.orbitals+i*dof].getCRS());
+		SparseMatrixType nup = n(cm[orbital + SPIN_UP * modelParameters_.orbitals + i * dof].getCRS());
+		SparseMatrixType ndown = n(cm[orbital + SPIN_DOWN * modelParameters_.orbitals + i * dof].getCRS());
 
 		SizeType linSize = superGeometry_.numberOfSites();
 
-		SizeType iUp = actualIndexOfSite + (orbital + 0*modelParameters_.orbitals)*linSize;
-		hmatrix +=  V[iUp] * nup;
-		SizeType iDown = actualIndexOfSite + (orbital + 1*modelParameters_.orbitals)*linSize;
+		SizeType iUp = actualIndexOfSite + (orbital + 0 * modelParameters_.orbitals) * linSize;
+		hmatrix += V[iUp] * nup;
+		SizeType iDown = actualIndexOfSite + (orbital + 1 * modelParameters_.orbitals) * linSize;
 		hmatrix += V[iDown] * ndown;
 	}
 
-	void addPotentialV(SparseMatrixType &hmatrix,
-	                   SizeType i,
-	                   SizeType actualIndexOfSite,
-	                   SizeType orb,
-	                   SizeType orb2,
-	                   const typename PsimagLite::Vector<RealType>::Type& V) const
+	void addPotentialV(SparseMatrixType& hmatrix,
+	    SizeType i,
+	    SizeType actualIndexOfSite,
+	    SizeType orb,
+	    SizeType orb2,
+	    const typename PsimagLite::Vector<RealType>::Type& V) const
 	{
-		int dof=2*modelParameters_.orbitals;
+		int dof = 2 * modelParameters_.orbitals;
 		const VectorOperatorType& cm = creationMatrix_;
-		SizeType orbitalsSquared = modelParameters_.orbitals*modelParameters_.orbitals;
+		SizeType orbitalsSquared = modelParameters_.orbitals * modelParameters_.orbitals;
 
-		SparseMatrixType nup = nEx(cm[orb+SPIN_UP*modelParameters_.orbitals+i*dof].getCRS(),
-		        cm[orb2+SPIN_UP*modelParameters_.orbitals+i*dof].getCRS());
-		SparseMatrixType ndown = nEx(cm[orb+SPIN_DOWN*modelParameters_.orbitals+i*dof].getCRS(),
-		        cm[orb2+SPIN_DOWN*modelParameters_.orbitals+i*dof].getCRS());
+		SparseMatrixType nup = nEx(cm[orb + SPIN_UP * modelParameters_.orbitals + i * dof].getCRS(),
+		    cm[orb2 + SPIN_UP * modelParameters_.orbitals + i * dof].getCRS());
+		SparseMatrixType ndown = nEx(cm[orb + SPIN_DOWN * modelParameters_.orbitals + i * dof].getCRS(),
+		    cm[orb2 + SPIN_DOWN * modelParameters_.orbitals + i * dof].getCRS());
 
 		SizeType linSize = superGeometry_.numberOfSites();
 
-		SizeType iUp = actualIndexOfSite + (orb + orb2*modelParameters_.orbitals +
-		                                    0*orbitalsSquared)*linSize;
+		SizeType iUp = actualIndexOfSite + (orb + orb2 * modelParameters_.orbitals + 0 * orbitalsSquared) * linSize;
 		hmatrix += V[iUp] * nup;
-		SizeType iDown = actualIndexOfSite + (orb + orb2*modelParameters_.orbitals +
-		                                      1*orbitalsSquared)*linSize;
+		SizeType iDown = actualIndexOfSite + (orb + orb2 * modelParameters_.orbitals + 1 * orbitalsSquared) * linSize;
 		hmatrix += V[iDown] * ndown;
 	}
 
@@ -625,19 +629,19 @@ private:
 	{
 		SparseMatrixType tmpMatrix;
 		SparseMatrixType cdagger;
-		transposeConjugate(cdagger,c);
-		multiply(tmpMatrix,c,cdagger);
+		transposeConjugate(cdagger, c);
+		multiply(tmpMatrix, c, cdagger);
 
 		return tmpMatrix;
 	}
 
 	SparseMatrixType nEx(const SparseMatrixType& c1,
-	                     const SparseMatrixType& c2) const
+	    const SparseMatrixType& c2) const
 	{
 		SparseMatrixType tmpMatrix;
 		SparseMatrixType cdagger;
-		transposeConjugate(cdagger,c2);
-		multiply(tmpMatrix,c1,cdagger);
+		transposeConjugate(cdagger, c2);
+		multiply(tmpMatrix, c1, cdagger);
 
 		return tmpMatrix;
 	}
@@ -656,19 +660,19 @@ private:
 		const RealType zeroPointFive = 0.5;
 		SizeType orbitals = modelParameters_.orbitals;
 		for (SizeType k0 = 0; k0 < orbitals; ++k0) {
-			const MatrixType& m0 = cm[k0 + SPIN_DOWN*orbitals].getCRS().toDense();
+			const MatrixType& m0 = cm[k0 + SPIN_DOWN * orbitals].getCRS().toDense();
 			for (SizeType k1 = 0; k1 < orbitals; ++k1) {
-				const MatrixType& m1 = cm[k1 + SPIN_UP*orbitals].getCRS().toDense();
-				m0m1 = m0*m1;
+				const MatrixType& m1 = cm[k1 + SPIN_UP * orbitals].getCRS().toDense();
+				m0m1 = m0 * m1;
 				for (SizeType k2 = 0; k2 < orbitals; ++k2) {
-					const MatrixType& m2 = cm[k2 + SPIN_UP*orbitals].getCRS().toDense();
+					const MatrixType& m2 = cm[k2 + SPIN_UP * orbitals].getCRS().toDense();
 					SizeType k3 = (k0 + k1 + k2) % orbitals;
 
-					const MatrixType& m3 = cm[k3 + SPIN_DOWN*orbitals].getCRS().toDense();
-					m2m3 = m3*m2;
+					const MatrixType& m3 = cm[k3 + SPIN_DOWN * orbitals].getCRS().toDense();
+					m2m3 = m3 * m2;
 					transposeConjugate(m2m3t, m2m3);
 					term = m2m3t * m0m1;
-					qxDense += zeroPointFive*term;
+					qxDense += zeroPointFive * term;
 				}
 			}
 		}
@@ -676,16 +680,15 @@ private:
 		fullMatrixToCrsMatrix(qx_, qxDense);
 	}
 
-	ParamsModelType  modelParameters_;
+	ParamsModelType modelParameters_;
 	const SuperGeometryType& superGeometry_;
-	SpinSquaredHelper<RealType,HilbertState> spinSquaredHelper_;
-	SpinSquared<SpinSquaredHelper<RealType,HilbertState> > spinSquared_;
+	SpinSquaredHelper<RealType, HilbertState> spinSquaredHelper_;
+	SpinSquared<SpinSquaredHelper<RealType, HilbertState>> spinSquared_;
 	HilbertBasisType basis_;
 	VectorQnType qq_;
 	VectorOperatorType creationMatrix_;
 	SparseMatrixType qx_;
-}; //class ModelHubbardMultiBand
+}; // class ModelHubbardMultiBand
 } // namespace Dmrg
 /*@}*/
 #endif
-
