@@ -79,36 +79,39 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
  */
 #ifndef MODEL_HUBBARD_DMRG
 #define MODEL_HUBBARD_DMRG
-#include <cassert>
-#include "Sort.h" // in PsimagLite
-#include "ParametersModelHubbard.h"
-#include "HilbertSpaceHubbard.h"
 #include "CrsMatrix.h"
-#include "SpinSquaredHelper.h"
-#include "SpinSquared.h"
-#include "VerySparseMatrix.h"
+#include "HilbertSpaceHubbard.h"
+#include "ParametersModelHubbard.h"
 #include "ProgramGlobals.h"
+#include "Sort.h" // in PsimagLite
+#include "SpinSquared.h"
+#include "SpinSquaredHelper.h"
+#include "VerySparseMatrix.h"
+#include <cassert>
 
-namespace Dmrg {
-template<typename ModelBaseType> class ExtendedHubbard1Orb;
+namespace Dmrg
+{
+template <typename ModelBaseType>
+class ExtendedHubbard1Orb;
 
 //! Model Hubbard for DMRG solver, inherits from ModelBase and implements its interface:
-template<typename ModelBaseType>
-class ModelHubbard : public ModelBaseType {
+template <typename ModelBaseType>
+class ModelHubbard : public ModelBaseType
+{
 
 	typedef typename ModelBaseType::BlockType BlockType;
 	typedef typename ModelBaseType::SolverParamsType SolverParamsType;
 	typedef typename ModelBaseType::VectorType VectorType;
 
 	static const int FERMION_SIGN = -1;
-	static const int DEGREES_OF_FREEDOM=2;
-	static const int NUMBER_OF_ORBITALS=1;
+	static const int DEGREES_OF_FREEDOM = 2;
+	static const int NUMBER_OF_ORBITALS = 1;
 
 public:
 
 	typedef ModelHubbard<ModelBaseType> ThisType;
 	typedef unsigned int long WordType;
-	typedef  HilbertSpaceHubbard<WordType> HilbertSpaceHubbardType;
+	typedef HilbertSpaceHubbard<WordType> HilbertSpaceHubbardType;
 	typedef typename ModelBaseType::ModelHelperType ModelHelperType;
 	typedef typename ModelBaseType::SuperGeometryType SuperGeometryType;
 	typedef typename ModelBaseType::LeftRightSuperType LeftRightSuperType;
@@ -124,26 +127,26 @@ public:
 	typedef typename QnType::VectorQnType VectorQnType;
 	typedef typename HilbertSpaceHubbardType::HilbertState HilbertState;
 	typedef typename ModelBaseType::InputValidatorType InputValidatorType;
-	typedef	typename ModelBaseType::MyBasis MyBasis;
-	typedef	typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
+	typedef typename ModelBaseType::MyBasis MyBasis;
+	typedef typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
 	typedef typename PsimagLite::Vector<HilbertState>::Type HilbertBasisType;
 	typedef typename ModelBaseType::ModelTermType ModelTermType;
 	typedef typename ModelBaseType::OpForLinkType OpForLinkType;
 	typedef typename ModelBaseType::OpsLabelType OpsLabelType;
 
-	enum {SPIN_UP = HilbertSpaceHubbardType::SPIN_UP,
-		  SPIN_DOWN = HilbertSpaceHubbardType::SPIN_DOWN};
+	enum { SPIN_UP = HilbertSpaceHubbardType::SPIN_UP,
+		SPIN_DOWN = HilbertSpaceHubbardType::SPIN_DOWN };
 
 	ModelHubbard(const SolverParamsType& solverParams,
-	             InputValidatorType& io,
-	             const SuperGeometryType& geometry,
-	             PsimagLite::String extension)
+	    InputValidatorType& io,
+	    const SuperGeometryType& geometry,
+	    PsimagLite::String extension)
 	    : ModelBaseType(solverParams,
-	                    geometry,
-	                    io),
-	      modelParameters_(io),
-	      spinSquared_(spinSquaredHelper_,NUMBER_OF_ORBITALS,DEGREES_OF_FREEDOM),
-	      extension_(extension)
+		geometry,
+		io)
+	    , modelParameters_(io)
+	    , spinSquared_(spinSquaredHelper_, NUMBER_OF_ORBITALS, DEGREES_OF_FREEDOM)
+	    , extension_(extension)
 	{
 		ModelBaseType::onSiteHLegacyFix(modelParameters_.onSiteHaddLegacy);
 
@@ -157,19 +160,18 @@ public:
 			throw PsimagLite::RuntimeError(msg);
 		}
 
-		if (vsize != 2*totalSites) {
+		if (vsize != 2 * totalSites) {
 			PsimagLite::String msg("ModelHubbard: potentialV expecting ");
-			msg += ttos(2*totalSites) + " entries, got " + ttos(vsize) + "\n";
+			msg += ttos(2 * totalSites) + " entries, got " + ttos(vsize) + "\n";
 			throw PsimagLite::RuntimeError(msg);
 		}
 
-		if (modelParameters_.magneticX.size()>0 && ModelBaseType::targetQuantum().sizeOfOther() == 2) {
+		if (modelParameters_.magneticX.size() > 0 && ModelBaseType::targetQuantum().sizeOfOther() == 2) {
 			PsimagLite::String msg("ModelHubbard: Sz not conserved: You should remove ");
 			msg += "TargeteElectronsDown or TargetSzPlusConst from the input file.\n";
 			msg += "TargeteElectronsUp is then interpreted as total number of electrons\n";
 			throw PsimagLite::RuntimeError(msg);
 		}
-
 	}
 
 protected:
@@ -189,24 +191,25 @@ protected:
 		VectorOperatorType creationMatrix(DEGREES_OF_FREEDOM);
 		//! Set the operators c^\daggger_{i\sigma} in the natural basis
 		SizeType ind = 0;
-		for (int sigma=0;sigma<DEGREES_OF_FREEDOM;sigma++) {
-			tmpMatrix = findOperatorMatrices(ind,sigma,natBasis);
-			int asign= 1;
-			if (sigma>0) asign= 1;
+		for (int sigma = 0; sigma < DEGREES_OF_FREEDOM; sigma++) {
+			tmpMatrix = findOperatorMatrices(ind, sigma, natBasis);
+			int asign = 1;
+			if (sigma > 0)
+				asign = 1;
 			typename OperatorType::Su2RelatedType su2related;
-			if (sigma==0) {
-				su2related.source.push_back(ind*DEGREES_OF_FREEDOM);
-				su2related.source.push_back(ind*DEGREES_OF_FREEDOM+1);
+			if (sigma == 0) {
+				su2related.source.push_back(ind * DEGREES_OF_FREEDOM);
+				su2related.source.push_back(ind * DEGREES_OF_FREEDOM + 1);
 				su2related.transpose.push_back(-1);
 				su2related.transpose.push_back(-1);
 				su2related.offset = NUMBER_OF_ORBITALS;
 			}
 
 			OperatorType myOp(tmpMatrix,
-			                  ProgramGlobals::FermionOrBosonEnum::FERMION,
-			                  typename OperatorType::PairType(1,1-sigma),
-			                  asign,
-			                  su2related);
+			    ProgramGlobals::FermionOrBosonEnum::FERMION,
+			    typename OperatorType::PairType(1, 1 - sigma),
+			    asign,
+			    su2related);
 
 			c.push(myOp, (sigma == 0) ? "up" : "down");
 			creationMatrix[sigma] = myOp;
@@ -219,72 +222,66 @@ protected:
 			OpsLabelType& splus = this->createOpsLabel("splus");
 			OpsLabelType& sminus = this->createOpsLabel("sminus");
 
-			PsimagLite::Matrix<SparseElementType> tmp =
-			        multiplyTc(creationMatrix[iup].getCRS(),creationMatrix[idown].getCRS());
+			PsimagLite::Matrix<SparseElementType> tmp = multiplyTc(creationMatrix[iup].getCRS(), creationMatrix[idown].getCRS());
 			SparseMatrixType tmp2(tmp);
 			typename OperatorType::Su2RelatedType su2Related;
 			splus.push(OperatorType(tmp2,
-			                        ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                        typename OperatorType::PairType(0,0),
-			                        1.0,
-			                        su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 			SparseMatrixType tmp3;
 			transposeConjugate(tmp3, tmp2);
 			sminus.push(OperatorType(tmp3,
-			                         ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                         typename OperatorType::PairType(0,0),
-			                         1.0,
-			                         su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 		}
 
 		{
 			OpsLabelType& sz = this->createOpsLabel("sz");
-			PsimagLite::Matrix<SparseElementType> tmp =
-			        multiplyTc(creationMatrix[iup].getCRS(),creationMatrix[iup].getCRS());
-			PsimagLite::Matrix<SparseElementType> tmp2 =
-			        multiplyTc(creationMatrix[idown].getCRS(),creationMatrix[idown].getCRS());
-			tmp = 0.5*(tmp - tmp2);
+			PsimagLite::Matrix<SparseElementType> tmp = multiplyTc(creationMatrix[iup].getCRS(), creationMatrix[iup].getCRS());
+			PsimagLite::Matrix<SparseElementType> tmp2 = multiplyTc(creationMatrix[idown].getCRS(), creationMatrix[idown].getCRS());
+			tmp = 0.5 * (tmp - tmp2);
 			SparseMatrixType tmp3(tmp);
 			typename OperatorType::Su2RelatedType su2Related;
 			sz.push(OperatorType(tmp3,
-			                     ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                     typename OperatorType::PairType(0,0),
-			                     1.0,
-			                     su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 		}
 
-
 		PsimagLite::Matrix<SparseElementType> dense1;
 		{
 			OpsLabelType& nupop = this->createOpsLabel("nup");
 			OperatorType cup = creationMatrix[SPIN_UP];
 			cup.dagger();
-			SparseMatrixType tmp3(multiplyTc(cup.getCRS(),cup.getCRS()));
+			SparseMatrixType tmp3(multiplyTc(cup.getCRS(), cup.getCRS()));
 			typename OperatorType::Su2RelatedType su2Related;
 			nupop.push(OperatorType(tmp3,
-			                        ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                        typename OperatorType::PairType(0,0),
-			                        1.0,
-			                        su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 			crsMatrixToFullMatrix(dense1, tmp3);
 		}
 
-
 		PsimagLite::Matrix<SparseElementType> dense2;
 		{
 			OpsLabelType& ndownop = this->createOpsLabel("ndown");
 
 			OperatorType cdown = creationMatrix[SPIN_DOWN];
 			cdown.dagger();
-			SparseMatrixType tmp3(multiplyTc(cdown.getCRS(),cdown.getCRS()));
+			SparseMatrixType tmp3(multiplyTc(cdown.getCRS(), cdown.getCRS()));
 			typename OperatorType::Su2RelatedType su2Related;
 			ndownop.push(OperatorType(tmp3,
-			                          ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                          typename OperatorType::PairType(0,0),
-			                          1.0,
-			                          su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 			crsMatrixToFullMatrix(dense2, tmp3);
-
 		}
 
 		{
@@ -293,26 +290,26 @@ protected:
 			SparseMatrixType tmp(dense1);
 			typename OperatorType::Su2RelatedType su2Related;
 			nop.push(OperatorType(tmp,
-			                      ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                      typename OperatorType::PairType(0,0),
-			                      1.0,
-			                      su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 		}
 
 		{
 			OpsLabelType& d = this->createOpsLabel("d");
 			PsimagLite::Matrix<SparseElementType> cup;
-			crsMatrixToFullMatrix(cup,creationMatrix[SPIN_UP].getCRS());
+			crsMatrixToFullMatrix(cup, creationMatrix[SPIN_UP].getCRS());
 			PsimagLite::Matrix<SparseElementType> cdown;
-			crsMatrixToFullMatrix(cdown,creationMatrix[SPIN_DOWN].getCRS());
-			cup = (cup*cdown);
+			crsMatrixToFullMatrix(cdown, creationMatrix[SPIN_DOWN].getCRS());
+			cup = (cup * cdown);
 			SparseMatrixType tmp3(cup);
 			typename OperatorType::Su2RelatedType su2Related;
 			d.push(OperatorType(tmp3,
-			                    ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                    typename OperatorType::PairType(0,0),
-			                    1.0,
-			                    su2Related));
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    typename OperatorType::PairType(0, 0),
+			    1.0,
+			    su2Related));
 		}
 	}
 
@@ -339,7 +336,7 @@ protected:
 	*/
 	void fillModelLinks()
 	{
-		ModelTermType& hop = ModelBaseType::createTerm("hopping");//(A)
+		ModelTermType& hop = ModelBaseType::createTerm("hopping"); //(A)
 
 		OpForLinkType cup("c", 0); // (B)
 		hop.push(cup, 'N', cup, 'C', typename ModelTermType::Su2Properties(1, 1, 0)); // (C)
@@ -347,7 +344,8 @@ protected:
 		OpForLinkType cdown("c", 1); // (D)
 		hop.push(cdown, 'N', cdown, 'C', typename ModelTermType::Su2Properties(1, -1, 1)); // (E)
 
-		if (extension_ != "RashbaSOC") return;
+		if (extension_ != "RashbaSOC")
+			return;
 
 		assert(extension_ == "RashbaSOC");
 
@@ -357,15 +355,13 @@ protected:
 		rashbaSOC.push(cup, 'N', cdown, 'C');
 
 		// down-up
-		auto valueModifer = [](SparseElementType& value)
-		{ value = -PsimagLite::conj(value);};
+		auto valueModifer = [](SparseElementType& value) { value = -PsimagLite::conj(value); };
 
 		rashbaSOC.push(cdown,
-		               'N',
-		               cup,
-		               'C',
-		               valueModifer,
-		               typename ModelTermType::Su2Properties(1, 0, 0));
+		    'N',
+		    cup,
+		    'C',
+		    valueModifer);
 	}
 
 	/* PSIDOC Hubbard::write
@@ -386,72 +382,72 @@ protected:
 	PSIDOCCOPY $FirstFunctionBelow
 	 */
 	void write(PsimagLite::String label1,
-	           PsimagLite::IoNg::Out::Serializer& io) const
+	    PsimagLite::IoNg::Out::Serializer& io) const
 	{
-		if (!io.doesGroupExist(label1))    // (A)
-			io.createGroup(label1);          // (B)
+		if (!io.doesGroupExist(label1)) // (A)
+			io.createGroup(label1); // (B)
 
 		PsimagLite::String label = label1 + "/" + this->params().model;
-		io.createGroup(label);             // (C)
+		io.createGroup(label); // (C)
 		modelParameters_.write(label, io); // (D)
 		spinSquaredHelper_.write(label, io);
 		spinSquared_.write(label, io);
 	}
 
-	void addDiagonalsInNaturalBasis(SparseMatrixType &hmatrix,
-	                                const BlockType& block,
-	                                RealType time)  const
+	void addDiagonalsInNaturalBasis(SparseMatrixType& hmatrix,
+	    const BlockType& block,
+	    RealType time) const
 	{
 		ModelBaseType::additionalOnSiteHamiltonian(hmatrix, block, time);
 
-		SizeType n=block.size();
-		SparseMatrixType tmpMatrix,niup,nidown,Szsquare,Szi,Splusi,Sminusi;
+		SizeType n = block.size();
+		SparseMatrixType tmpMatrix, niup, nidown, Szsquare, Szi, Splusi, Sminusi;
 		SizeType linSize = ModelBaseType::superGeometry().numberOfSites();
 
 		for (SizeType i = 0; i < n; ++i) {
 			const SizeType site = block[i];
 
 			// onsite U hubbard
-			//n_i up
+			// n_i up
 			const OperatorType& cup = ModelBaseType::naturalOperator("c", site, 0);
 			transposeConjugate(tmpMatrix, cup.getCRS());
-			multiply(niup,tmpMatrix, cup.getCRS());
-			//n_i down
+			multiply(niup, tmpMatrix, cup.getCRS());
+			// n_i down
 			const OperatorType& cdown = ModelBaseType::naturalOperator("c", site, 1);
 			transposeConjugate(tmpMatrix, cdown.getCRS());
 			multiply(Sminusi, tmpMatrix, cup.getCRS());
 			transposeConjugate(Splusi, Sminusi);
-			multiply(nidown,tmpMatrix, cdown.getCRS());
+			multiply(nidown, tmpMatrix, cdown.getCRS());
 
 			multiply(tmpMatrix, niup, nidown);
 			RealType tmp = modelParameters_.hubbardU[block[i]];
-			hmatrix += tmp*tmpMatrix;
+			hmatrix += tmp * tmpMatrix;
 
 			// V_iup term
-			tmp = modelParameters_.potentialV[site + 0*linSize];
-			hmatrix += tmp*niup;
+			tmp = modelParameters_.potentialV[site + 0 * linSize];
+			hmatrix += tmp * niup;
 
 			// V_idown term
-			tmp = modelParameters_.potentialV[site + 1*linSize];
-			hmatrix += tmp*nidown;
+			tmp = modelParameters_.potentialV[site + 1 * linSize];
+			hmatrix += tmp * nidown;
 
 			// anisotropy
 			if (modelParameters_.anisotropy.size() == linSize) {
-				RealType mult1 =  1.0;
+				RealType mult1 = 1.0;
 				RealType mult2 = -1.0;
-				operatorPlus(Szi,niup,mult1,nidown,mult2);
-				multiply(Szsquare,Szi,Szi);
-				assert(i*2 < block.size());
-				assert(block[i*2] < modelParameters_.anisotropy.size());
-				RealType tmp = modelParameters_.anisotropy[block[i*2]]*0.25;
-				hmatrix += tmp*Szsquare;
+				operatorPlus(Szi, niup, mult1, nidown, mult2);
+				multiply(Szsquare, Szi, Szi);
+				assert(i * 2 < block.size());
+				assert(block[i * 2] < modelParameters_.anisotropy.size());
+				RealType tmp = modelParameters_.anisotropy[block[i * 2]] * 0.25;
+				hmatrix += tmp * Szsquare;
 			}
 
 			// magneticX
 			if (modelParameters_.magneticX.size() == linSize) {
-				RealType tmp = modelParameters_.magneticX[block[i]]*0.5;
-				hmatrix += tmp*Sminusi;
-				hmatrix += tmp*Splusi;
+				RealType tmp = modelParameters_.magneticX[block[i]] * 0.5;
+				hmatrix += tmp * Sminusi;
+				hmatrix += tmp * Splusi;
 			}
 		}
 	}
@@ -461,13 +457,14 @@ protected:
 private:
 
 	void setBasis(HilbertBasisType& basis,
-	              const VectorSizeType& block) const
+	    const VectorSizeType& block) const
 	{
-		int sitesTimesDof = DEGREES_OF_FREEDOM*block.size();
-		HilbertState total = (1<<sitesTimesDof);
+		int sitesTimesDof = DEGREES_OF_FREEDOM * block.size();
+		HilbertState total = (1 << sitesTimesDof);
 
 		basis.resize(total);
-		for (HilbertState a = 0; a < total; ++a) basis[a] = a;
+		for (HilbertState a = 0; a < total; ++a)
+			basis[a] = a;
 		if (basis.size() == 4) {
 			basis[0] = 0;
 			basis[1] = 2;
@@ -477,46 +474,49 @@ private:
 	}
 
 	//! Calculate fermionic sign when applying operator c^\dagger_{i\sigma} to basis state ket
-	RealType sign(typename HilbertSpaceHubbardType::HilbertState const &ket,
-	              int i,
-	              int sigma) const
+	RealType sign(typename HilbertSpaceHubbardType::HilbertState const& ket,
+	    int i,
+	    int sigma) const
 	{
-		int value=0;
-		value += HilbertSpaceHubbardType::calcNofElectrons(ket,0,i,0);
-		value += HilbertSpaceHubbardType::calcNofElectrons(ket,0,i,1);
-		int tmp1 = HilbertSpaceHubbardType::get(ket,0) &1;
-		int tmp2 = HilbertSpaceHubbardType::get(ket,0) &2;
-		if (i>0 && tmp1>0) value++;
-		if (i>0 && tmp2>0) value++;
-
-		if (sigma==1) { // spin down
-			if ((HilbertSpaceHubbardType::get(ket,i) &1)) value++;
+		int value = 0;
+		value += HilbertSpaceHubbardType::calcNofElectrons(ket, 0, i, 0);
+		value += HilbertSpaceHubbardType::calcNofElectrons(ket, 0, i, 1);
+		int tmp1 = HilbertSpaceHubbardType::get(ket, 0) & 1;
+		int tmp2 = HilbertSpaceHubbardType::get(ket, 0) & 2;
+		if (i > 0 && tmp1 > 0)
+			value++;
+		if (i > 0 && tmp2 > 0)
+			value++;
 
+		if (sigma == 1) { // spin down
+			if ((HilbertSpaceHubbardType::get(ket, i) & 1))
+				value++;
 		}
-		if (value%2==0) return 1.0;
+		if (value % 2 == 0)
+			return 1.0;
 
 		return FERMION_SIGN;
 	}
 
 	//! Find c^\dagger_isigma in the natural basis natBasis
 	SparseMatrixType findOperatorMatrices(int i,
-	                                      int sigma,
-	                                      const HilbertBasisType& natBasis) const
+	    int sigma,
+	    const HilbertBasisType& natBasis) const
 	{
-		typename HilbertSpaceHubbardType::HilbertState bra,ket;
+		typename HilbertSpaceHubbardType::HilbertState bra, ket;
 		int n = natBasis.size();
-		PsimagLite::Matrix<typename SparseMatrixType::value_type> cm(n,n);
+		PsimagLite::Matrix<typename SparseMatrixType::value_type> cm(n, n);
 
-		for (SizeType ii=0;ii<natBasis.size();ii++) {
-			bra=ket=natBasis[ii];
-			if (HilbertSpaceHubbardType::isNonZero(ket,i,sigma)) {
+		for (SizeType ii = 0; ii < natBasis.size(); ii++) {
+			bra = ket = natBasis[ii];
+			if (HilbertSpaceHubbardType::isNonZero(ket, i, sigma)) {
 
 			} else {
-				HilbertSpaceHubbardType::create(bra,i,sigma);
-				int jj = PsimagLite::indexOrMinusOne(natBasis,bra);
-				if (jj<0)
+				HilbertSpaceHubbardType::create(bra, i, sigma);
+				int jj = PsimagLite::indexOrMinusOne(natBasis, bra);
+				if (jj < 0)
 					throw PsimagLite::RuntimeError("findOperatorMatrices\n");
-				cm(ii,jj) =sign(ket,i,sigma);
+				cm(ii, jj) = sign(ket, i, sigma);
 			}
 		}
 
@@ -525,33 +525,32 @@ private:
 	}
 
 	void setSymmetryRelated(VectorQnType& qns,
-	                        const HilbertBasisType& basis,
-	                        int) const
+	    const HilbertBasisType& basis,
+	    int) const
 	{
 		// find j,m and flavors (do it by hand since we assume n==1)
 		// note: we use 2j instead of j
 		// note: we use m+j instead of m
 		// This assures us that both j and m are SizeType
-		typedef std::pair<SizeType,SizeType> PairType;
+		typedef std::pair<SizeType, SizeType> PairType;
 
 		const bool isCanonical = (ModelBaseType::targetQuantum().sizeOfOther() == 2);
 		if (isCanonical && extension_ == "RashbaSOC")
-			err(PsimagLite::String(__FILE__) +
-			    ": RashbaSOC sub-model must be canonical. Please " +
-			    "delete the TargetSzPlusConst= from the input file\n");
+			err(PsimagLite::String(__FILE__) + ": RashbaSOC sub-model must be canonical. Please " + "delete the TargetSzPlusConst= from the input file\n");
 
 		qns.resize(basis.size(), QnType::zero());
 		VectorSizeType other((isCanonical) ? 2 : 1, 0);
 		for (SizeType i = 0; i < basis.size(); ++i) {
 			PairType jmpair = calcJmValue<PairType>(basis[i]);
 			// nup
-			SizeType electronsUp = HilbertSpaceHubbardType::getNofDigits(basis[i],SPIN_UP);
+			SizeType electronsUp = HilbertSpaceHubbardType::getNofDigits(basis[i], SPIN_UP);
 			// ndown
-			SizeType electronsDown = HilbertSpaceHubbardType::getNofDigits(basis[i],SPIN_DOWN);
+			SizeType electronsDown = HilbertSpaceHubbardType::getNofDigits(basis[i], SPIN_DOWN);
 
 			other[0] = electronsUp + electronsDown;
 
-			if (isCanonical) other[1] = electronsUp;
+			if (isCanonical)
+				other[1] = electronsUp;
 
 			bool sign = other[0] & 1;
 			qns[i] = QnType(sign, other, jmpair, other[0]);
@@ -562,30 +561,30 @@ private:
 	// note: we use m+j instead of m
 	// This assures us that both j and m are SizeType
 	// does not work for 6 or 9
-	template<typename PairType>
+	template <typename PairType>
 	PairType calcJmValue(const HilbertState& ket) const
 	{
-		if (!MyBasis::useSu2Symmetry()) return PairType(0,0);
-		SizeType site0=0;
-		SizeType site1=0;
+		if (!MyBasis::useSu2Symmetry())
+			return PairType(0, 0);
+		SizeType site0 = 0;
+		SizeType site1 = 0;
 
-		spinSquared_.doOnePairOfSitesA(ket,site0,site1);
-		spinSquared_.doOnePairOfSitesB(ket,site0,site1);
-		spinSquared_.doDiagonal(ket,site0,site1);
+		spinSquared_.doOnePairOfSitesA(ket, site0, site1);
+		spinSquared_.doOnePairOfSitesB(ket, site0, site1);
+		spinSquared_.doDiagonal(ket, site0, site1);
 
-		RealType sz = spinSquared_.spinZ(ket,site0);
-		PairType jm= spinSquaredHelper_.getJmPair(sz);
+		RealType sz = spinSquared_.spinZ(ket, site0);
+		PairType jm = spinSquaredHelper_.getJmPair(sz);
 
 		return jm;
 	}
 
-	ParametersModelHubbard<RealType, QnType>  modelParameters_;
-	SpinSquaredHelper<RealType,WordType> spinSquaredHelper_;
-	SpinSquared<SpinSquaredHelper<RealType,WordType> > spinSquared_;
+	ParametersModelHubbard<RealType, QnType> modelParameters_;
+	SpinSquaredHelper<RealType, WordType> spinSquaredHelper_;
+	SpinSquared<SpinSquaredHelper<RealType, WordType>> spinSquared_;
 	PsimagLite::String extension_;
-};	//class ModelHubbard
+}; // class ModelHubbard
 
 } // namespace Dmrg
 /*@}*/
 #endif
-
