@@ -80,18 +80,20 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
 #ifndef DMRG_SU3_MODEL_H
 #define DMRG_SU3_MODEL_H
 
-#include <algorithm>
-#include "ParametersSu3.h"
-#include "CrsMatrix.h"
-#include "../../Engine/VerySparseMatrix.h"
 #include "../../Engine/ProgramGlobals.h"
 #include "../../Engine/Utils.h"
+#include "../../Engine/VerySparseMatrix.h"
+#include "CrsMatrix.h"
+#include "ParametersSu3.h"
 #include "Su3RepresentationP1.h"
+#include <algorithm>
 
-namespace Dmrg {
+namespace Dmrg
+{
 
-template<typename ModelBaseType>
-class Su3Model : public ModelBaseType {
+template <typename ModelBaseType>
+class Su3Model : public ModelBaseType
+{
 
 public:
 
@@ -102,7 +104,7 @@ public:
 	typedef typename ModelBaseType::LinkType LinkType;
 	typedef typename ModelHelperType::OperatorsType OperatorsType;
 	typedef typename ModelHelperType::RealType RealType;
-	typedef	typename ModelBaseType::VectorType VectorType;
+	typedef typename ModelBaseType::VectorType VectorType;
 	typedef typename ModelBaseType::QnType QnType;
 	typedef typename ModelBaseType::VectorQnType VectorQnType;
 	typedef typename ModelBaseType::BlockType BlockType;
@@ -119,32 +121,32 @@ public:
 	typedef typename OperatorsType::OperatorType OperatorType;
 	typedef typename OperatorType::PairType PairType;
 	typedef typename PsimagLite::Vector<OperatorType>::Type VectorOperatorType;
-	typedef	typename ModelBaseType::MyBasis MyBasis;
-	typedef	typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
+	typedef typename ModelBaseType::MyBasis MyBasis;
+	typedef typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
 	typedef typename ModelBaseType::OpsLabelType OpsLabelType;
 	typedef typename ModelBaseType::OpForLinkType OpForLinkType;
 	typedef ParametersSu3<RealType, QnType> ParametersSu3Type;
 	typedef Su3RepresentationBase<ComplexOrRealType> Su3RepresentationBaseType;
 	typedef Su3RepresentationP1<ComplexOrRealType,
-	PsimagLite::IsComplexNumber<ComplexOrRealType>::True> Su3RepresentationP1Type;
+	    PsimagLite::IsComplexNumber<ComplexOrRealType>::True>
+	    Su3RepresentationP1Type;
 
 	static const bool IS_REAL = !PsimagLite::IsComplexNumber<ComplexOrRealType>::True;
 
 	Su3Model(const SolverParamsType& solverParams,
-	         InputValidatorType& io,
-	         const SuperGeometryType& geometry)
+	    InputValidatorType& io,
+	    const SuperGeometryType& geometry)
 	    : ModelBaseType(solverParams,
-	                    geometry,
-	                    io),
-	      superGeometry_(geometry),
-	      modelParameters_(io),
-	      su3Rep_(nullptr)
+		geometry,
+		io)
+	    , superGeometry_(geometry)
+	    , modelParameters_(io)
+	    , su3Rep_(nullptr)
 	{
 		if (modelParameters_.p == 1) {
 			su3Rep_ = new Su3RepresentationP1Type();
 		} else {
-			err("Implementation for p = " + ttos(modelParameters_.p) +
-			    " has not been implemented\n");
+			err("Implementation for p = " + ttos(modelParameters_.p) + " has not been implemented\n");
 		}
 	}
 
@@ -166,8 +168,8 @@ public:
 
 	// m*T3(i)*T3(i) + m*T8(i)*T8(i)
 	void addDiagonalsInNaturalBasis(SparseMatrixType& hmatrix,
-	                                const BlockType& block,
-	                                RealType time) const
+	    const BlockType& block,
+	    RealType time) const
 	{
 		ModelBaseType::additionalOnSiteHamiltonian(hmatrix, block, time);
 
@@ -178,10 +180,10 @@ public:
 
 		MatrixType m8;
 		su3Rep_->getMatrix(m8, (IS_REAL) ? 4 : 7);
-		MatrixType m = m3*m3;
+		MatrixType m = m3 * m3;
 
 		if (IS_REAL) {
-			MatrixType mtemp = m8*m8;
+			MatrixType mtemp = m8 * m8;
 			m += mtemp;
 		}
 
@@ -208,7 +210,8 @@ protected:
 		BlockType block(1, site);
 		SizeType total = su3Rep_->size();
 		HilbertBasisType natBasis(total);
-		for (SizeType i = 0; i < total; ++i) natBasis[i] = i;
+		for (SizeType i = 0; i < total; ++i)
+			natBasis[i] = i;
 
 		setSymmetryRelated(qns, natBasis, block.size());
 
@@ -223,10 +226,10 @@ protected:
 			typename OperatorType::Su2RelatedType su2related;
 
 			OperatorType myOp(sparseMatrix,
-			                  ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                  PairType(0, 0),
-			                  1,
-			                  su2related);
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    PairType(0, 0),
+			    1,
+			    su2related);
 			this->createOpsLabel("T" + ttos(a + 1)).push(myOp);
 			this->makeTrackable("T" + ttos(a + 1));
 		}
@@ -238,7 +241,8 @@ protected:
 		BlockType block(1, site);
 		SizeType total = su3Rep_->size();
 		HilbertBasisType natBasis(total);
-		for (SizeType i = 0; i < total; ++i) natBasis[i] = i;
+		for (SizeType i = 0; i < total; ++i)
+			natBasis[i] = i;
 
 		setSymmetryRelated(qns, natBasis, block.size());
 
@@ -253,10 +257,10 @@ protected:
 			typename OperatorType::Su2RelatedType su2related;
 
 			OperatorType myOp(sparseMatrix,
-			                  ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                  PairType(0, 0),
-			                  1,
-			                  su2related);
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    PairType(0, 0),
+			    1,
+			    su2related);
 			this->createOpsLabel("Tplus" + ttos(a + 1)).push(myOp);
 			this->makeTrackable("Tplus" + ttos(a + 1));
 			myOp.dagger();
@@ -274,11 +278,11 @@ protected:
 			typename OperatorType::Su2RelatedType su2related;
 
 			OperatorType myOp(sparseMatrix,
-			                  ProgramGlobals::FermionOrBosonEnum::BOSON,
-			                  PairType(0, 0),
-			                  1,
-			                  su2related);
-			if (a==4) {
+			    ProgramGlobals::FermionOrBosonEnum::BOSON,
+			    PairType(0, 0),
+			    1,
+			    su2related);
+			if (a == 4) {
 				this->createOpsLabel("T8").push(myOp);
 				this->makeTrackable("T8");
 			} else {
@@ -318,7 +322,7 @@ protected:
 	void fillModelLinksReal()
 	{
 		ModelTermType& jOnepm = ModelBaseType::createTerm("jOne_pm");
-		auto multiplyByZeroPointFive = [](ComplexOrRealType& value) { value *= 0.5;};
+		auto multiplyByZeroPointFive = [](ComplexOrRealType& value) { value *= 0.5; };
 
 		for (SizeType a = 0; a < 3; ++a) {
 			OpForLinkType aOpForLink("Tplus" + ttos(a + 1));
@@ -332,17 +336,17 @@ protected:
 		ModelTermType& jOne88 = ModelBaseType::createTerm("jOne_88");
 		OpForLinkType aOpForLink8("T8");
 		jOne88.push(aOpForLink8, 'N', aOpForLink8, 'C');
-
 	}
+
 private:
 
 	// \sum_i T3(i) and \sum_i T8(i) are conserved separately
 	// We delegate to the representation the actual values and computation
 	void setSymmetryRelated(VectorQnType& qns,
-	                        const HilbertBasisType& basis,
-	                        int n) const
+	    const HilbertBasisType& basis,
+	    int n) const
 	{
-		typedef std::pair<SizeType,SizeType> PairType;
+		typedef std::pair<SizeType, SizeType> PairType;
 
 		VectorSizeType other(2);
 		QnType::ifPresentOther0IsElectrons = false;
@@ -363,5 +367,4 @@ private:
 
 } // namespace Dmrg
 /*@}*/
-#endif //DMRG_SU3_MODEL_H
-
+#endif // DMRG_SU3_MODEL_H
