@@ -80,10 +80,12 @@ DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.
 #define SUPER_HUBBARD_EXTENDED_H
 #include "../Models/ExtendedHubbard1Orb/ExtendedHubbard1Orb.h"
 
-namespace Dmrg {
+namespace Dmrg
+{
 //! Extended Hubbard for DMRG solver, uses ExtendedHubbard1Orb by containment
-template<typename ModelBaseType>
-class SuperHubbardExtended : public ModelBaseType {
+template <typename ModelBaseType>
+class SuperHubbardExtended : public ModelBaseType
+{
 
 public:
 
@@ -100,8 +102,8 @@ public:
 	typedef typename QnType::VectorQnType VectorQnType;
 	typedef typename ModelHelperType::SparseMatrixType SparseMatrixType;
 	typedef typename SparseMatrixType::value_type ComplexOrRealType;
-	typedef	typename ModelBaseType::MyBasis BasisType;
-	typedef	typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
+	typedef typename ModelBaseType::MyBasis BasisType;
+	typedef typename ModelBaseType::BasisWithOperatorsType MyBasisWithOperators;
 	typedef typename ModelHubbardType::HilbertBasisType HilbertBasisType;
 	typedef typename ModelHelperType::BlockType BlockType;
 	typedef typename ModelBaseType::SolverParamsType SolverParamsType;
@@ -117,12 +119,13 @@ public:
 	typedef typename ModelBaseType::OpForLinkType OpForLinkType;
 
 	SuperHubbardExtended(const SolverParamsType& solverParams,
-	                     InputValidatorType& io,
-	                     const SuperGeometryType& geometry)
-	    : ModelBaseType(solverParams, geometry, io),
-	      modelParameters_(io),
-	      extendedHubbard_(solverParams,io,geometry, "")
-	{}
+	    InputValidatorType& io,
+	    const SuperGeometryType& geometry)
+	    : ModelBaseType(solverParams, geometry, io)
+	    , modelParameters_(io)
+	    , extendedHubbard_(solverParams, io, geometry, "")
+	{
+	}
 
 	void write(PsimagLite::String label1, PsimagLite::IoNg::Out::Serializer& io) const
 	{
@@ -135,9 +138,9 @@ public:
 		extendedHubbard_.write(label, io);
 	}
 
-	virtual void addDiagonalsInNaturalBasis(SparseMatrixType &hmatrix,
-	                                        const BlockType& block,
-	                                        RealType time)  const
+	virtual void addDiagonalsInNaturalBasis(SparseMatrixType& hmatrix,
+	    const BlockType& block,
+	    RealType time) const
 	{
 		extendedHubbard_.addDiagonalsInNaturalBasis(hmatrix, block, time);
 	}
@@ -162,48 +165,44 @@ protected:
 
 		OpForLinkType splus("splus");
 
-		auto valueModiferTerm0 = [isSu2](ComplexOrRealType& value)
-		{ value *= (isSu2) ? -0.5 : 0.5;};
+		auto valueModiferTerm0 = [isSu2](ComplexOrRealType& value) { value *= (isSu2) ? -0.5 : 0.5; };
 
 		spsm.push(splus,
-		          'N',
-		          splus,
-		          'C',
-		          valueModiferTerm0,
-		          typename ModelTermType::Su2Properties(2, -1, 2));
+		    'N',
+		    splus,
+		    'C',
+		    valueModiferTerm0);
 
 		ModelTermType& szsz = ModelBaseType::createTerm("szsz");
 
 		if (!isSu2) {
 			OpForLinkType sz("sz");
-			szsz.push(sz, 'N', sz, 'N',  typename ModelTermType::Su2Properties(2, 0.5));
+			szsz.push(sz, 'N', sz, 'N', typename ModelTermType::Su2Properties(2, 0.5));
 		} else {
-			auto valueModifierTermOther = [isSu2](ComplexOrRealType& value)
-			{ if (isSu2) value = -value;};
+			auto valueModifierTermOther = [isSu2](ComplexOrRealType& value) { if (isSu2) value = -value; };
 			spsm.push(splus,
-			          'N',
-			          splus,
-			          'C',
-			          valueModifierTermOther,
-			          typename ModelTermType::Su2Properties(2, -1, 2));
+			    'N',
+			    splus,
+			    'C',
+			    valueModifierTermOther);
 		}
 	}
 
 private:
 
 	//! Full hamiltonian from creation matrices cm
-	void addSiSj(SparseMatrixType &,
-	             const VectorOperatorType&,
-	             const BlockType& block) const
+	void addSiSj(SparseMatrixType&,
+	    const VectorOperatorType&,
+	    const BlockType& block) const
 	{
 		// Assume block.size()==1 and then problem solved!!
 		// there are no connection if there's only one site ;-)
-		assert(block.size()==1);
+		assert(block.size() == 1);
 	}
 
-	ParametersModelHubbard<RealType, QnType>  modelParameters_;
+	ParametersModelHubbard<RealType, QnType> modelParameters_;
 	ModelHubbardType extendedHubbard_;
-};	//class SuperHubbardExtended
+}; // class SuperHubbardExtended
 
 } // namespace Dmrg
 /*@}*/
