@@ -3,20 +3,21 @@
 
 #include "ObserveDriver.h"
 
-namespace Dmrg {
-template<typename VectorWithOffsetType,
-         typename ModelType>
+namespace Dmrg
+{
+template <typename VectorWithOffsetType,
+    typename ModelType>
 bool observeOneFullSweep(IoInputType& io,
-                         const ModelType& model,
-                         const PsimagLite::String& list,
-                         SizeType orbitals)
+    const ModelType& model,
+    const PsimagLite::String& list,
+    SizeType orbitals)
 {
 	typedef typename ModelType::SuperGeometryType SuperGeometryType;
 	typedef typename ModelType::ModelHelperType::LeftRightSuperType LeftRightSuperType;
 	typedef typename ModelType::MatrixType MatrixType;
 	typedef typename ModelType::VectorType VectorType;
-	typedef ObserverHelper<IoInputType,MatrixType,VectorType,VectorWithOffsetType,LeftRightSuperType> ObserverHelperType;
-	typedef Observer<ObserverHelperType,ModelType> ObserverType;
+	typedef ObserverHelper<IoInputType, MatrixType, VectorType, VectorWithOffsetType, LeftRightSuperType> ObserverHelperType;
+	typedef Observer<ObserverHelperType, ModelType> ObserverType;
 	typedef ObservableLibrary<ObserverType> ObservableLibraryType;
 	typedef typename ObservableLibraryType::ManyPointActionType ManyPointActionType;
 	typedef typename PsimagLite::OneOperatorSpec::SiteSplit SiteSplitType;
@@ -24,7 +25,7 @@ bool observeOneFullSweep(IoInputType& io,
 	static SizeType start = 0;
 
 	const SuperGeometryType& superGeometry = model.superGeometry();
-	SizeType n  = superGeometry.numberOfSites();
+	SizeType n = superGeometry.numberOfSites();
 	SizeType rows = n; // could be n/2 if there's enough symmetry
 	SizeType cols = n;
 	SizeType nf = n - 2;
@@ -44,29 +45,29 @@ bool observeOneFullSweep(IoInputType& io,
 			nf = atoi(item.substr(label.length()).c_str());
 			rows = nf;
 			cols = nf;
-			std::cerr<<"observe: Found "<<label<<" = "<<nf;
-			std::cerr<<" (rows and cols also set to it)\n";
+			std::cerr << "observe: Found " << label << " = " << nf;
+			std::cerr << " (rows and cols also set to it)\n";
 		}
 
 		label = "%trail=";
 		labelIndex = item.find(label);
 		if (labelIndex == 0) {
 			trail = atoi(item.substr(label.length()).c_str());
-			std::cerr<<"observe: Found "<<label<<" = "<<trail<<"\n";
+			std::cerr << "observe: Found " << label << " = " << trail << "\n";
 			hasTrail = true;
 		}
 
 		label = "%rows=";
 		labelIndex = item.find(label);
 		if (labelIndex == 0) {
-			std::cerr<<"observe: Found %rows= with index "<<labelIndex<<"\n";
+			std::cerr << "observe: Found %rows= with index " << labelIndex << "\n";
 			rows = atoi(item.substr(label.length()).c_str());
 		}
 
 		label = "%cols=";
 		labelIndex = item.find(label);
 		if (labelIndex == 0) {
-			std::cerr<<"observe: Found %cols= with index "<<labelIndex<<"\n";
+			std::cerr << "observe: Found %cols= with index " << labelIndex << "\n";
 			cols = atoi(item.substr(label.length()).c_str());
 		}
 	}
@@ -75,21 +76,22 @@ bool observeOneFullSweep(IoInputType& io,
 		trail = n - 2 - nf;
 
 	ObservableLibraryType observerLib(io,
-	                                  n,
-	                                  model,
-	                                  start,
-	                                  nf,
-	                                  trail);
+	    n,
+	    model,
+	    start,
+	    nf,
+	    trail);
 
 	ManyPointActionType* manyPointAction = new ManyPointActionType(false, "");
 	for (SizeType i = 0; i < vecOptions.size(); ++i) {
 		PsimagLite::String item = vecOptions[i];
 
-		if (item.find("%") == 0) continue;
+		if (item.find("%") == 0)
+			continue;
 
 		SiteSplitType braceContent = PsimagLite::OneOperatorSpec::extractSiteIfAny(item,
-		                                                                           '{',
-		                                                                           '}');
+		    '{',
+		    '}');
 
 		PsimagLite::String actionString;
 		if (braceContent.hasSiteString) {
